@@ -44,7 +44,7 @@ while ( ~< *DATA) {
 #
 # Email addresses for we do not have names.
 #
-%map {$_} = "?" for 
+%map {$_} = "?" for @( 
     "agrow\100thegotonerd.com",
     "alexander_bluhm\100genua.de",
     "alexander_gernler\100genua.de",
@@ -82,7 +82,7 @@ while ( ~< *DATA) {
     "raf\100tradingpost.com.au",
     "scott\100perlcode.org",
     "smoketst\100hp46t243.cup.hp.com",
-    "yath-perlbug\100yath.de",
+    "yath-perlbug\100yath.de",)
 ;
 
 #
@@ -90,7 +90,7 @@ while ( ~< *DATA) {
 # Presumably deliberately?
 # 
 
-%map {$_} = '!' for
+%map {$_} = '!' for @(
      # Nick Ing-Simmons has passed away (2006-09-25).
      "nick\100ing-simmons.net",
      "nik\100tiuk.ti.com",
@@ -113,14 +113,14 @@ while ( ~< *DATA) {
      "ml-perl\100thepierianspring.org",
 
      # Yuval Kogman
-     "nothingmuch\100woobling.org",
+     "nothingmuch\100woobling.org",)
 
 ;
 
 
 if ((nelems @authors)) {
   my %raw;
-  foreach my $filename (< @authors) {
+  foreach my $filename ( @authors) {
     open FH, "<", "$filename" or die "Can't open $filename: $!";
     while ( ~< *FH) {
       next if m/^\#/;
@@ -206,7 +206,7 @@ sub display_ordered {
   my $i = (nelems @sorted);
   return unless (nelems @sorted);
   my $sum = 0;
-  foreach my $i ($reverse ? 0 ..( (nelems @sorted)-1) : reverse 0 ..( (nelems @sorted)-1)) {
+  foreach my $i (@($reverse ? < 0 ..( (nelems @sorted)-1) : < reverse 0 ..( (nelems @sorted)-1))) {
     next unless @sorted[$i];
     my $prefix;
     $sum += $i * nelems @{@sorted[$i]};
@@ -217,7 +217,7 @@ sub display_ordered {
     } else {
 	$prefix = "$value:\t";
     }
-    print < wrap ($prefix, "\t", join (" ", sort < @{@sorted[$i]}), "\n");
+    print < wrap ($prefix, "\t", join (" ", sort @{@sorted[$i]}), "\n");
   }
 }
 
@@ -227,7 +227,7 @@ sub process {
   my @authors = @( $log =~ m/From:\s+.*?([^"\@ \t\n<>]+\@[^"\@ \t\n<>]+)/gm );
 
   if ((nelems @authors)) {
-    foreach (< @authors) {
+    foreach ( @authors) {
       s/^<//;
       s/>$//;
       $_ = lc $_;
