@@ -2261,85 +2261,6 @@ Perl_do_shmio(pTHX_ I32 optype, SV **mark, SV **sp)
 
 #endif /* SYSV IPC */
 
-/*
-=head1 IO Functions
-
-=for apidoc start_glob
-
-Function called by C<do_readline> to spawn a glob (or do the glob inside
-perl on VMS). This code used to be inline, but now perl uses C<File::Glob>
-this glob starter is only used by miniperl during the build process.
-Moving it away shrinks pp_hot.c; shrinking pp_hot.c helps speed perl up.
-
-=cut
-*/
-
-PerlIO *
-Perl_start_glob (pTHX_ SV *tmpglob, GV *gv)
-{
-    dVAR;
-    SV * const tmpcmd = newSV(0);
-    PerlIO *fp;
-    IO * io = GvIO(gv);
-
-    PERL_ARGS_ASSERT_START_GLOB;
-
-    ENTER;
-    SAVEFREESV(tmpcmd);
-#ifdef VMS /* expand the wildcards right here, rather than opening a pipe, */
-           /* since spawning off a process is a real performance hit */
-
-PerlIO * 
-Perl_vms_start_glob
-   (pTHX_ SV *tmpglob,
-    IO *io);
-
-    fp = Perl_vms_start_glob(aTHX_ tmpglob, io);
-
-#else /* !VMS */
-#ifdef MACOS_TRADITIONAL
-    sv_setpv(tmpcmd, "glob ");
-    sv_catsv(tmpcmd, tmpglob);
-#else
-#ifdef DOSISH
-#ifdef OS2
-    sv_setpv(tmpcmd, "for a in ");
-    sv_catsv(tmpcmd, tmpglob);
-    sv_catpv(tmpcmd, "; do echo \"$a\\0\\c\"; done");
-#else
-#ifdef DJGPP
-    sv_setpv(tmpcmd, "/dev/dosglob/"); /* File System Extension */
-    sv_catsv(tmpcmd, tmpglob);
-#else
-    sv_setpv(tmpcmd, "perlglob ");
-    sv_catsv(tmpcmd, tmpglob);
-#endif /* !DJGPP */
-#endif /* !OS2 */
-#else /* !DOSISH */
-#if defined(CSH)
-    sv_setpvn(tmpcmd, PL_cshname, PL_cshlen);
-    sv_catpv(tmpcmd, " -cf 'set nonomatch; glob ");
-    sv_catsv(tmpcmd, tmpglob);
-    sv_catpv(tmpcmd, "' 2>/dev/null");
-#else
-    sv_setpv(tmpcmd, "echo ");
-    sv_catsv(tmpcmd, tmpglob);
-#if 'z' - 'a' == 25
-    sv_catpv(tmpcmd, " |tr -s ' \t\f\r' '\\012\\012\\012\\012'");
-#else
-    sv_catpv(tmpcmd, " |tr -s ' \t\f\r' '\\n\\n\\n\\n'");
-#endif
-#endif /* !CSH */
-#endif /* !DOSISH */
-#endif /* MACOS_TRADITIONAL */
-    (void)do_openn(gv, "-|", 2,
-		   FALSE, O_RDONLY, 0, NULL, &tmpcmd, 1);
-    fp = IoIFP(io);
-#endif /* !VMS */
-    LEAVE;
-    return fp;
-}
-
 /*
  * Local variables:
  * c-indentation-style: bsd
