@@ -15,18 +15,18 @@ use warnings; # uses #3 and #4, since warnings uses Carp
 use Exporter (); # use #5
 
 our $VERSION   = "0.74";
-our @ISA       = @( qw(Exporter) );
-our @EXPORT_OK = @( qw( set_style set_style_standard add_callback
+our @ISA       = qw(Exporter);
+our @EXPORT_OK = qw( set_style set_style_standard add_callback
 		     concise_subref concise_cv concise_main
-		     add_style walk_output compile reset_sequence ) );
+		     add_style walk_output compile reset_sequence );
 our %EXPORT_TAGS =
-    %( io	=> \@(qw( walk_output compile reset_sequence )),
-      style	=> \@(qw( add_style set_style_standard )),
-      cb	=> \@(qw( add_callback )),
-      mech	=> \@(qw( concise_subref concise_cv concise_main )),  );
+    %( io	=> \qw( walk_output compile reset_sequence ),
+      style	=> \qw( add_style set_style_standard ),
+      cb	=> \qw( add_callback ),
+      mech	=> \qw( concise_subref concise_cv concise_main ),  );
 
 # use #6
-use B qw(class ppname main_start main_root main_cv cstring svref_2object
+use B < qw(class ppname main_start main_root main_cv cstring svref_2object
 	 SVf_IOK SVf_NOK SVf_POK SVf_IVisUV SVf_FAKE OPf_KIDS OPf_SPECIAL
 	 CVf_ANON PAD_FAKELEX_ANON PAD_FAKELEX_MULTI SVf_ROK);
 
@@ -94,7 +94,7 @@ sub add_style {
     die "style '$newstyle' already exists, choose a new name\n"
 	if exists %style{$newstyle};
     die "expecting 3 style-format args\n" unless (nelems @args) == 3;
-    %style{$newstyle} = \@(< @args);
+    %style{$newstyle} = \ @args;
     $stylename = $newstyle; # update rendering state
 }
 
@@ -151,7 +151,7 @@ sub concise_stashref {
 	my $codeobj = svref_2object($coderef);
 	next unless ref $codeobj eq 'B::CV';
 	try { concise_cv_obj($order, $codeobj, $k) };
-	warn "err {$@->message} on $codeobj" if $@;
+	warn "err {$@->message} on {dump::view($codeobj)}" if $@;
     }
 }
 
@@ -219,7 +219,7 @@ sub concise_specials {
     } elsif ($name eq "CHECK") {
 	pop @cv_s; # skip the CHECK block that calls us
     }
-    for my $cv (< @cv_s) {
+    for my $cv ( @cv_s) {
 	print $walkHandle "$name $i:\n";
 	$i++;
 	concise_cv_obj($order, $cv, $name);
@@ -232,8 +232,8 @@ my $end_sym   = "\e(B"; # "\cO" respectively
 my @tree_decorations =
   @(\@("  ", "--", "+-", "|-", "| ", "`-", "-", 1),
    \@(" ", "-", "+", "+", "|", "`", "", 0),
-   \@("  ", map("$start_sym$_$end_sym", "qq", "wq", "tq", "x ", "mq", "q"), 1),
-   \@(" ", map("$start_sym$_$end_sym", "q", "w", "t", "x", "m"), "", 0),
+   \@("  ", < map("$start_sym$_$end_sym", @( "qq", "wq", "tq", "x ", "mq", "q")), 1),
+   \@(" ", < map("$start_sym$_$end_sym", @( "q", "w", "t", "x", "m")), "", 0),
   );
 
 my @render_packs; # collect -stash=<packages>
@@ -242,10 +242,10 @@ sub compileOpts {
     # set rendering state from options and args
     my (@options,@args);
     if ((nelems @_)) {
-	@options = @( grep { (! ref) && m/^-/ } < @_ );
-	@args = @( grep { (ref $_) || !m/^-/ } < @_ );
+	@options = grep { (! ref) && m/^-/ } @_;
+	@args = grep { (ref $_) || !m/^-/ } @_;
     }
-    for my $o (< @options) {
+    for my $o ( @options) {
 	# mode/order
 	if ($o eq "-basic") {
 	    $order = "basic";
@@ -303,12 +303,12 @@ sub compileOpts {
 }
 
 sub compile {
-    my @args = @( < compileOpts(< @_) );
+    my @args = compileOpts(< @_);
     return sub {
-	my @newargs = @( < compileOpts(< @_) ); # accept new rendering options
-	warn "disregarding non-options: {join ' ', <@newargs}\n" if (nelems @newargs);
+	my @newargs = compileOpts(< @_); # accept new rendering options
+	warn "disregarding non-options: {join ' ',@newargs}\n" if (nelems @newargs);
 
-	for (< @args) {
+	for ( @args) {
             my $objname = $_;
 	    next unless $objname; # skip null args to avoid noisy responses
 
@@ -354,7 +354,7 @@ sub compile {
 		concise_subref($order, $objref, $objname);
 	    }
 	}
-	for my $pkg (< @render_packs) {
+	for my $pkg ( @render_packs) {
 	    no strict 'refs';
 	    concise_stashref($order, \%{Symbol::stash($pkg)});
 	}
@@ -375,7 +375,7 @@ my %opclass = %('OP' => "0", 'UNOP' => "1", 'BINOP' => "2", 'LOGOP' => "|",
 	       'PVOP' => '"', 'LOOP' => "\{", 'COP' => ";", 'PADOP' => "#");
 
 no warnings 'qw'; # "Possible attempt to put comments..."; use #7
-my @linenoise = @(
+my @linenoise =
   qw'#  () sc (  @? 1  $* gv *{ m$ m@ m% m? p/ *$ $  $# & a& pt \\ s\\ rf bl
      `  *? <> ?? ?/ r/ c/ // qr s/ /c y/ =  @= C  sC Cp sp df un BM po +1 +I
      -1 -I 1+ I+ 1- I- ** *  i* /  i/ %$ i% x  +  i+ -  i- .  "  << >> <  i<
@@ -390,7 +390,7 @@ my @linenoise = @(
      co cr u. cm ut r. l@ s@ r@ mD uD oD rD tD sD wD cD f$ w$ p$ sh e$ k$ g3
      g4 s4 g5 s5 T@ C@ L@ G@ A@ S@ Hg Hc Hr Hw Mg Mc Ms Mr Sg Sc So rq do {e
      e} {t t} g6 G6 6e g7 G7 7e g8 G8 8e g9 G9 9e 6s 7s 8s 9s 6E 7E 8E 9E Pn
-     Pu GP SP EP Gn Gg GG SG EG g0 c$ lk t$ ;s n> // /= CO' );
+     Pu GP SP EP Gn Gg GG SG EG g0 c$ lk t$ ;s n> // /= CO';
 
 my $chars = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ";
 
@@ -406,7 +406,7 @@ sub op_flags { # common flags (see BASOP.op_flags in op.h)
     push @v, "M" if $x ^&^ 32;
     push @v, "S" if $x ^&^ 64;
     push @v, "*" if $x ^&^ 128;
-    return join("", < @v);
+    return join("", @v);
 }
 
 sub base_n {
@@ -454,7 +454,7 @@ sub walk_topdown {
 
 sub walklines {
     my($ar, $level) = < @_;
-    for my $l (< @$ar) {
+    for my $l ( @$ar) {
 	if (ref($l) eq "ARRAY") {
 	    walklines($l, $level + 1);
 	} else {
@@ -530,7 +530,7 @@ sub sequence {
 sub fmt_line {    # generate text-line for op.
     my($hr, $op, $text, $level) = < @_;
 
-    $_->($hr, $op, \$text, \$level, $stylename) for < @callbacks;
+    $_->($hr, $op, \$text, \$level, $stylename) for  @callbacks;
 
     return '' if $hr->{SKIP};	# suppress line if a callback said so
     return '' if $hr->{goto} and $hr->{goto} eq '-';	# no goto nowhere
@@ -568,32 +568,32 @@ sub fmt_line {    # generate text-line for op.
 our %priv; # used to display each opcode's BASEOP.op_private values
 
 %priv{$_}->{128} = "LVINTRO"
-  for ("pos", "substr", "vec", "threadsv", "gvsv", "rv2sv", "rv2hv", "rv2gv",
+  for @( ("pos", "substr", "vec", "threadsv", "gvsv", "rv2sv", "rv2hv", "rv2gv",
        "rv2av", "aelem", "helem", "aslice", "hslice", "padsv",
-       "padav", "padhv", "enteriter");
-%priv{$_}->{64} = "REFC" for ("leave", "leavesub", "leavesublv", "leavewrite");
+       "padav", "padhv", "enteriter"));
+%priv{$_}->{64} = "REFC" for @( ("leave", "leavesub", "leavesublv", "leavewrite"));
 %priv{"aassign"}->{64} = "COMMON";
 %priv{"aassign"}->{32} = "STATE";
 %priv{"sassign"}->{32} = "STATE";
 %priv{"sassign"}->{64} = "BKWARD";
-%priv{$_}->{64} = "RTIME" for ("match", "subst", "substcont", "qr");
-%{%priv{"trans"}}{[1,2,4,8,16,64]} = ("<UTF", ">UTF", "IDENT", "SQUASH", "DEL",
+%priv{$_}->{64} = "RTIME" for @( ("match", "subst", "substcont", "qr"));
+ <%{%priv{"trans"}}{[@(1,2,4,8,16,64)]} = ("<UTF", ">UTF", "IDENT", "SQUASH", "DEL",
 				    "COMPL", "GROWS");
 %priv{"repeat"}->{64} = "DOLIST";
 %priv{"leaveloop"}->{64} = "CONT";
-%{%priv{$_}}{[32,64,96]} = ("DREFAV", "DREFHV", "DREFSV")
-  for (qw(rv2gv rv2sv padsv aelem helem));
-%priv{$_}->{16} = "STATE" for ("padav", "padhv", "padsv");
-%{%priv{"entersub"}}{[16,32,64]} = ("DBG","TARG","NOMOD");
-%{%priv{$_}}{[4,8,128]} = ("INARGS","AMPER","NO()") for ("entersub", "rv2cv");
+ <%{%priv{$_}}{[@(32,64,96)]} = ("DREFAV", "DREFHV", "DREFSV")
+  for @( ( <qw(rv2gv rv2sv padsv aelem helem)));
+%priv{$_}->{16} = "STATE" for @( ("padav", "padhv", "padsv"));
+ <%{%priv{"entersub"}}{[@(16,32,64)]} = ("DBG","TARG","NOMOD");
+ <%{%priv{$_}}{[@(4,8,128)]} = ("INARGS","AMPER","NO()") for @( ("entersub", "rv2cv"));
 %priv{"gv"}->{32} = "EARLYCV";
 %priv{"aelem"}->{16} = %priv{"helem"}->{16} = "LVDEFER";
-%priv{$_}->{16} = "OURINTR" for ("gvsv", "rv2sv", "rv2av", "rv2hv", "r2gv",
-	"enteriter");
+%priv{$_}->{16} = "OURINTR" for @( ("gvsv", "rv2sv", "rv2av", "rv2hv", "r2gv",
+	"enteriter"));
 %priv{$_}->{16} = "TARGMY"
-  for (map(($_,"s$_"),"chop", "chomp"),
-       map(($_,"i_$_"), "postinc", "postdec", "multiply", "divide", "modulo",
-	   "add", "subtract", "negate"), "pow", "concat", "stringify",
+  for @( (< map(($_,"s$_"), @("chop", "chomp")),
+       < map(($_,"i_$_"), @( "postinc", "postdec", "multiply", "divide", "modulo",
+	   "add", "subtract", "negate")), "pow", "concat", "stringify",
        "left_shift", "right_shift", "bit_and", "bit_xor", "bit_or",
        "complement", "atan2", "sin", "cos", "rand", "exp", "log", "sqrt",
        "int", "hex", "oct", "abs", "length", "index", "rindex", "sprintf",
@@ -601,48 +601,48 @@ our %priv; # used to display each opcode's BASEOP.op_private values
        "chdir", "chown", "chroot", "unlink", "chmod", "utime", "rename",
        "link", "symlink", "mkdir", "rmdir", "wait", "waitpid", "system",
        "exec", "kill", "getppid", "getpgrp", "setpgrp", "getpriority",
-       "setpriority", "time", "sleep");
-%priv{$_}->{4} = "REVERSED" for ("enteriter", "iter");
-%{%priv{"const"}}{[4,8,16,32,64,128]} = ("SHORT","STRICT","ENTERED",'$[',"BARE","WARN");
+       "setpriority", "time", "sleep"));
+%priv{$_}->{4} = "REVERSED" for @( ("enteriter", "iter"));
+ <%{%priv{"const"}}{[@(4,8,16,32,64,128)]} = ("SHORT","STRICT","ENTERED",'$[',"BARE","WARN");
 %priv{"flip"}->{64} = %priv{"flop"}->{64} = "LINENUM";
 %priv{"list"}->{64} = "GUESSED";
 %priv{"delete"}->{64} = "SLICE";
 %priv{"exists"}->{64} = "SUB";
-%{%priv{"sort"}}{[1,2,4,8,16,32,64]} = ("NUM", "INT", "REV", "INPLACE","DESC","QSORT","STABLE");
+ <%{%priv{"sort"}}{[@(1,2,4,8,16,32,64)]} = ("NUM", "INT", "REV", "INPLACE","DESC","QSORT","STABLE");
 %priv{"threadsv"}->{64} = "SVREFd";
-%{%priv{$_}}{[16,32,64,128]} = ("INBIN","INCR","OUTBIN","OUTCR")
-  for ("open", "backtick");
+ <%{%priv{$_}}{[@(16,32,64,128)]} = ("INBIN","INCR","OUTBIN","OUTCR")
+  for @( ("open", "backtick"));
 %priv{"exit"}->{128} = "VMS";
 %priv{$_}->{2} = "FTACCESS"
-  for ("ftrread", "ftrwrite", "ftrexec", "fteread", "ftewrite", "fteexec");
+  for @( ("ftrread", "ftrwrite", "ftrexec", "fteread", "ftewrite", "fteexec"));
 %priv{"entereval"}->{2} = "HAS_HH";
 {
   # Stacked filetests are post 5.8.x
   %priv{$_}->{4} = "FTSTACKED"
-    for ("ftrread", "ftrwrite", "ftrexec", "fteread", "ftewrite", "fteexec",
+    for @( ("ftrread", "ftrwrite", "ftrexec", "fteread", "ftewrite", "fteexec",
          "ftis", "fteowned", "ftrowned", "ftzero", "ftsize", "ftmtime",
 	 "ftatime", "ftctime", "ftsock", "ftchr", "ftblk", "ftfile", "ftdir",
 	 "ftpipe", "ftlink", "ftsuid", "ftsgid", "ftsvtx", "fttty", "fttext",
-	 "ftbinary");
+	 "ftbinary"));
   # Lexical $_ is post 5.8.x
   %priv{$_}->{2} = "GREPLEX"
-    for ("mapwhile", "mapstart", "grepwhile", "grepstart");
+    for @( ("mapwhile", "mapstart", "grepwhile", "grepstart"));
 }
 
 our %hints; # used to display each COP's op_hints values
-
+ <
 # strict refs, subs, vars
-%hints{[2,512,1024]} = ('$', '&', '*');
-# integers, locale, bytes
-%hints{[1,4,8,16]} = ('i', 'l', 'b');
-# block scope, localise %^H, $^OPEN (in), $^OPEN (out)
-%hints{[256,131072,262144,524288]} = ('{','%','<','>');
-# overload new integer, float, binary, string, re
-%hints{[4096,8192,16384,32768,65536]} = ('I', 'F', 'B', 'S', 'R');
-# taint and eval
-%hints{[1048576,2097152]} = ('T', 'E');
-# filetest access, UTF-8
-%hints{[4194304,8388608]} = ('X', 'U');
+%hints{[@(2,512,1024)]} = ('$', '&', '*');
+ <# integers, locale, bytes
+%hints{[@(1,4,8,16)]} = ('i', 'l', 'b');
+ <# block scope, localise %^H, $^OPEN (in), $^OPEN (out)
+%hints{[@(256,131072,262144,524288)]} = ('{','%','<','>');
+ <# overload new integer, float, binary, string, re
+%hints{[@(4096,8192,16384,32768,65536)]} = ('I', 'F', 'B', 'S', 'R');
+ <# taint and eval
+%hints{[@(1048576,2097152)]} = ('T', 'E');
+ <# filetest access, UTF-8
+%hints{[@(4194304,8388608)]} = ('X', 'U');
 
 sub _flags {
     my($hash, $x) = < @_;
@@ -654,7 +654,7 @@ sub _flags {
 	}
     }
     push @s, $x if $x;
-    return join(",", < @s);
+    return join(",", @s);
 }
 
 sub private_flags {
@@ -745,7 +745,7 @@ sub concise_op {
 	    %h{targarglife} = %h{targarg} = "%h{targ} $refs";
 	}
     } elsif (%h{targ}) {
-	my $padname = ( <( <$curcv->PADLIST->ARRAY)[[0]]->ARRAY)[[%h{targ}]];
+	my $padname = (($curcv->PADLIST->ARRAY)[0]->ARRAY)[%h{targ}];
 	if (defined $padname and class($padname) ne "SPECIAL") {
 	    %h{targarg}  = $padname->PVX;
 	    if ($padname->FLAGS ^&^ SVf_FAKE) {
@@ -795,7 +795,7 @@ sub concise_op {
 	} elsif ($ {$op->pmreplstart}) {
 	    undef $lastnext;
 	    $pmreplstart = "replstart->" . seq($op->pmreplstart);
-	    %h{arg} = "(" . join(" ", $precomp, $pmreplstart) . ")";
+	    %h{arg} = "(" . join(" ", @( $precomp, $pmreplstart)) . ")";
 	} else {
 	    %h{arg} = "($precomp)";
 	}
@@ -806,10 +806,10 @@ sub concise_op {
 	my $label = $op->label;
 	%h{coplabel} = $label;
 	$label = $label ? "$label: " : "";
-	my $loc = $op->file;
+	my $loc = $op->location ? $op->location[0] : '<unknown>';
 	my $pathnm = $loc;
 	$loc =~ s[.*/][];
-	my $ln = $op->line;
+	my $ln = $op->location ? $op->location[1] : '-1';
 	$loc .= ":$ln";
 	my($stash, $cseq) = ($op->stash->NAME, $op->cop_seq - $cop_seq_base);
 	%h{arg} = "($label$stash $cseq $loc)";
@@ -830,7 +830,7 @@ sub concise_op {
 	    my $idx = (%h{class} eq "SVOP") ? $op->targ : $op->padix;
 	    my $preferpv = %h{name} eq "method_named";
 	    if (%h{class} eq "PADOP" or !${$op->sv}) {
-		my $sv = ( <( <$curcv->PADLIST->ARRAY)[[1]]->ARRAY)[[$idx]];
+		my $sv = $curcv->PADLIST->ARRAY[1]->ARRAY[$idx];
 		%h{arg} = "[" . concise_sv($sv, \%h, $preferpv) . "]";
 		%h{targarglife} = %h{targarg} = "";
 	    } else {
@@ -939,7 +939,7 @@ sub tree {
 	@lines[0] = $single . @lines[0];
     }
     return @("$name$lead" . shift @lines,
-           map(" " x (length($name)+$size) . $_, < @lines));
+           < map(" " x (length($name)+$size) . $_, @lines));
 }
 
 # *** Warning: fragile kludge ahead ***
