@@ -2,21 +2,21 @@ package OptreeCheck;
 use base 'Exporter';
 use strict;
 use warnings;
-use vars qw($TODO $Level $using_open);
+use vars < qw($TODO $Level $using_open);
 require "./test.pl";
 
 our $VERSION = '0.02';
 
 # now export checkOptree, and those test.pl functions used by tests
-our @EXPORT = @( qw( checkOptree plan skip skip_all pass is like unlike
-		  require_ok runperl) );
+our @EXPORT = qw( checkOptree plan skip skip_all pass is like unlike
+		  require_ok runperl);
 
 
 # The hints flags will differ if $^OPEN is set.
 # The approach taken is to put the hints-with-open in the golden results, and
 # flag that they need to be taken out if $^OPEN is set.
 
-if (((caller 0)[[10]]||\%())->{'open<'}) {
+if ((@(caller 0)[10]||\%())->{'open<'}) {
     $using_open = 1;
 }
 
@@ -289,7 +289,7 @@ report={diag,fail,print}.
 
 use Config;
 use Carp;
-use B::Concise qw(walk_output);
+use B::Concise < qw(walk_output);
 
 BEGIN {
     $^WARN_HOOK = sub {
@@ -323,10 +323,10 @@ our %gOpts = 	# values are replaced at runtime !!
      # array values are one-of selections, with 1st value as default
      #  array: 2nd value is used as help-str, 1st val (still) default
      help	=> \@(0, 'provides help and exits', 0),
-     testmode	=> \@(qw/ native cross both /),
+     testmode	=> \qw/ native cross both /,
 
      # reporting mode for rendering errs
-     report	=> \@(qw/ diag fail print /),
+     report	=> \qw/ diag fail print /,
      errcont	=> \@(1, 'if 1, tests match even if report is fail', 0),
 
      # fixup for VMS, cygwin, which dont have stderr b4 stdout
@@ -380,7 +380,7 @@ sub getCmdLine {	# import assistant
 	     turn on a flag by typing its name,
 	     select a value from list by typing name=val.\n    }, <
 	  mydumper(\%gOpts))
-	if grep m/help/, < @ARGV;
+	if grep m/help/, @ARGV;
 
     # replace values for each key !! MUST MARK UP %gOpts
     foreach my $opt (keys %gOpts) {
@@ -394,10 +394,10 @@ sub getCmdLine {	# import assistant
 	    # uhh this WORKS. but it's inscrutable
 	    # grep s/$opt=(\w+)/grep {$_ eq $1} @ARGV and $gOpts{$opt}=$1/e, @ARGV;
 	    my $tval;  # temp
-	    if (grep s/$opt=(\w+)/{$tval=$1}/, < @ARGV) {
+	    if (grep s/$opt=(\w+)/{$tval=$1}/, @ARGV) {
 		# check val before accepting
-		my @allowed = @( < @{%gOpts{$opt}} );
-		if (grep { $_ eq $tval } < @allowed) {
+		my @allowed = @{%gOpts{$opt}};
+		if (grep { $_ eq $tval } @allowed) {
 		    %gOpts{$opt} = $tval;
 		}
 		else {die "invalid value: '$tval' for $opt\n"}
@@ -410,10 +410,10 @@ sub getCmdLine {	# import assistant
         else { # handle scalars
 
 	    # if 'opt' is present, true
-	    %gOpts{$opt} = (grep m/^$opt/, < @ARGV) ? 1 : 0;
+	    %gOpts{$opt} = (grep m/^$opt/, @ARGV) ? 1 : 0;
 
 	    # override with 'foo' if 'opt=foo' appears
-	    grep s/$opt=(.*)/{%gOpts{$opt}=$1}/, < @ARGV;
+	    grep s/$opt=(.*)/{%gOpts{$opt}=$1}/, @ARGV;
 	}
      }
     print("$0 heres current state:\n", < mydumper(\%gOpts))
@@ -441,7 +441,7 @@ sub checkOptree {
 
 	local $Level = $Level + 2;
       TODO:
-	foreach my $want (< @{%modes{%gOpts{testmode}}}) {
+	foreach my $want ( @{%modes{%gOpts{testmode}}}) {
 	    local $TODO = $tc->{todo} if $tc->{todo};
 
 	    $tc->{cross} = %msgs{"$want-$thrstat"};
@@ -473,7 +473,7 @@ sub newTestCases {
 	}
 	elsif (ref $tc->{errs} eq 'ARRAY') {
 	    my %errs;
-	    %errs{[< @{$tc->{errs}}]} = (1) x nelems @{$tc->{errs}};
+ <	    %errs{[ @{$tc->{errs}}]} = (1) x nelems @{$tc->{errs}};
 	    $tc->{errs} = \%errs;
 	}
 	elsif (ref $tc->{errs} eq 'Regexp') {
@@ -489,7 +489,7 @@ sub label {
     return $tc->{name} if $tc->{name};
 
     my $buf = (ref $tc->{bcopts}) 
-	? join(',', < @{$tc->{bcopts}}) : $tc->{bcopts};
+	? join(',', @{$tc->{bcopts}}) : $tc->{bcopts};
 
     foreach (qw( note prog code )) {
 	$buf .= " $_: $tc->{$_}" if $tc->{$_} and not ref $tc->{$_};
@@ -505,17 +505,17 @@ sub getRendering {
     fail("getRendering: code or prog is required")
 	unless $tc->{code} or $tc->{prog} or $tc->{Dx};
 
-    my @opts = @( < get_bcopts($tc) );
+    my @opts = get_bcopts($tc);
     my $rendering = ''; # suppress "Use of uninitialized value in open"
     my @errs;		# collect errs via 
 
     if ($tc->{Dx}) {
-	$rendering = runperl( switches => \@('-w',join(',',"-Dx",< @opts)),
+	$rendering = runperl( switches => \@('-w',join(',', @("-Dx",< @opts))),
 			      prog => $tc->{Dx}, stderr => 1,
 			      ); # verbose => 1);
     }
     elsif ($tc->{prog}) {
-	$rendering = runperl( switches => \@('-w',join(',',"-MO=Concise",< @opts)),
+	$rendering = runperl( switches => \@('-w',join(',', @("-MO=Concise",< @opts))),
 			      prog => $tc->{prog}, stderr => 1,
 			      ); # verbose => 1);
     } 
@@ -584,12 +584,12 @@ sub checkErrs {
     # check for agreement, by hash (order less important)
     my (%goterrs, @got);
     $tc->{goterrs} ||= \@();
-    %goterrs{[< @{$tc->{goterrs}}]} = (1) x scalar nelems @{$tc->{goterrs}};
+ <    %goterrs{[ @{$tc->{goterrs}}]} = (1) x scalar nelems @{$tc->{goterrs}};
     
     foreach my $k (keys %{$tc->{errs} ||= \%()}) {
-	if (@got = @( grep m/^$k$/, keys %goterrs )) {
+	if (@got = grep m/^$k$/, keys %goterrs) {
 	    delete $tc->{errs}->{$k};
-	    delete %goterrs{$_} foreach < @got;
+	    delete %goterrs{$_} foreach  @got;
 	}
     }
     $tc->{goterrs} = \%goterrs;
@@ -606,12 +606,12 @@ sub diag_or_fail {
     my $tc = shift;
 
     my @lines;
-    push @lines, "got unexpected:", sort keys %{$tc->{goterrs}} if %{$tc->{goterrs}};
-    push @lines, "missed expected:", sort keys %{$tc->{errs}}   if %{$tc->{errs}};
+    push @lines, "got unexpected:", < sort keys %{$tc->{goterrs}} if %{$tc->{goterrs}};
+    push @lines, "missed expected:", < sort keys %{$tc->{errs}}   if %{$tc->{errs}};
 
     if ((nelems @lines)) {
 	unshift @lines, $tc->{name};
-	my $report = join("\n", < @lines);
+	my $report = join("\n", @lines);
 
 	if    (%gOpts{report} eq 'diag')	{ _diag ($report) }
 	elsif (%gOpts{report} eq 'fail')	{ fail  ($report) }
@@ -777,14 +777,14 @@ sub reduceDiffs {
 
     my $tc	= shift;
     my $got	= $tc->{got};
-    my @got	= @( split(m/\n/, $got) );
+    my @got	= split(m/\n/, $got);
     my $want	= $tc->{wantstr};
-    my @want	= @( split(m/\n/, $want) );
+    my @want	= split(m/\n/, $want);
 
     # split rexstr into units that should eat leading lines.
-    my @rexs = @( map qr/$_/, split (m/\n/, $tc->{rexstr}) );
+    my @rexs = map qr/$_/, split (m/\n/, $tc->{rexstr});
 
-    foreach my $rex (< @rexs) {
+    foreach my $rex ( @rexs) {
         my $exp = shift @want;
         my $line = shift @got;
         # remove matches, and report
@@ -911,7 +911,7 @@ sub mydumper {
 	or do{
 	    print "Sorry, Data::Dumper is not available\n";
 	    print "half hearted attempt:\n";
-	    foreach my $it (< @_) {
+	    foreach my $it ( @_) {
 		if (ref $it eq 'HASH') {
 		    print " $_ => $it->{$_}\n" foreach sort keys %$it;
 		}
@@ -1002,17 +1002,17 @@ sub OptreeCheck::gentest {
 
 
 sub OptreeCheck::processExamples {
-    my @files = @( < @_ );
+    my @files = @_;
 
     # gets array of paragraphs, which should be code-samples.  Theyre
     # turned into optreeCheck tests,
 
-    foreach my $file (< @files) {
+    foreach my $file ( @files) {
 	open (my $fh, "<", $file) or die "cant open $file: $!\n";
 	$/ = "";
 	my @chunks = @( ~< $fh );
 	print < preamble (scalar nelems @chunks);
-	foreach my $t (< @chunks) {
+	foreach my $t ( @chunks) {
 	    print "\n\n=for gentest\n\n# chunk: $t=cut\n\n";
 	    print < OptreeCheck::gentest ($t);
 	}
