@@ -15,9 +15,9 @@ sub import {
     warnings::warnif('deprecated', qq{Parameterless "use IO" deprecated})
         if (nelems @_) == 0 ;
     
-    my @l = @( (nelems @_) ? < @_ : qw(Handle Seekable File Socket Dir) );
+    my @l = @( (nelems @_) ? < @_ : < qw(Handle Seekable File Socket Dir) );
 
-    eval join("", map { "require IO::" . @(m/(\w+)/)[0] . ";\n" } < @l)
+    eval join("", map { "require IO::" . @(m/(\w+)/)[0] . ";\n" } @l)
 	or die $@;
 }
 
