@@ -99,11 +99,11 @@ our($VERSION, @EXPORT, @ISA);
 use IO::Handle ();
 # XXX we can't get these from IO::Handle or we'll get prototype
 # mismatch warnings on C<use POSIX; use IO::File;> :-(
-use Fcntl qw(SEEK_SET SEEK_CUR SEEK_END);
+use Fcntl < qw(SEEK_SET SEEK_CUR SEEK_END);
 require Exporter;
 
-@EXPORT = @( qw(SEEK_SET SEEK_CUR SEEK_END) );
-@ISA = @( qw(Exporter) );
+@EXPORT = qw(SEEK_SET SEEK_CUR SEEK_END);
+@ISA = qw(Exporter);
 
 $VERSION = "1.10";
 $VERSION = eval $VERSION;
