@@ -17,14 +17,11 @@ use Errno;
 
 # legacy
 
-require IO::Socket::INET;
-require IO::Socket::UNIX if ($^O ne 'epoc' && $^O ne 'symbian');
-
-@ISA = @( qw(IO::Handle) );
+@ISA = qw(IO::Handle);
 
 $VERSION = "1.30_01";
 
-@EXPORT_OK = @( qw(sockatmark) );
+@EXPORT_OK = qw(sockatmark);
 
 sub import {
     my $pkg = shift;
