@@ -5,18 +5,17 @@ use warnings;
 use bytes;
 
 use Carp;
-use Scalar::Util qw(blessed readonly);
+use Scalar::Util < qw(blessed readonly);
 use File::GlobMapper;
 
 require Exporter;
 our ($VERSION, @ISA, @EXPORT, %EXPORT_TAGS, $HAS_ENCODE);
-@ISA = @( qw(Exporter) );
+@ISA = qw(Exporter);
 $VERSION = '2.006';
 
-@EXPORT = @( qw( isaFilehandle isaFilename whatIsInput whatIsOutput 
+@EXPORT = qw( isaFilehandle isaFilename whatIsInput whatIsOutput 
               isaFileGlobString cleanFileGlobString oneTarget
-              setBinModeInput setBinModeOutput
-              ckInOutParams 
+              setBinModeInput
               createSelfTiedObject
               getEncoding
 
@@ -29,13 +28,13 @@ $VERSION = '2.006';
               STATUS_ENDSTREAM
               STATUS_EOF
               STATUS_ERROR
-          ) );  
+          );  
 
-%EXPORT_TAGS = %( Status => \@(qw( STATUS_OK
+%EXPORT_TAGS = %( Status => \qw( STATUS_OK
                                  STATUS_ENDSTREAM
                                  STATUS_EOF
                                  STATUS_ERROR
-                           )));
+                           ));
 
                        
 use constant STATUS_OK        => 0;
@@ -256,7 +255,7 @@ sub Validator::new
     if ($inType eq 'fileglob') # && $outType ne 'fileglob'
     {
         my $glob = cleanFileGlobString(@_[0]);
-        my @inputs = glob@( <$glob);
+        my @inputs = glob$glob;
 
         if ((nelems @inputs) == 0)
         {
@@ -275,7 +274,7 @@ sub Validator::new
         {
             $obj->validateInputFilenames(< @inputs)
                 or return undef;
-            @_[0] = \@( < @inputs ) ;
+            @_[0] = \ @inputs ;
             %data{inType} = 'filenames' ;
         }
     }
@@ -332,7 +331,7 @@ sub Validator::validateInputFilenames
 {
     my $self = shift ;
 
-    foreach my $filename (< @_)
+    foreach my $filename ( @_)
     {
         $self->croakError("$self->{reportClass}: input filename is undef or null string")
             if ! defined $filename || $filename eq ''  ;
@@ -367,7 +366,7 @@ sub Validator::validateInputArray
         return $self->saveErrorString("empty array reference") ;
     }    
 
-    foreach my $element ( < @{ @_[0] } )
+    foreach my $element (  @{ @_[0] } )
     {
         my $inType  = whatIsInput($element);
     
@@ -416,7 +415,7 @@ sub Validator::validateInputArray
 
 sub createSelfTiedObject
 {
-    my $class = shift || (caller)[[0]] ;
+    my $class = shift || die "called without a class";
     my $error_ref = shift ;
 
     my $obj = bless \%(), ref($class) || $class;
@@ -439,12 +438,11 @@ sub createSelfTiedObject
 #$VERSION = '2.000_08';
 #@ISA = qw(Exporter);
 
-%EXPORT_TAGS{Parse} = \@(qw( ParseParameters 
+%EXPORT_TAGS{Parse} = \qw( ParseParameters 
                            Parse_any Parse_unsigned Parse_signed 
                            Parse_boolean Parse_custom Parse_string
                            Parse_multiple Parse_writable_scalar
-                         )
-                      );              
+                         );              
 
 push @EXPORT, < @{ %EXPORT_TAGS{Parse} } ;
 
@@ -473,7 +471,7 @@ sub ParseParameters
 {
     my $level = shift || 0 ; 
 
-    my $sub = (caller($level + 1))[[3]] ;
+    my $sub = @(caller($level + 1))[3] ;
     local $Carp::CarpLevel = 1 ;
     my $p = IO::Compress::Base::Parameters->new() ;
     $p->parse(< @_)
@@ -557,7 +555,7 @@ sub IO::Compress::Base::Parameters::parse
 
     while (my ($key, $v) = each %$default)
     {
-        croak "need 4 params [{join ' ', <@$v}]"
+        croak "need 4 params [{join ' ',@$v}]"
             if (nelems @$v) != 4 ;
 
         my ($first_only, $sticky, $type, $value) = < @$v ;
@@ -616,8 +614,8 @@ sub IO::Compress::Base::Parameters::parse
     }
  
     if ((nelems @Bad)) {
-        my ($bad) = join(", ", < @Bad) ;
-        return $self->setError("unknown key value(s) {join ' ', <@Bad}") ;
+        my ($bad) = join(", ", @Bad) ;
+        return $self->setError("unknown key value(s) {join ' ',@Bad}") ;
     }
 
     return 1;
@@ -765,7 +763,7 @@ sub IO::Compress::Base::Parameters::clone
     my %got ;
 
     while (my ($k, $v) = each %{ $self->{Got} }) {
-        %got{$k} = \@( < @$v );
+        %got{$k} = \ @$v;
     }
 
     $obj->{Error} = $self->{Error};
@@ -823,7 +821,7 @@ sub reset
 sub clone
 {
     my $self = shift;
-    bless \@( < @$self ), ref $self ;
+    bless \ @$self, ref $self ;
 }
 
 sub getHigh
