@@ -4,9 +4,9 @@ use strict;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  v2.006 qw(:Status);
+use IO::Compress::Base::Common  v2.006 < qw(:Status);
 
-use Compress::Raw::Zlib  v2.006 qw(Z_OK Z_FINISH MAX_WBITS) ;
+use Compress::Raw::Zlib  v2.006 < qw(Z_OK Z_FINISH MAX_WBITS) ;
 our ($VERSION);
 
 $VERSION = '2.006';
