@@ -10,7 +10,7 @@ use IO::Compress::RawDeflate v2.006 ;
 
 use Compress::Raw::Zlib  v2.006 ;
 use IO::Compress::Zlib::Constants v2.006 ;
-use IO::Compress::Base::Common  v2.006 qw(createSelfTiedObject);
+use IO::Compress::Base::Common  v2.006 < qw(createSelfTiedObject);
 
 
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $DeflateError);
@@ -18,8 +18,8 @@ our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $DeflateError);
 $VERSION = '2.006';
 $DeflateError = '';
 
-@ISA    = @( qw(IO::Compress::RawDeflate Exporter) );
-@EXPORT_OK = @( qw( $DeflateError deflate ) ) ;
+@ISA    = qw(IO::Compress::RawDeflate Exporter);
+@EXPORT_OK = qw( $DeflateError deflate ) ;
 %EXPORT_TAGS = %( < %IO::Compress::RawDeflate::DEFLATE_CONSTANTS ) ;
 push @{ %EXPORT_TAGS{all} }, < @EXPORT_OK ;
 Exporter::export_ok_tags('all');
