@@ -5,7 +5,7 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common  v2.006 qw(:Status createSelfTiedObject);
+use IO::Compress::Base::Common  v2.006 < qw(:Status createSelfTiedObject);
 use IO::Compress::Zlib::Constants v2.006 ;
 
 use IO::Uncompress::RawInflate  v2.006 ;
@@ -16,8 +16,8 @@ our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $InflateError);
 $VERSION = '2.006';
 $InflateError = '';
 
-@ISA    = @( qw( IO::Uncompress::RawInflate Exporter ) );
-@EXPORT_OK = @( qw( $InflateError inflate ) ) ;
+@ISA    = qw( IO::Uncompress::RawInflate Exporter );
+@EXPORT_OK = qw( $InflateError inflate ) ;
 %EXPORT_TAGS = %( < %IO::Uncompress::RawInflate::DEFLATE_CONSTANTS ) ;
 push @{ %EXPORT_TAGS{all} }, < @EXPORT_OK ;
 Exporter::export_ok_tags('all');
