@@ -10,5 +10,5 @@ sub hashes {
 print < form
 	\%(field=>\@(qr/(#+)/=>\&hashes)),
 	"[###|###############################]",
-	\@(1,2,3), \@(qw[First Second Last]);
+	\@(1,2,3), \qw[First Second Last];
 
