@@ -3,15 +3,15 @@ use Perl6::Form;
 my $bullet = "<>";
 
 my @items = @( ~< *DATA );
-s/\\n/\n/g for < @items;
-s/\\r/\r/g for < @items;
+s/\\n/\n/g for  @items;
+s/\\r/\r/g for  @items;
 
 print < form
 	\%(bullet=>'<>'),
 	 "<> \{:[[[[[[[[[[[[[[[[[[:\}    <> \{:[[[[[[[[[[[[[[[[[[:\}",
 		 \@items,                     \@items;
 
-my $items = join "", < @items;
+my $items = join "", @items;
 
 print < form
 	 "-----------------------",
