@@ -1,5 +1,5 @@
 use Perl6::Form;
 
-print form
+print < form
 	'A left-justified field look like this: \{[[[[[[[[[[[}',
 	'The escape character for formats is: \';
