@@ -9,6 +9,6 @@ print < form
 
 
 sub farsi {
-	\@( map { m/(-?)(\d+)(?:\.(\d\d))?/; $1.($3||0).".".$2 } < @_ );
+	\ map { m/(-?)(\d+)(?:\.(\d\d))?/; $1.($3||0).".".$2 } @_;
 }
 
