@@ -2,8 +2,8 @@ use Perl6::Form;
 
 my @data = @( ~< *DATA );
 
-for (< @data) {
-	my ($pid, $cmd, $time, $cpu) = split;
+for ( @data) {
+	my ($pid, $cmd, $time, $cpu) = < split;
 	$cmd =~ s/_/ /g;
 	print < form
 		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{>>>>>>\}  \{>>.\}\%",
@@ -12,8 +12,8 @@ for (< @data) {
 
 print "---------------------------------------------\n";
 
-for (< @data) {
-	my ($pid, $cmd, $time, $cpu) = split;
+for ( @data) {
+	my ($pid, $cmd, $time, $cpu) = < split;
 	$cmd =~ s/_/ /g;
 	print < form
 		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]]\}   \{>\{5.2\}.<\%\}",
@@ -22,8 +22,8 @@ for (< @data) {
 
 print "---------------------------------------------\n";
 
-for (< @data) {
-	my ($pid, $cmd, $time, $cpu) = split;
+for ( @data) {
+	my ($pid, $cmd, $time, $cpu) = < split;
 	$cmd =~ s/_/ /g;
 	print < form
 		 \%(single=>'%'),
@@ -33,8 +33,8 @@ for (< @data) {
 
 print "---------------------------------------------\n";
 
-for (< @data) {
-	my ($pid, $cmd, $time, $cpu) = split;
+for ( @data) {
+	my ($pid, $cmd, $time, $cpu) = < split;
 	$cmd =~ s/_/ /g;
 	print < form
 		 "\{>>>\}  \{<<<<<<<<<<<<<<\}  \{]]]]]+\}  \{>>.\}\%",
@@ -43,8 +43,8 @@ for (< @data) {
 
 print "---------------------------------------------\n";
 
-for (< @data) {
-	my ($pid, $cmd, $time, $cpu) = split;
+for ( @data) {
+	my ($pid, $cmd, $time, $cpu) = < split;
 	$cmd =~ s/_/ /g;
 	printf "\%5d  \%-16s  \%8s  \%5.1f\%\%\n",
 		  $pid,  $cmd,  $time, $cpu;
