@@ -1,8 +1,8 @@
 #!/usr/local/bin/perl -w
 use strict;
 
-use Hash::Util qw(lock_hash unlock_hash lock_keys);
-use Storable qw(nfreeze);
+use Hash::Util < qw(lock_hash unlock_hash lock_keys);
+use Storable < qw(nfreeze);
 
 # If this looks like a hack, it's probably because it is :-)
 sub uuencode_it {
@@ -81,7 +81,7 @@ uuencode_it (\%uhash, "Hash with utf8 flag but no utf8 keys");
 $utf8 = "Schlo\xdf" . chr 256;
 chop $utf8;
 my $a_circumflex = (ord ('A') == 193 ? "\x47" : "\xe5");
-%uhash = %(map {$_, $_} 'castle', "ch{$a_circumflex}teau", $utf8, "\x{57CE}");
+%uhash = %(< map {$_, $_} @( 'castle', "ch{$a_circumflex}teau", $utf8, "\x{57CE}"));
 
 uuencode_it (\%uhash, "Hash with utf8 keys");
 
