@@ -5,13 +5,13 @@ use strict;
 use warnings;
 
 our $VERSION     = "0.09";
-our @ISA         = @( qw(Exporter) );
-my @XS_FUNCTIONS = @( qw(regmust) );
-my %XS_FUNCTIONS = %( map { $_ => 1 } < @XS_FUNCTIONS );
-our @EXPORT_OK   = @(< @XS_FUNCTIONS,
+our @ISA         = qw(Exporter);
+my @XS_FUNCTIONS = qw(regmust);
+my %XS_FUNCTIONS = %( < map { $_ => 1 } @XS_FUNCTIONS );
+our @EXPORT_OK   = @(< @XS_FUNCTIONS, <
                     qw(is_regexp regexp_pattern
                        regname regnames regnames_count));
-our %EXPORT_OK = %( map { $_ => 1 } < @EXPORT_OK );
+our %EXPORT_OK = %( < map { $_ => 1 } @EXPORT_OK );
 
 # *** WARNING *** WARNING *** WARNING *** WARNING *** WARNING ***
 #
@@ -38,8 +38,8 @@ sub setcolor {
 
   my $terminal = Term::Cap->Tgetent(\%(OSPEED => 9600)); # Avoid warning.
   my $props = %ENV{PERL_RE_TC} || 'md,me,so,se,us,ue';
-  my @props = @( split m/,/, $props );
-  my $colors = join "\t", map {$terminal->Tputs($_,1)} < @props;
+  my @props = split m/,/, $props;
+  my $colors = join "\t", map {$terminal->Tputs($_,1)} @props;
 
   $colors =~ s/\0//g;
   %ENV{PERL_RE_COLORS} = $colors;
@@ -156,7 +156,7 @@ sub bits {
 	    re->export_to_level(2, 're', $s);
 	} else {
 	    warn("Unknown \"re\" subpragma '$s' (known ones are: "
-                 . join(', ', map {qq('$_')} 'debug', 'debugcolor', sort keys %bitmask)
+                 . join(', ', map {qq('$_')} @( 'debug', 'debugcolor', < sort keys %bitmask))
                  . ")");
 	}
     }
