@@ -43,10 +43,10 @@ with a volume name, a relative pathname should always begin with a
 use Symbol;
 
 sub new {
-    @_ +>= 1 && @_ +<= 2 or die 'usage: new DirHandle [DIRNAME]';
+    (nelems @_) +>= 1 && (nelems @_) +<= 2 or die 'usage: new DirHandle [DIRNAME]';
     my $class = shift;
     my $dh = gensym;
-    if (@_) {
+    if ((nelems @_)) {
 	DirHandle::open($dh, @_[0])
 	    or return undef;
     }
@@ -54,7 +54,7 @@ sub new {
 }
 
 sub DESTROY {
-    my ($dh) = @_;
+    my ($dh) = < @_;
     # Don't warn about already being closed as it may have been closed 
     # correctly, or maybe never opened at all.
     no warnings 'io';
@@ -62,26 +62,32 @@ sub DESTROY {
 }
 
 sub open {
-    @_ == 2 or die 'usage: $dh->open(DIRNAME)';
-    my ($dh, $dirname) = @_;
+    (nelems @_) == 2 or die 'usage: $dh->open(DIRNAME)';
+    my ($dh, $dirname) = < @_;
     opendir($dh, $dirname);
 }
 
 sub close {
-    @_ == 1 or die 'usage: $dh->close()';
-    my ($dh) = @_;
+    (nelems @_) == 1 or die 'usage: $dh->close()';
+    my ($dh) = < @_;
     closedir($dh);
 }
 
-sub read {
-    @_ == 1 or die 'usage: $dh->read()';
-    my ($dh) = @_;
-    readdir($dh);
+sub readdir {
+    (nelems @_) == 1 or die 'usage: $dh->read()';
+    my ($dh) = < @_;
+    return $( CORE::readdir($dh) );
+}
+
+sub readdirs {
+    (nelems @_) == 1 or die 'usage: $dh->read()';
+    my ($dh) = < @_;
+    return @( CORE::readdir($dh) ); # Force list context.
 }
 
 sub rewind {
-    @_ == 1 or die 'usage: $dh->rewind()';
-    my ($dh) = @_;
+    (nelems @_) == 1 or die 'usage: $dh->rewind()';
+    my ($dh) = < @_;
     rewinddir($dh);
 }
 
