@@ -27,12 +27,12 @@ No user-serviceable parts inside.
 
 sub _rebuild_cache {
     my ($pkg, $exports, $cache) = < @_;
-    s/^&// foreach < @$exports;
-    %{$cache}{[< @$exports]} = (1) x nelems @$exports;
+    s/^&// foreach  @$exports;
+ <    %{$cache}{[ @$exports]} = (1) x nelems @$exports;
     my $ok = \@{*{Symbol::fetch_glob("{$pkg}::EXPORT_OK")}};
     if ((nelems @$ok)) {
-	s/^&// foreach < @$ok;
-	%{$cache}{[< @$ok]} = (1) x nelems @$ok;
+	s/^&// foreach  @$ok;
+ <	%{$cache}{[ @$ok]} = (1) x nelems @$ok;
     }
 }
 
@@ -49,22 +49,22 @@ sub heavy_export {
 	    $cache_is_current = 1;
 	}
 
-	if (grep m{^[/!:]}, < @imports) {
+	if (grep m{^[/!:]}, @imports) {
 	    my $tagsref = \%{*{Symbol::fetch_glob("{$pkg}::EXPORT_TAGS")}};
 	    my $tagdata;
 	    my %imports;
 	    my($remove, $spec, @names, @allexports);
 	    # negated first item implies starting with default set:
 	    unshift @imports, ':DEFAULT' if @imports[0] =~ m/^!/;
-	    foreach $spec (< @imports){
+	    foreach $spec ( @imports){
 		$remove = $spec =~ s/^!//;
 
 		if ($spec =~ s/^://){
 		    if ($spec eq 'DEFAULT'){
-			@names = @( < @$exports );
+			@names = @$exports;
 		    }
 		    elsif ($tagdata = $tagsref->{$spec}) {
-			@names = @( < @$tagdata );
+			@names = @$tagdata;
 		    }
 		    else {
 			warn qq["$spec" is not defined in \%{$pkg}::EXPORT_TAGS];
@@ -74,35 +74,35 @@ sub heavy_export {
 		}
 		elsif ($spec =~ m:^/(.*)/$:){
 		    my $patn = $1;
-		    @allexports = @( keys %$export_cache ) unless (nelems @allexports); # only do keys once
-		    @names = @( grep(m/$patn/, < @allexports) ); # not anchored by default
+		    @allexports = keys %$export_cache unless (nelems @allexports); # only do keys once
+		    @names = grep(m/$patn/, @allexports); # not anchored by default
 		}
 		else {
 		    @names = @($spec); # is a normal symbol name
 		}
 
-		warn "Import ".($remove ? "del":"add").": {join ' ', <@names} "
+		warn "Import ".($remove ? "del":"add").": {join ' ',@names} "
 		    if $Exporter::Verbose;
 
 		if ($remove) {
-		   foreach $sym (< @names) { delete %imports{$sym} } 
+		   foreach $sym ( @names) { delete %imports{$sym} } 
 		}
-		else {
-		    %imports{[< @names]} = (1) x nelems @names;
+		else { <
+		    %imports{[ @names]} = (1) x nelems @names;
 		}
 	    }
-	    @imports = @( keys %imports );
+	    @imports = keys %imports;
 	}
 
         my @carp;
-	foreach $sym (< @imports) {
+	foreach $sym ( @imports) {
 	    if (!$export_cache->{$sym}) {
 		if ($sym =~ m/^\d/) {
 		    $pkg->VERSION($sym); # inherit from UNIVERSAL
 		    # If the version number was the only thing specified
 		    # then we should act as if nothing was specified:
 		    if ((nelems @imports) == 1) {
-			@imports = @( < @$exports );
+			@imports = @$exports;
 			last;
 		    }
 		    # We need a way to emulate 'use Foo ()' but still
@@ -131,11 +131,11 @@ sub heavy_export {
 	    }
 	}
 	if ($oops) {
-	    die("{join ' ', < @carp}Can't continue after import errors");
+	    die("{join ' ', @carp}Can't continue after import errors");
 	}
     }
     else {
-	@imports = @( < @$exports );
+	@imports = @$exports;
     }
 
     my($fail, $fail_cache) = (\@{*{Symbol::fetch_glob("{$pkg}::EXPORT_FAIL")}},
@@ -146,15 +146,15 @@ sub heavy_export {
 	    # Build cache of symbols. Optimise the lookup by adding
 	    # barewords twice... both with and without a leading &.
 	    # (Technique could be applied to $export_cache at cost of memory)
-	    my @expanded = @( map { m/^\w/ ? ($_, '&'.$_) : $_ } < @$fail );
-	    warn "{$pkg}::EXPORT_FAIL cached: {join ' ', <@expanded}" if $Exporter::Verbose;
-	    %{$fail_cache}{[< @expanded]} = (1) x nelems @expanded;
+	    my @expanded = map { m/^\w/ ? ($_, '&'.$_) : $_ } @$fail;
+	    warn "{$pkg}::EXPORT_FAIL cached: {join ' ',@expanded}" if $Exporter::Verbose;
+ <	    %{$fail_cache}{[ @expanded]} = (1) x nelems @expanded;
 	}
 	my @failed;
-	foreach $sym (< @imports) { push(@failed, $sym) if $fail_cache->{$sym} }
+	foreach $sym ( @imports) { push(@failed, $sym) if $fail_cache->{$sym} }
 	if ((nelems @failed)) {
-	    @failed = @( < $pkg->export_fail(< @failed) );
-	    foreach $sym (< @failed) {
+	    @failed = $pkg->export_fail(< @failed);
+	    foreach $sym ( @failed) {
 		warn(qq["$sym" is not implemented by the $pkg module ]
 			. "on this architecture");
 	    }
@@ -165,9 +165,9 @@ sub heavy_export {
     }
 
     warn "Importing into $callpkg from $pkg: ",
-		join(", ",sort < @imports) if $Exporter::Verbose;
+		join(", ",sort @imports) if $Exporter::Verbose;
 
-    foreach $sym (< @imports) {
+    foreach $sym ( @imports) {
 	# shortcut for the common case of no type character
 	(*{Symbol::fetch_glob("{$callpkg}::$sym")} = \&{*{Symbol::fetch_glob("{$pkg}::$sym")}}, next)
 	    unless $sym =~ s/^(\W)//;
@@ -198,12 +198,12 @@ sub _push_tags {
     my @nontag = @( () );
     my $export_tags = \%{*{Symbol::fetch_glob("{$pkg}::EXPORT_TAGS")}};
     push(@{*{Symbol::fetch_glob("{$pkg}::$var")}},
-	map { $export_tags->{$_} ? < @{$export_tags->{$_}} 
+	< map { $export_tags->{$_} ? < @{$export_tags->{$_}} 
                                  : do { push(@nontag,$_); $_ } }
-		(nelems @$syms) ? < @$syms : keys %$export_tags);
+ @(		(nelems @$syms) ? < @$syms : < keys %$export_tags));
     if ((nelems @nontag) and $^W) {
 	# This may change to a die one day
-	warn(join(", ", < @nontag)." are not tags of $pkg");
+	warn(join(", ", @nontag)." are not tags of $pkg");
     }
 }
 
@@ -214,11 +214,11 @@ sub heavy_require_version {
 }
 
 sub heavy_export_tags {
-  _push_tags((caller)[[0]], "EXPORT",    \@_);
+  _push_tags(@(caller)[0], "EXPORT",    \@_);
 }
 
 sub heavy_export_ok_tags {
-  _push_tags((caller)[[0]], "EXPORT_OK", \@_);
+  _push_tags(@(caller)[0], "EXPORT_OK", \@_);
 }
 
 1;
