@@ -4,10 +4,10 @@ use strict;
 use warnings;
 
 require Exporter;
-our @ISA = @( qw(Exporter) );
+our @ISA = qw(Exporter);
 
-our @EXPORT  = @( qw(test_harness pod2man perllocal_install uninstall 
-                  warn_if_old_packlist) );
+our @EXPORT  = qw(test_harness pod2man perllocal_install uninstall 
+                  warn_if_old_packlist);
 our $VERSION = '6.44';
 
 my $Is_VMS = $^O eq 'VMS';
@@ -53,11 +53,11 @@ sub test_harness {
     # Because Windows doesn't do this for us and listing all the *.t files
     # out on the command line can blow over its exec limit.
     require ExtUtils::Command;
-    my @argv = @( < ExtUtils::Command::expand_wildcards(< @ARGV) );
+    my @argv = ExtUtils::Command::expand_wildcards(< @ARGV);
 
-    local @INC = @( < @INC );
-    unshift @INC, map { File::Spec->rel2abs($_) } < @_;
-    Test::Harness::runtests(sort { lc $a cmp lc $b } < @argv);
+    local @INC = @INC;
+    unshift @INC, < map { File::Spec->rel2abs($_) } @_;
+    Test::Harness::runtests( <sort { lc $a cmp lc $b } @argv);
 }
 
 
@@ -192,7 +192,7 @@ sub perllocal_install {
 
     # VMS feeds args as a piped file on STDIN since it usually can't
     # fit all the args on a single command line.
-    my @mod_info = @( $Is_VMS ? split m/\|/, ~< *STDIN
+    my @mod_info = @( $Is_VMS ? < split m/\|/, ~< *STDIN
                            : < @ARGV );
 
     my $pod;
