@@ -1,10 +1,10 @@
 package ExtUtils::Constant::Utils;
 
 use strict;
-use vars qw($VERSION @EXPORT_OK @ISA);
+use vars < qw($VERSION @EXPORT_OK @ISA);
 
 @ISA = @( 'Exporter' );
-@EXPORT_OK = @( qw(C_stringify perl_stringify) );
+@EXPORT_OK = qw(C_stringify perl_stringify);
 $VERSION = '0.01';
 
 =head1 NAME
