@@ -1,13 +1,13 @@
 package ExtUtils::Constant::XS;
 
 use strict;
-use vars qw($VERSION %XS_Constant %XS_TypeSet @ISA @EXPORT_OK);
+use vars < qw($VERSION %XS_Constant %XS_TypeSet @ISA @EXPORT_OK);
 use ExtUtils::Constant::Utils 'perl_stringify';
 require ExtUtils::Constant::Base;
 
 
-@ISA = @( qw(ExtUtils::Constant::Base Exporter) );
-@EXPORT_OK = @( qw(%XS_Constant %XS_TypeSet) );
+@ISA = qw(ExtUtils::Constant::Base Exporter);
+@EXPORT_OK = qw(%XS_Constant %XS_TypeSet);
 
 $VERSION = '0.02';
 
@@ -74,7 +74,7 @@ sub header {
     push @lines, "#define PERL_constant_IS$_\t$start\n"; $start++;
   }
 
-  return join '', < @lines;
+  return join '', @lines;
 }
 
 sub valid_type {
@@ -91,7 +91,7 @@ sub assignment_clause_for_type {
   if (ref $typeset) {
     die "Type $type is aggregate, but only single value given"
       if (nelems @_) == 1;
-    return @( map {"$typeset->[$_]@_[$_];"} 0 .. ((nelems @$typeset)-1) );
+    return map {"$typeset->[$_]@_[$_];"} 0 .. ((nelems @$typeset)-1);
   } elsif (defined $typeset) {
     die "Aggregate value given for type $type"
       if (nelems @_) +> 1;
@@ -189,7 +189,7 @@ sub C_constant_other_params {
 
 sub dogfood {
   my ($self, $args, < @items) = < @_;
-  my ($package, $subname, $default_type, $what, $indent, $breakout) =
+  my ($package, $subname, $default_type, $what, $indent, $breakout) = <
     %{$args}{[qw(package subname default_type what indent breakout)]};
   my $result = <<"EOT";
   /* When generated this function returned values for the list of names given
