@@ -4,7 +4,7 @@ use strict;
 
 BEGIN {
     require ExtUtils::MM_Unix;
-    our @ISA = @( qw( ExtUtils::MM_Unix ) );
+    our @ISA = qw( ExtUtils::MM_Unix );
 }
 
 
