@@ -2,14 +2,14 @@ package ExtUtils::MM_OS2;
 
 use strict;
 
-use ExtUtils::MakeMaker qw(neatvalue);
+use ExtUtils::MakeMaker < qw(neatvalue);
 use File::Spec;
 
 our $VERSION = '6.44';
 
 require ExtUtils::MM_Any;
 require ExtUtils::MM_Unix;
-our @ISA = @( qw(ExtUtils::MM_Unix) );
+our @ISA = qw(ExtUtils::MM_Unix);
 
 =pod
 
@@ -87,7 +87,7 @@ $self->{BASEEXT}.def: Makefile.PL
 	system "cd tmp_imp; %Config::Config{ar} x ../tmpimp%Config::Config{lib_ext}" 
 	    and die "Cannot extract import objects: $!, \$?=$?";      
     }
-    join('',< @m);
+    join('', @m);
 }
 
 sub static_lib {
@@ -95,13 +95,13 @@ sub static_lib {
     my $old = $self->ExtUtils::MM_Unix::static_lib();
     return $old unless $self->{IMPORTS} && %{$self->{IMPORTS}};
     
-    my @chunks = @( split m/\n{2,}/, $old );
+    my @chunks = split m/\n{2,}/, $old;
     shift @chunks unless length @chunks[0]; # Empty lines at the start
     @chunks[0] .= <<'EOC';
 
 	$(AR) $(AR_STATIC_ARGS) $@ tmp_imp/* && $(RANLIB) $@
 EOC
-    return join "\n\n". '', < @chunks;
+    return join "\n\n". '', @chunks;
 }
 
 sub replace_manpage_separator {
