@@ -4,7 +4,7 @@ use strict;
 our $VERSION = 6.44;
 
 require ExtUtils::MM_Unix;
-our @ISA = @( qw(ExtUtils::MM_Unix) );
+our @ISA = qw(ExtUtils::MM_Unix);
 
 
 =head1 NAME
