@@ -4,19 +4,21 @@ package ExtUtils::MM_Unix;
 use strict;
 
 use ExtUtils::MakeMaker::Config;
-use File::Basename qw(basename dirname);
+use File::Basename < qw(basename dirname);
 use DirHandle;
 
 our %Config_Override;
 
-use ExtUtils::MakeMaker qw($Verbose neatvalue);
+our $Verbose;
+require ExtUtils::MakeMaker;
+ExtUtils::MakeMaker->import( <qw($Verbose neatvalue));
 
 # If we make $VERSION an our variable parse_version() breaks
-use vars qw($VERSION);
+use vars < qw($VERSION);
 $VERSION = '6.44';
 
 require ExtUtils::MM_Any;
-our @ISA = @( qw(ExtUtils::MM_Any) );
+our @ISA = qw(ExtUtils::MM_Any);
 
 my %Is;
 BEGIN { 
@@ -161,7 +163,7 @@ sub c_o {
 	$command \$*.C
 } if !%Is{OS2} and !%Is{Win32} and !%Is{Dos}; #Case-specific
 
-    return join "", < @m;
+    return join "", @m;
 }
 
 =item cflags (o)
@@ -183,9 +185,9 @@ sub cflags {
     my($prog, $uc, $perltype, %cflags);
     $libperl ||= $self->{LIBPERL_A} || "libperl$self->{LIB_EXT}" ;
     $libperl =~ s/\.\$\(A\)$/$self->{LIB_EXT}/;
-
+ <
     %cflags{[qw(cc ccflags optimize shellflags)]}
-	= %Config{[qw(cc ccflags optimize shellflags)]};
+	= < %Config{[qw(cc ccflags optimize shellflags)]};
     my($optdebug) = "";
 
     %cflags{shellflags} ||= '';
@@ -227,7 +229,7 @@ sub cflags {
 	  echo perltype=\$perltype
 	  echo optdebug=\$optdebug
 	  ` );
-	foreach my $line (< @o){
+	foreach my $line ( @o){
 	    chomp $line;
 	    if ($line =~ m/(.*?)=\s*(.*)\s*$/){
 		%cflags{$1} = $2;
@@ -310,14 +312,14 @@ sub const_config {
 END
 
     my(%once_only);
-    foreach my $key (< @{$self->{CONFIG}}){
+    foreach my $key ( @{$self->{CONFIG}}){
         # SITE*EXP macros are defined in &constants; avoid duplicates here
         next if %once_only{$key};
         $self->{uc $key} = quote_paren($self->{uc $key});
         push @m, uc($key) , ' = ' , $self->{uc $key}, "\n";
         %once_only{$key} = 1;
     }
-    join('', < @m);
+    join('', @m);
 }
 
 =item const_loadlibs (o)
@@ -349,7 +351,7 @@ sub const_loadlibs {
         next unless $self->{$tmp};
         push @m, "$tmp = $self->{$tmp}\n";
     }
-    return join "", < @m;
+    return join "", @m;
 }
 
 =item constants (o)
@@ -366,7 +368,7 @@ sub constants {
 
     $self->{DFSEP} = '$(DIRFILESEP)';  # alias for internal use
 
-    for my $macro (qw(
+    for my $macro (@( <qw(
 
               AR_STATIC_ARGS DIRFILESEP DFSEP
               NAME NAME_SYM 
@@ -378,9 +380,9 @@ sub constants {
               INSTALLDIRS INSTALL_BASE DESTDIR PREFIX
               PERLPREFIX      SITEPREFIX      VENDORPREFIX
                    ),
-                   (map { ("INSTALL".$_,
+                   (< map { ("INSTALL".$_,
                           "DESTINSTALL".$_)
-                        } < $self->installvars),
+                        } $self->installvars), <
                    qw(
               PERL_LIB    
               PERL_ARCHLIB
@@ -393,7 +395,7 @@ sub constants {
               PERL_CORE
               PERM_RW PERM_RWX
 
-	      ) ) 
+	      )) ) 
     {
 	next unless defined $self->{$macro};
 
@@ -428,12 +430,12 @@ MM_REVISION = $self->{MM_REVISION}
 
     push @m, "
 # Handy lists of source code files:
-XS_FILES = ".$self->wraplist(sort keys %{$self->{XS} || \%()})."
+XS_FILES = ".$self->wraplist( <sort keys %{$self->{XS} || \%()})."
 C_FILES  = ".$self->wraplist(< @{$self->{C}})."
 O_FILES  = ".$self->wraplist(< @{$self->{O_FILES}})."
 H_FILES  = ".$self->wraplist(< @{$self->{H}})."
-MAN1PODS = ".$self->wraplist(sort keys %{$self->{MAN1PODS} || \%()})."
-MAN3PODS = ".$self->wraplist(sort keys %{$self->{MAN3PODS} || \%()})."
+MAN1PODS = ".$self->wraplist( <sort keys %{$self->{MAN1PODS} || \%()})."
+MAN3PODS = ".$self->wraplist( <sort keys %{$self->{MAN3PODS} || \%()})."
 ";
 
 
@@ -466,12 +468,12 @@ PERL_ARCHIVE_AFTER = $self->{PERL_ARCHIVE_AFTER}
 
     push @m, "
 
-TO_INST_PM = ".$self->wraplist(sort keys %{$self->{PM}})."
+TO_INST_PM = ".$self->wraplist( <sort keys %{$self->{PM}})."
 
 PM_TO_BLIB = ".$self->wraplist(< %{$self->{PM}})."
 ";
 
-    join('',< @m);
+    join('', @m);
 }
 
 
@@ -488,7 +490,7 @@ sub depend {
 	last unless defined $key;
 	push @m, "$key : $val\n";
     }
-    join "", < @m;
+    join "", @m;
 }
 
 
@@ -507,7 +509,7 @@ sub init_DEST {
     $self->{DESTDIR} ||= '';
 
     # Make DEST variables.
-    foreach my $var ( <$self->installvars) {
+    foreach my $var ( $self->installvars) {
         my $destvar = 'DESTINSTALL'.$var;
         $self->{$destvar} ||= '$(DESTDIR)$(INSTALL'.$var.')';
     }
@@ -956,7 +958,7 @@ MAKE
 	$(CHMOD) $(PERM_RWX) $@
 MAKE
 
-    return join('',< @m);
+    return join('', @m);
 }
 
 =item exescan
@@ -994,9 +996,9 @@ sub find_perl {
 
     if ($trace +>= 2){
         print "Looking for perl $ver by these names:
-{join ' ', <@$names}
+{join ' ',@$names}
 in these dirs:
-{join ' ', <@$dirs}
+{join ' ',@$dirs}
 ";
     }
 
@@ -1014,8 +1016,8 @@ WARNING
         }
     }
 
-    foreach my $name (< @$names){
-        foreach my $dir (< @$dirs){
+    foreach my $name ( @$names){
+        foreach my $dir ( @$dirs){
             next unless defined $dir; # $self->{PERL_SRC} may be undefined
             my ($abs, $val);
             if ($self->file_name_is_absolute($name)) {     # /foo/bar
@@ -1056,7 +1058,7 @@ WARNING
             }
         }
     }
-    print STDOUT "Unable to find a perl $ver (by these names: {join ' ', <@$names}, in these dirs: {join ' ', <@$dirs})\n";
+    print STDOUT "Unable to find a perl $ver (by these names: {join ' ',@$names}, in these dirs: {join ' ',@$dirs})\n";
     0; # false and not empty
 }
 
@@ -1073,7 +1075,7 @@ sub fixin {    # stolen from the pink Camel book, more or less
     my ( $self, < @files ) = < @_;
 
     my ($does_shbang) = %Config{'sharpbang'} =~ m/^\s*\#\!/;
-    for my $file (< @files) {
+    for my $file ( @files) {
         my $file_new = "$file.new";
         my $file_bak = "$file.bak";
 
@@ -1082,7 +1084,7 @@ sub fixin {    # stolen from the pink Camel book, more or less
         chomp( my $line = ~< $fixin );
         next unless $line =~ s/^\s*\#!\s*//;    # Not a shbang file.
         # Now figure out the interpreter name.
-        my ( $cmd, $arg ) = split ' ', $line, 2;
+        my ( $cmd, $arg ) = < split ' ', $line, 2;
         $cmd =~ s!^.*/!!;
 
         # Now look (in reverse) for interpreter in absolute PATH (unless perl).
@@ -1098,10 +1100,10 @@ sub fixin {    # stolen from the pink Camel book, more or less
         }
         else {
             my (@absdirs)
-                = @( reverse grep { $self->file_name_is_absolute } < $self->path );
+                = reverse grep { $self->file_name_is_absolute } $self->path;
             $interpreter = '';
 
-            foreach my $dir (< @absdirs) {
+            foreach my $dir ( @absdirs) {
                 if ( $self->maybe_command($cmd) ) {
                     warn "Ignoring $interpreter in $file\n"
                         if $Verbose && $interpreter;
@@ -1171,7 +1173,7 @@ eval 'exec $interpreter $arg -S \$0 \$\{1+"\$\@"\}'
 sub _rename {
     my($old, $new) = < @_;
 
-    foreach my $file ($old, $new) {
+    foreach my $file (@($old, $new)) {
         if( %Is{VMS} and basename($file) !~ m/\./ ) {
             # rename() in 5.8.0 on VMS will not rename a file if it
             # does not contain a dot yet it returns success.
@@ -1250,15 +1252,15 @@ sub init_dirscan {	# --- File and Directory Lists (.xs .pm .pod etc)
     my($self) = < @_;
     my(%dir, %xs, %c, %h, %pl_files, %pm);
 
-    my %ignore = %( map {( $_ => 1 )} qw(Makefile.PL Build.PL test.pl t) );
+    my %ignore = %( < map {( $_ => 1 )} qw(Makefile.PL Build.PL test.pl t) );
 
     # ignore the distdir
     %Is{VMS} ? %ignore{"$self->{DISTVNAME}.dir"} = 1
             : %ignore{$self->{DISTVNAME}} = 1;
+ <
+    %ignore{[ map lc, keys %ignore]} = < values %ignore if %Is{VMS};
 
-    %ignore{[map lc, keys %ignore]} = values %ignore if %Is{VMS};
-
-    foreach my $name ( <$self->lsdir($Curdir)){
+    foreach my $name ( $self->lsdir($Curdir)){
 	next if $name =~ m/\#/;
 	next if $name eq $Curdir or $name eq $Updir or %ignore{$name};
 	next unless $self->libscan($name);
@@ -1293,14 +1295,14 @@ sub init_dirscan {	# --- File and Directory Lists (.xs .pm .pod etc)
     }
 
     $self->{PL_FILES}   ||= \%pl_files;
-    $self->{DIR}        ||= \@(sort keys %dir);
+    $self->{DIR}        ||= \sort keys %dir;
     $self->{XS}         ||= \%xs;
-    $self->{C}          ||= \@(sort keys %c);
-    $self->{H}          ||= \@(sort keys %h);
+    $self->{C}          ||= \sort keys %c;
+    $self->{H}          ||= \sort keys %h;
     $self->{PM}         ||= \%pm;
 
-    my @o_files = @( < @{$self->{C}} );
-    $self->{O_FILES} = \@(grep s/\.c(pp|xx|c)?\z/$self->{OBJ_EXT}/i, < @o_files);
+    my @o_files = @{$self->{C}};
+    $self->{O_FILES} = \ grep s/\.c(pp|xx|c)?\z/$self->{OBJ_EXT}/i, @o_files;
 }
 
 
@@ -1360,7 +1362,7 @@ sub init_MAN1PODS {
     my($self) = < @_;
 
     if ( exists $self->{EXE_FILES} ) {
-	foreach my $name (< @{$self->{EXE_FILES}}) {
+	foreach my $name ( @{$self->{EXE_FILES}}) {
 	    next unless $self->_has_pod($name);
 
 	    $self->{MAN1PODS}->{$name} =
@@ -1393,7 +1395,7 @@ sub init_MAN3PODS {
 	}
     }
 
-    my $parentlibs_re = join '|', < @{$self->{PMLIBPARENTDIRS}};
+    my $parentlibs_re = join '|', @{$self->{PMLIBPARENTDIRS}};
 
     # Remove "Configure.pm" and similar, if it's not the only pod listed
     # To force inclusion, just name it "Configure.pod", or override 
@@ -1407,7 +1409,7 @@ sub init_MAN3PODS {
 	$manpagename =~ s/\.p(od|m|l)\z//;
 	# everything below lib is ok
 	unless($manpagename =~ s!^\W*($parentlibs_re)\W+!!s) {
-	    $manpagename = $self->catfile(
+	    $manpagename = $self->catfile( <
 	        split(m/::/,$self->{PARENT_NAME}),$manpagename
 	    );
 	}
@@ -1467,10 +1469,10 @@ sub init_PM {
 
     # Avoid $_ wherever possible:
     # @{$self->{PMLIBDIRS}} = grep -d && !$dir{$_}, @{$self->{PMLIBDIRS}};
-    my (@pmlibdirs) = @( < @{$self->{PMLIBDIRS}} );
+    my (@pmlibdirs) = @{$self->{PMLIBDIRS}};
     @{$self->{PMLIBDIRS}} = @( () );
-    my %dir = %( map { ($_ => $_) } < @{$self->{DIR}} );
-    foreach my $pmlibdir (< @pmlibdirs) {
+    my %dir = %( < map { ($_ => $_) } @{$self->{DIR}} );
+    foreach my $pmlibdir ( @pmlibdirs) {
 	-d $pmlibdir && !%dir{$pmlibdir} && push @{$self->{PMLIBDIRS}}, $pmlibdir;
     }
 
@@ -1481,7 +1483,7 @@ sub init_PM {
     return if $self->{PM} and $self->{ARGS}->{PM};
 
     if ((nelems @{$self->{PMLIBDIRS}})){
-	print "Searching PMLIBDIRS: {join ' ', <@{$self->{PMLIBDIRS}}}\n"
+	print "Searching PMLIBDIRS: {join ' ',@{$self->{PMLIBDIRS}}}\n"
 	    if ($Verbose +>= 2);
 	require File::Find;
         File::Find::find(sub {
@@ -1499,7 +1501,7 @@ sub init_PM {
             my $prefix = $self->{INST_LIBDIR};
             my $striplibpath;
 
-	    my $parentlibs_re = join '|', < @{$self->{PMLIBPARENTDIRS}};
+	    my $parentlibs_re = join '|', @{$self->{PMLIBPARENTDIRS}};
 	    $prefix =  $self->{INST_LIB} 
                 if ($striplibpath = $path) =~ s{^(\W*)($parentlibs_re)\W}
 	                                       {$1}i;
@@ -1551,12 +1553,12 @@ sub init_main {
 ### Only UNIX:
 ###    ($self->{FULLEXT} =
 ###     $self->{NAME}) =~ s!::!/!g ; #eg. BSD/Foo/Socket
-    $self->{FULLEXT} = $self->catdir(split m/::/, $self->{NAME});
+    $self->{FULLEXT} = $self->catdir( <split m/::/, $self->{NAME});
 
 
     # Copied from DynaLoader:
 
-    my(@modparts) = @( split(m/::/,$self->{NAME}) );
+    my(@modparts) = split(m/::/,$self->{NAME});
     my($modfname) = @modparts[-1];
 
     # Some systems have restrictions on files names for DLL's etc.
@@ -1652,7 +1654,7 @@ from the perl source tree.
 	    # Maybe somebody tries to build an extension with an
 	    # uninstalled Perl outside of Perl build tree
 	    my $lib;
-	    for my $dir (< @INC) {
+	    for my $dir ( @INC) {
 	      $lib = $dir, last if -e $self->catdir($dir, "Config.pm");
 	    }
 	    if ($lib) {
@@ -1690,7 +1692,7 @@ EOP
     push(@{$self->{CONFIG}}, < @ExtUtils::MakeMaker::Get_from_Config);
     push(@{$self->{CONFIG}}, 'shellflags') if %Config{shellflags};
     my(%once_only);
-    foreach my $m (< @{$self->{CONFIG}}){
+    foreach my $m ( @{$self->{CONFIG}}){
         next if %once_only{$m};
         print STDOUT "CONFIG key '$m' does not exist in Config.pm\n"
                 unless exists %Config{$m};
@@ -1746,9 +1748,9 @@ sub init_others {	# --- Initialize Other Attributes
     $self->{LIBS} = \@('') unless (nelems @{$self->{LIBS}}) && defined $self->{LIBS}->[0];
     $self->{LD_RUN_PATH} = "";
 
-    foreach my $libs ( < @{$self->{LIBS}} ){
+    foreach my $libs (  @{$self->{LIBS}} ){
 	$libs =~ s/^\s*(.*\S)\s*$/$1/; # remove leading and trailing whitespace
-	my(@libs) = @( < $self->extliblist($libs) );
+	my(@libs) = $self->extliblist($libs);
 	if (@libs[0] or @libs[1] or @libs[2]){
 	    # LD_RUN_PATH now computed by ExtUtils::Liblist
 	    ($self->{EXTRALIBS},  $self->{BSLOADLIBS}, 
@@ -1865,9 +1867,9 @@ sub init_lib2arch {
     # architecture. If not we take it as a sign that it should be the
     # same as the requested installation directory. Otherwise we take
     # the found one.
-    for my $libpair (\%(l=>"privlib",   a=>"archlib"), 
+    for my $libpair (@(\%(l=>"privlib",   a=>"archlib"), 
                      \%(l=>"sitelib",   a=>"sitearch"),
-                     \%(l=>"vendorlib", a=>"vendorarch"),
+                     \%(l=>"vendorlib", a=>"vendorarch"),)
                     )
     {
         my $lib = "install$libpair->{l}";
@@ -1913,8 +1915,8 @@ sub init_PERL {
     my($self) = shift;
 
     my @defpath = @( () );
-    foreach my $component ($self->{PERL_SRC}, < $self->path(), 
-                           %Config{binexp}) 
+    foreach my $component (@($self->{PERL_SRC}, < $self->path(), 
+                           %Config{binexp})) 
     {
 	push @defpath, $component if defined $component;
     }
@@ -1930,8 +1932,8 @@ sub init_PERL {
     $thisperl = $self->abs2rel($thisperl) if $self->{PERL_CORE};
 
     my @perls = @($thisperl);
-    push @perls, map { "$_%Config{exe_ext}" }
-                     ('perl', 'perl5', "perl%Config{version}");
+    push @perls, < map { "$_%Config{exe_ext}" }
+ @(                     ('perl', 'perl5', "perl%Config{version}"));
 
     # miniperl has priority over all but the cannonical perl when in the
     # core.  Otherwise its a last resort.
@@ -2194,7 +2196,7 @@ uninstall_from_vendordirs ::
 	$(NOECHO) $(UNINSTALL) }.$self->catfile('$(VENDORARCHEXP)','auto','$(FULLEXT)','.packlist').q{
 };
 
-    join("",< @m);
+    join("", @m);
 }
 
 =item installbin (o)
@@ -2207,13 +2209,13 @@ sub installbin {
     my($self) = shift;
 
     return "" unless $self->{EXE_FILES} && ref $self->{EXE_FILES} eq "ARRAY";
-    my @exefiles = @( < @{$self->{EXE_FILES}} );
+    my @exefiles = @{$self->{EXE_FILES}};
     return "" unless (nelems @exefiles);
 
-    @exefiles = @( map < vmsify($_), < @exefiles ) if %Is{VMS};
+    @exefiles = map < vmsify($_), @exefiles if %Is{VMS};
 
     my %fromto;
-    for my $from (< @exefiles) {
+    for my $from ( @exefiles) {
 	my($path)= $self->catfile('$(INST_SCRIPT)', basename($from));
 
 	local($_) = $path; # for backwards compatibility
@@ -2223,20 +2225,20 @@ sub installbin {
         $to = vmsify($to) if %Is{VMS};
 	%fromto{$from} = $to;
     }
-    my @to   = @( values %fromto );
+    my @to   = values %fromto;
 
     my @m;
     push(@m, qq{
-EXE_FILES = {join ' ', <@exefiles}
+EXE_FILES = {join ' ',@exefiles}
 
-pure_all :: {join ' ', <@to}
+pure_all :: {join ' ',@to}
 	\$(NOECHO) \$(NOOP)
 
 realclean ::
 });
 
     # realclean can get rather large.
-    push @m, map "\t$_\n", < $self->split_command('$(RM_F)', < @to);
+    push @m, < map "\t$_\n", $self->split_command('$(RM_F)', < @to);
     push @m, "\n";
 
 
@@ -2255,7 +2257,7 @@ MAKE
 
     }
 
-    join "", < @m;
+    join "", @m;
 }
 
 
@@ -2291,7 +2293,7 @@ sub lsdir {
     $dh->open($dir || ".") or return ();
     @ls = $dh->readdirs;
     $dh->close;
-    @ls = @( grep(m/$regex/, < @ls) ) if $regex;
+    @ls = grep(m/$regex/, @ls) if $regex;
     return @ls;
 }
 
@@ -2309,7 +2311,7 @@ sub macro {
 	last unless defined $key;
 	push @m, "$key = $val\n";
     }
-    join "", < @m;
+    join "", @m;
 }
 
 =item makeaperl (o)
@@ -2325,7 +2327,7 @@ DynaLoader_pure_p1_c0_032.a are automatically ignored to avoid link errors.)
 
 sub makeaperl {
     my($self, < %attribs) = < @_;
-    my($makefilename, $searchdirs, $static, $extra, $perlinc, $target, $tmp, $libperl) =
+    my($makefilename, $searchdirs, $static, $extra, $perlinc, $target, $tmp, $libperl) = <
 	%attribs{[qw(MAKE DIRS STAT EXTRA INCL TARGET TMP LIBPERL)]};
     my(@m);
     push @m, "
@@ -2333,9 +2335,9 @@ sub makeaperl {
 MAP_TARGET    = $target
 FULLPERL      = $self->{FULLPERL}
 ";
-    return join '', < @m if $self->{PARENT};
+    return join '', @m if $self->{PARENT};
 
-    my($dir) = join ":", < @{$self->{DIR}};
+    my($dir) = join ":", @{$self->{DIR}};
 
     unless ($self->{MAKEAPERL}) {
 	push @m, q{
@@ -2349,7 +2351,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 		MAKEFILE=$(MAKE_APERL_FILE) LINKTYPE=static \
 		MAKEAPERL=1 NORECURS=1 CCCDLFLAGS=};
 
-	foreach (< @ARGV){
+	foreach ( @ARGV){
 		if( m/\s/ ){
 			s/=(.*)/='$1'/;
 		}
@@ -2358,7 +2360,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 #	push @m, map( " \\\n\t\t$_", @ARGV );
 	push @m, "\n";
 
-	return join '', < @m;
+	return join '', @m;
     }
 
 
@@ -2374,8 +2376,8 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
     $cccmd =~ s/\(CC\)/\(PERLMAINCC\)/;
 
     # The front matter of the linkcommand...
-    $linkcmd = join ' ', "\$(CC)",
-	    grep($_, %Config{[qw(ldflags ccdlflags)]});
+    $linkcmd = join ' ', @( "\$(CC)",
+	    < grep($_, %Config{[qw(ldflags ccdlflags)]}));
     $linkcmd =~ s/\s+/ /g;
     $linkcmd =~ s,(perl\.exp),\$(PERL_INC)/$1,;
 
@@ -2401,7 +2403,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 
 		# Throw away anything not explicitly marked for inclusion.
 		# DynaLoader is implied.
-		foreach my $incl ((< @{$self->{INCLUDE_EXT}},'DynaLoader')){
+		foreach my $incl (@((< @{$self->{INCLUDE_EXT}},'DynaLoader'))){
 			if( $xx eq $incl ){
 				$found++;
 				last;
@@ -2415,7 +2417,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 		$xx =~ s,/,::,g;
 
 		# Throw away anything explicitly marked for exclusion
-		foreach my $excl (< @{$self->{EXCLUDE_EXT}}){
+		foreach my $excl ( @{$self->{EXCLUDE_EXT}}){
 			return if( $xx eq $excl );
 		}
 	}
@@ -2430,11 +2432,11 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 	return if $File::Find::name =~ m:auto/$self->{FULLEXT}/$self->{BASEEXT}$self->{LIB_EXT}\z:;
 	use Cwd 'cwd';
 	%static{cwd() . "/" . $_}++;
-    }, grep( -d $_, < @{$searchdirs || \@()}) );
+    }, < grep( -d $_, @{$searchdirs || \@()}) );
 
     # We trust that what has been handed in as argument, will be buildable
     $static = \@() unless $static;
-    %static{[< @{$static}]} = (1) x nelems @{$static};
+ <    %static{[ @{$static}]} = (1) x nelems @{$static};
 
     $extra = \@() unless $extra && ref $extra eq 'ARRAY';
     for (sort keys %static) {
@@ -2443,7 +2445,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 	push @$extra, $_;
     }
 
-    s/^(.*)/"-I$1"/ for < @{$perlinc || \@()}; 
+    s/^(.*)/"-I$1"/ for  @{$perlinc || \@()}; 
 
     $target ||= "perl";
     $tmp    ||= ".";
@@ -2453,7 +2455,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 # extralibs.all are computed correctly
     push @m, "
 MAP_LINKCMD   = $linkcmd
-MAP_PERLINC   = {join ' ', <@{$perlinc || \@()}
+MAP_PERLINC   = {join ' ',@{$perlinc || \@()}
 }MAP_STATIC    = ",
 join(" \\\n\t", reverse sort keys %static), "
 
@@ -2495,12 +2497,12 @@ LLIBPERL    = $llibperl
 ";
 
     push @m, '
-$(INST_ARCHAUTODIR)/extralibs.all : $(INST_ARCHAUTODIR)$(DFSEP).exists '.join(" \\\n\t", < @$extra).'
+$(INST_ARCHAUTODIR)/extralibs.all : $(INST_ARCHAUTODIR)$(DFSEP).exists '.join(" \\\n\t", @$extra).'
 	$(NOECHO) $(RM_F)  $@
 	$(NOECHO) $(TOUCH) $@
 ';
 
-    foreach my $catfile (< @$extra){
+    foreach my $catfile ( @$extra){
 	push @m, "\tcat $catfile >> \$\@\n";
     }
 
@@ -2552,7 +2554,7 @@ map_clean :
 	}.$self->{RM_F}.qq{ $tmp/perlmain\$(OBJ_EXT) $tmp/perlmain.c \$(MAP_TARGET) $makefilename \$(INST_ARCHAUTODIR)/extralibs.all
 };
 
-    join '', < @m;
+    join '', @m;
 }
 
 =item makefile (o)
@@ -2573,7 +2575,7 @@ $(OBJECT) : $(FIRST_MAKEFILE)
 ' if $self->{OBJECT};
 
     my $newer_than_target = %Is{VMS} ? '$(MMS$SOURCE_LIST)' : '$?';
-    my $mpl_args = join " ", map qq["$_"], < @ARGV;
+    my $mpl_args = join " ", map qq["$_"], @ARGV;
 
     $m .= sprintf <<'MAKE_FRAG', $newer_than_target, $mpl_args;
 # We take a very conservative approach here, but it's worth it.
@@ -2714,6 +2716,9 @@ sub parse_version {
         |;
         local $^W = 0;
         $result = eval($eval);  ## no critic
+        if (ref $result) {
+            $result = $result->stringify;
+        }
         warn "Could not eval '$eval' in $parsefile: {$@->message}" if $@;
         last;
     }
@@ -2752,8 +2757,8 @@ sub pasthru {
 	push @pasthru, "PASTHRU_$key=\"\$(PASTHRU_$key)\"";
     }
 
-    push @m, "\nPASTHRU = ", join ($sep, < @pasthru), "\n";
-    join "", < @m;
+    push @m, "\nPASTHRU = ", join ($sep, @pasthru), "\n";
+    join "", @m;
 }
 
 =item perl_script
@@ -2795,7 +2800,7 @@ $(PERL_ARCHLIB)/Config.pm: $(PERL_SRC)/config.sh
 	%s
 MAKE_FRAG
 
-    return join "", < @m unless $self->needs_linking;
+    return join "", @m unless $self->needs_linking;
 
     push @m, q{
 PERL_HDRS = \
@@ -2846,7 +2851,7 @@ $(OBJECT) : $(PERL_HDRS)
 
     push @m, join(" ", values %{$self->{XS}})." : \$(XSUBPPDEPS)\n"  if %{$self->{XS}};
 
-    join "\n", < @m;
+    join "\n", @m;
 }
 
 
@@ -2897,9 +2902,9 @@ pm_to_blib : $(TO_INST_PM)
 pm_to_blib(\\\%( < \@ARGV ), '$autodir', '\$(PM_FILTER)')
 CODE
 
-    my @cmds = @( < $self->split_command($pm_to_blib, < %{$self->{PM}}) );
+    my @cmds = $self->split_command($pm_to_blib, < %{$self->{PM}});
 
-    $r .= join '', map { "\t\$(NOECHO) $_\n" } < @cmds;
+    $r .= join '', map { "\t\$(NOECHO) $_\n" } @cmds;
     $r .= qq{\t\$(NOECHO) \$(TOUCH) pm_to_blib\n};
 
     return $r;
@@ -2948,7 +2953,7 @@ for a binary distribution.
 sub ppd {
     my($self) = < @_;
 
-    my $pack_ver = join ",", (split (m/\./, $self->{VERSION}), (0)x4)[[0..3]];
+    my $pack_ver = join ",", @( < split(m/\./, $self->{VERSION}), (0)x4)[[0..3]];
 
     my $abstract = $self->{ABSTRACT} || '';
     $abstract =~ s/\n/\\n/sg;
@@ -2970,8 +2975,8 @@ PPD_HTML
     foreach my $prereq (sort keys %{$self->{PREREQ_PM} || \%()}) {
         my $pre_req = $prereq;
         $pre_req =~ s/::/-/g;
-        my $dep_ver = join ",", (split (m/\./, $self->{PREREQ_PM}->{$prereq}), 
-                                    (0) x 4)[[0 .. 3]];
+        my $dep_ver = join ",", @( <split (m/\./, $self->{PREREQ_PM}->{$prereq}), 
+                                   (0) x 4)[[0 .. 3]];
         $ppd_xml .= sprintf <<'PPD_OUT', $pre_req, $dep_ver;
         <DEPENDENCY NAME="%s" VERSION="%s" />
 PPD_OUT
@@ -3008,9 +3013,9 @@ PPD_OUT
 </SOFTPKG>
 PPD_XML
 
-    my @ppd_cmds = @( < $self->echo($ppd_xml, '$(DISTNAME).ppd') );
+    my @ppd_cmds = $self->echo($ppd_xml, '$(DISTNAME).ppd');
 
-    return sprintf <<'PPD_OUT', join "\n\t", < @ppd_cmds;
+    return sprintf <<'PPD_OUT', join "\n\t", @ppd_cmds;
 # Creates a PPD (Perl Package Description) for a binary distribution.
 ppd :
 	%s
@@ -3088,7 +3093,7 @@ sub processPL {
                      ?  $pl_files->{$plfile}
 		     : \@($pl_files->{$plfile});
 
-	foreach my $target (< @$list) {
+	foreach my $target ( @$list) {
             if( %Is{VMS} ) {
                 $plfile = vmsify( <$self->eliminate_macros($plfile));
                 $target = vmsify( <$self->eliminate_macros($target));
@@ -3167,7 +3172,7 @@ sub cd {
     my($self, $dir, < @cmds) = < @_;
 
     # No leading tab and no trailing newline makes for easier embedding
-    my $make_frag = join "\n\t", map { "cd $dir && $_" } < @cmds;
+    my $make_frag = join "\n\t", map { "cd $dir && $_" } @cmds;
 
     return $make_frag;
 }
@@ -3184,11 +3189,11 @@ sub oneliner {
     $cmd =~ s{^\n+}{};
     $cmd =~ s{\n+$}{};
 
-    my @cmds = @( split m/\n/, $cmd );
-    $cmd = join " \n\t  -e ", map { $self->quote_literal($_) } < @cmds;
+    my @cmds = split m/\n/, $cmd;
+    $cmd = join " \n\t  -e ", map { $self->quote_literal($_) } @cmds;
     $cmd = $self->escape_newlines($cmd);
 
-    $switches = join ' ', < @$switches;
+    $switches = join ' ', @$switches;
 
     return qq{\$(ABSPERLRUN) $switches -e $cmd --};   
 }
@@ -3304,7 +3309,7 @@ MAKE_FRAG
 	$(NOECHO) $(ECHO) "$(EXTRALIBS)" >> $(PERL_SRC)/ext.libs
 MAKE_FRAG
 
-    join('', < @m);
+    join('', @m);
 }
 
 =item staticmake (o)
@@ -3382,7 +3387,7 @@ sub subdirs {
     # This method provides a mechanism to automatically deal with
     # subdirectories containing further Makefile.PL scripts.
     # It calls the subdir_x() method for each subdirectory.
-    foreach my $dir (< @{$self->{DIR}}){
+    foreach my $dir ( @{$self->{DIR}}){
 	push(@m, $self->subdir_x($dir));
 ####	print "Including $dir subdirectory\n";
     }
@@ -3395,7 +3400,7 @@ sub subdirs {
     } else {
 	push(@m, "\n# none")
     }
-    join('',< @m);
+    join('', @m);
 }
 
 =item test (o)
@@ -3430,7 +3435,7 @@ subdirs-test ::
 
 ");
 
-    foreach my $dir (< @{ $self->{DIR} }) {
+    foreach my $dir ( @{ $self->{DIR} }) {
         my $test = $self->cd($dir, '$(MAKE) test $(PASTHRU)');
 
         push @m, <<END
@@ -3471,7 +3476,7 @@ END
 	push @m, "test_static :: test_dynamic\n";
 	push @m, "testdb_static :: testdb_dynamic\n";
     }
-    join("", < @m);
+    join("", @m);
 }
 
 =item test_via_harness (override)
@@ -3529,7 +3534,7 @@ sub tools_other {
         push @m, "$tool = $self->{$tool}\n";
     }
 
-    return join "", < @m;
+    return join "", @m;
 }
 
 =item tool_xsubpp (o)
@@ -3543,12 +3548,12 @@ sub tool_xsubpp {
     return "" unless $self->needs_linking;
 
     my $xsdir;
-    my @xsubpp_dirs = @( < @INC );
+    my @xsubpp_dirs = @INC;
 
     # Make sure we pick up the new xsubpp if we're building perl.
     unshift @xsubpp_dirs, $self->{PERL_LIB} if $self->{PERL_CORE};
 
-    foreach my $dir (< @xsubpp_dirs) {
+    foreach my $dir ( @xsubpp_dirs) {
         $xsdir = $self->catdir($dir, 'ExtUtils');
         if( -r $self->catfile($xsdir, "xsubpp") ) {
             last;
@@ -3558,7 +3563,7 @@ sub tool_xsubpp {
     my $tmdir   = File::Spec->catdir($self->{PERL_LIB},"ExtUtils");
     my(@tmdeps) = @( $self->catfile($tmdir,'typemap') );
     if( $self->{TYPEMAPS} ){
-        foreach my $typemap (< @{$self->{TYPEMAPS}}){
+        foreach my $typemap ( @{$self->{TYPEMAPS}}){
             if( ! -f  $typemap ) {
                 warn "Typemap $typemap not found.\n";
             }
@@ -3568,7 +3573,7 @@ sub tool_xsubpp {
         }
     }
     push(@tmdeps, "typemap") if -f "typemap";
-    my(@tmargs) = @( map("-typemap $_", < @tmdeps) );
+    my(@tmargs) = map("-typemap $_", @tmdeps);
     if( exists $self->{XSOPT} ){
         unshift( @tmargs, $self->{XSOPT} );
     }
@@ -3590,8 +3595,8 @@ XSUBPPDIR = $xsdir
 XSUBPP = \$(XSUBPPDIR)\$(DFSEP)xsubpp
 XSUBPPRUN = \$(PERLRUN) \$(XSUBPP)
 XSPROTOARG = $self->{XSPROTOARG}
-XSUBPPDEPS = {join ' ', <@tmdeps} \$(XSUBPP)
-XSUBPPARGS = {join ' ', <@tmargs}
+XSUBPPDEPS = {join ' ',@tmdeps} \$(XSUBPP)
+XSUBPPARGS = {join ' ',@tmargs}
 XSUBPP_EXTRA_ARGS = 
 };
 };
@@ -3646,7 +3651,7 @@ help :
 	perldoc ExtUtils::MakeMaker
 };
 
-    join('',< @m);
+    join('', @m);
 }
 
 =item writedoc
@@ -3660,7 +3665,7 @@ sub writedoc {
     my($self,$what,$name,< @attribs)= < @_;
     my $time = localtime;
     print "=head2 $time: $what C<$name>\n\n=over 4\n\n=item *\n\n";
-    print join "\n\n=item *\n\n", map("C<$_>",< @attribs);
+    print join "\n\n=item *\n\n", map("C<$_>", @attribs);
     print "\n\n=back\n\n";
 }
 
