@@ -9,18 +9,18 @@ use strict;
 
 require Exporter;
 
-our @ISA = @( qw(Exporter) );
-our @EXPORT_OK = @( qw(process_file) );
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw(process_file);
 
 # use strict;  # One of these days...
 
 my(@XSStack);	# Stack of conditionals and INCLUDEs
 my($XSS_work_idx, $cpp_next_tmp);
 
-use vars qw($VERSION);
+use vars < qw($VERSION);
 $VERSION = '2.19_01';
 
-use vars qw(%input_expr %output_expr $ProtoUsed @InitFileCode $FH $proto_re $Overload $errors $Fallback
+use vars < qw(%input_expr %output_expr $ProtoUsed @InitFileCode $FH $proto_re $Overload $errors $Fallback
 	    $cplusplus $hiertype $WantPrototypes $WantVersionChk $except $WantLineNumbers
 	    $WantOptimize $process_inout $process_argtypes @tm
 	    $dir $filename $filepathname %IncludedFiles
@@ -122,7 +122,7 @@ sub process_file {
   $process_argtypes = %args{argtypes};
   @tm = @( ref %args{typemap} ? < @{%args{typemap}} : (%args{typemap}) );
   
-  for (%args{filename}) {
+  for (@(%args{filename})) {
     die "Missing required parameter 'filename'" unless $_;
     $filepathname = $_;
     ($dir, $filename) = ( dirname($_), basename($_));
@@ -164,13 +164,13 @@ sub process_file {
     select %args{output};
   }
 
-  foreach my $typemap (< @tm) {
+  foreach my $typemap ( @tm) {
     die "Can't find $typemap in $pwd\n" unless -r $typemap;
   }
 
   push @tm, < standard_typemap_locations();
 
-  foreach my $typemap (< @tm) {
+  foreach my $typemap ( @tm) {
     next unless -f $typemap ;
     # skip directories, binary files etc.
     warn("Warning: ignoring non-text typemap file '$typemap'\n"), next
@@ -422,7 +422,7 @@ EOF
   if ((nelems @BootCode))
   {
     print "\n    /* Initialisation Section */\n\n" ;
-    @line = @( < @BootCode );
+    @line = @BootCode;
     print_section();
     print "\n    /* End of Initialisation Section */\n\n" ;
   }
@@ -456,9 +456,9 @@ sub process_para {
     while ((nelems @line) && @line[0] !~ m/^[^\#]/) {
       my $line = shift(@line);
       print $line, "\n";
-      next unless $line =~ m/^\#\s*((if)(?:n?def)?|elsif|else|endif)\b/;
-      my $statement = $+;
-      if ($statement eq 'if') {
+      next unless $line =~ m/^\#\s*(if(?:n?def)?|elsif|else|endif)\b/;
+      my $statement = $1;
+      if ($statement =~ m/^if/) {
 	$XSS_work_idx = (nelems @XSStack);
 	push(@XSStack, \%(type => 'if'));
       } else {
@@ -469,18 +469,18 @@ sub process_para {
 	  push(@BootCode,     "#endif");
 	}
 	
-	my(@fns) = @( keys %{@XSStack[-1]->{functions} || \%()} );
-	if ($statement ne 'endif') {
+	my @fns = keys %{@XSStack[-1]->{functions} || \%()};
+	if ($statement ne 'endif') { <
 	  # Hide the functions defined in other #if branches, and reset.
-	  %{@XSStack[-1]->{other_functions}}{[< @fns]} = (1) x nelems @fns;
-	  %{@XSStack[-1]}{[qw(varname functions)]} = ('', \%());
+	  %{@XSStack[-1]->{other_functions}}{[ @fns]} = (1) x nelems @fns;
+ <	  %{@XSStack[-1]}{[qw(varname functions)]} = ('', \%());
 	} else {
 	  my($tmp) = pop(@XSStack);
 	  0 while (--$XSS_work_idx
 		   && @XSStack[$XSS_work_idx]->{type} ne 'if');
 	  # Keep all new defined functions
-	  push(@fns, keys %{$tmp->{other_functions} || \%()});
-	  %{@XSStack[$XSS_work_idx]->{functions}}{[< @fns]} = (1) x nelems @fns;
+	  push(@fns, < keys %{$tmp->{other_functions} || \%()});
+ <	  %{@XSStack[$XSS_work_idx]->{functions}}{[ @fns]} = (1) x nelems @fns;
 	}
       }
     }
@@ -572,7 +572,7 @@ sub process_para {
     }
 
     # Check for duplicate function definition
-    for my $tmp (< @XSStack) {
+    for my $tmp ( @XSStack) {
       next unless defined $tmp->{functions}->{$Full_func_name};
       Warn("Warning: duplicate function definition '$clean_func_name' detected");
       last;
@@ -589,7 +589,7 @@ sub process_para {
       my $args = "$orig_args ,";
       if ($args =~ m/^( (??{ $C_arg }) , )* $ /x) {
 	@args = @($args =~ m/\G ( (??{ $C_arg }) ) , /xg);
-	for ( < @args ) {
+	for ( @args ) {
 	  s/^\s+//;
 	  s/\s+$//;
 	  my ($arg, $default) = m/ ( [^=]* ) ( (?: = .* )? ) /x;
@@ -627,12 +627,12 @@ sub process_para {
 	  %in_out{$name} = $out_type if $out_type;
 	}
       } else {
-	@args = @( split(m/\s*,\s*/, $orig_args) );
+	@args = split(m/\s*,\s*/, $orig_args);
 	Warn("Warning: cannot parse argument list '$orig_args', fallback to split");
       }
     } else {
-      @args = @( split(m/\s*,\s*/, $orig_args) );
-      for (< @args) {
+      @args = split(m/\s*,\s*/, $orig_args);
+      for ( @args) {
 	if ($process_inout and s/^(IN|IN_OUTLIST|OUTLIST|IN_OUT|OUT)\s+//) {
 	  my $out_type = $1;
 	  next if $out_type eq 'IN';
@@ -679,23 +679,23 @@ sub process_para {
     my $min_args = $num_args - $extra_args;
     $report_args =~ s/"/\\"/g;
     $report_args =~ s/^,\s+//;
-    my @func_args = @( < @args );
+    my @func_args = @args;
     shift @func_args if defined($class);
 
-    for (< @func_args) {
+    for ( @func_args) {
       s/^/&/ if %in_out{$_};
     }
-    $func_args = join(", ", < @func_args);
-    %args_match{[< @args]} = < @args_num;
+    $func_args = join(", ", @func_args);
+ <    %args_match{[ @args]} = < @args_num;
 
-    $PPCODE = grep(m/^\s*PPCODE\s*:/, < @line);
-    $CODE = grep(m/^\s*CODE\s*:/, < @line);
+    $PPCODE = grep(m/^\s*PPCODE\s*:/, @line);
+    $CODE = grep(m/^\s*CODE\s*:/, @line);
     # Detect CODE: blocks which use ST(n)= or XST_m*(n,v)
     #   to set explicit return values.
     $EXPLICIT_RETURN = ($CODE &&
-			("{join ' ', <@line}" =~ m/(\bST\s*\([^;]*=) | (\bXST_m\w+\s*\()/x ));
-    $ALIAS  = grep(m/^\s*ALIAS\s*:/,  < @line);
-    $INTERFACE  = grep(m/^\s*INTERFACE\s*:/,  < @line);
+			("{join ' ', @line}" =~ m/(\bST\s*\([^;]*=) | (\bXST_m\w+\s*\()/x ));
+    $ALIAS  = grep(m/^\s*ALIAS\s*:/, @line);
+    $INTERFACE  = grep(m/^\s*INTERFACE\s*:/, @line);
 
     $xsreturn = 1 if $EXPLICIT_RETURN;
 
@@ -915,7 +915,7 @@ EOF
       print "\tXSprePUSH;" if $c and not $prepush_done;
       print "\tEXTEND(SP,$c);\n" if $c;
       $xsreturn += $c;
-      generate_output(%var_types{$_}, $num++, $_, 0, 1) for < @outlist;
+      generate_output(%var_types{$_}, $num++, $_, 0, 1) for  @outlist;
       
       # do cleanup
       process_keyword("CLEANUP|ALIAS|ATTRS|PROTOTYPE|OVERLOAD") ;
@@ -986,7 +986,7 @@ EOF
 	push @proto_arg, "$s\@"
 	  if $ellipsis ;
 	
-	$proto = join ("", grep defined, < @proto_arg);
+	$proto = join ("", grep defined, @proto_arg);
       }
       else {
 	# User has specified a prototype
@@ -1011,7 +1011,7 @@ EOF
     elsif ((nelems @Attributes)) {
       push(@InitFileCode, Q(<<"EOF"));
 #        cv = newXS(\"$pname\", XS_$Full_func_name, file);
-#        apply_attrs_string("$Package", cv, "{join ' ', <@Attributes}", 0);
+#        apply_attrs_string("$Package", cv, "{join ' ',@Attributes}", 0);
 EOF
     }
     elsif ($interface) {
@@ -1036,16 +1036,16 @@ sub errors { $errors }
 
 sub standard_typemap_locations {
   # Add all the default typemap locations to the search path
-  my @tm = @( qw(typemap) );
+  my @tm = qw(typemap);
   
   my $updir = File::Spec->updir;
-  foreach my $dir (File::Spec->catdir(($updir) x 1), File::Spec->catdir(($updir) x 2),
-		   File::Spec->catdir(($updir) x 3), File::Spec->catdir(($updir) x 4)) {
+  foreach my $dir (@(File::Spec->catdir(($updir) x 1), File::Spec->catdir(($updir) x 2),
+		   File::Spec->catdir(($updir) x 3), File::Spec->catdir(($updir) x 4))) {
     
     unshift @tm, File::Spec->catfile($dir, 'typemap');
     unshift @tm, File::Spec->catfile($dir, lib => ExtUtils => 'typemap');
   }
-  foreach my $dir (< @INC) {
+  foreach my $dir ( @INC) {
     my $file = File::Spec->catfile($dir, ExtUtils => 'typemap');
     unshift @tm, $file if -e $file;
   }
@@ -1240,7 +1240,7 @@ sub INTERFACE_MACRO_handler() {
 
   TrimWhitespace($in);
   if ($in =~ m/\s/) {		# two
-    ($interface_macro, $interface_macro_set) = split ' ', $in;
+    ($interface_macro, $interface_macro_set) = < split ' ', $in;
   } else {
     $interface_macro = $in;
     $interface_macro_set = 'UNKNOWN_CVT'; # catch later
@@ -1533,8 +1533,8 @@ sub PopFile()
     $filepathname = $data->{Filepathname} ;
     $lastline   = $data->{LastLine} ;
     $lastline_no = $data->{LastLineNo} ;
-    @line       = @( < @{ $data->{Line} } ) ;
-    @line_no    = @( < @{ $data->{LineNo} } ) ;
+    @line       = @{ $data->{Line} } ;
+    @line_no    = @{ $data->{LineNo} } ;
 
     if ($isPipe and $? ) {
       -- $lastline_no ;
@@ -1578,10 +1578,10 @@ sub ProtoString ($)
   }
 
 sub check_cpp {
-  my @cpp = @( grep(m/^\#\s*(?:if|e\w+)/, < @line) );
+  my @cpp = grep(m/^\#\s*(?:if|e\w+)/, @line);
   if ((nelems @cpp)) {
     my ($cpp, $cpplevel);
-    for $cpp (< @cpp) {
+    for $cpp ( @cpp) {
       if ($cpp =~ m/^\#\s*if/) {
 	$cpplevel++;
       } elsif (!$cpplevel) {
@@ -1699,7 +1699,7 @@ sub Warn
     # work out the line number
     my $line_no = @line_no[(nelems @line_no) - (nelems @line) -1] ;
 
-    print STDERR "{join ' ', <@_} in $filename, line $line_no\n" ;
+    print STDERR "{join ' ',@_} in $filename, line $line_no\n" ;
   }
 
 sub blurt
