@@ -17,7 +17,7 @@ my $cwd;
 BEGIN {
     ($cwd) = getcwd() =~ m/(.*)/;
 }
-use lib map { File::Spec->rel2abs($_, $cwd) } qw(blib/arch blib/lib);
+use lib < map { File::Spec->rel2abs($_, $cwd) } qw(blib/arch blib/lib);
 1;
 __END__
 
