@@ -7,8 +7,8 @@ use warnings;
 use strict;
 
 our $VERSION = '4.3';
-our @ISA     = @( qw(Exporter) );
-our @EXPORT  = @( qw(validate) );
+our @ISA     = qw(Exporter);
+our @EXPORT  = qw(validate);
 
 =head1 NAME
 
@@ -103,7 +103,7 @@ sub validate {
         if ($test =~ s/ ^ (!?-) (\w{2,}) \b /$1Z/x) {
             $testlist = $2;
             # split bundled tests, e.g. "ug" to 'u', 'g'
-            @testlist = @( split(m//, $testlist) );
+            @testlist = split(m//, $testlist);
         }
         else {
             # put in placeholder Z for stand-alone test
@@ -113,7 +113,7 @@ sub validate {
         # will compare these two later to stop on 1st warning w/in a bundle
         $oldwarnings = $Warnings;
 
-        foreach my $one (< @testlist) {
+        foreach my $one ( @testlist) {
             # examples of $test: "!-Z || die" or "-w || warn"
             my $this = $test;
 
