@@ -21,9 +21,9 @@ our(@ISA, @EXPORT, @EXPORT_OK, $VERSION, $Too_Big, $Syscopy_is_copy);
 $VERSION = '2.11';
 
 require Exporter;
-@ISA = @( qw(Exporter) );
-@EXPORT = @( qw(copy move) );
-@EXPORT_OK = @( qw(cp mv) );
+@ISA = qw(Exporter);
+@EXPORT = qw(copy move);
+@EXPORT_OK = qw(cp mv);
 
 $Too_Big = 1024 * 1024 * 2;
 
@@ -213,7 +213,7 @@ sub move {
 	$to = _catname($from, $to);
     }
 
-    ($tosz1,$tomt1) = (stat($to))[[7,9]];
+    ($tosz1,$tomt1) = < @(stat($to))[[@: 7,9]];
     $fromsz = -s $from;
     if ($^O eq 'os2' and defined $tosz1 and defined $fromsz) {
       # will not rename with overwrite
@@ -244,18 +244,18 @@ sub move {
     # Did rename return an error even though it succeeded, because $to
     # is on a remote NFS file system, and NFS lost the server's ack?
     return 1 if defined($fromsz) && !-e $from &&           # $from disappeared
-                (($tosz2,$tomt2) = (stat($to))[[7,9]]) &&    # $to's there
+                (($tosz2,$tomt2) = < @(stat($to))[[@:7,9]]) &&    # $to's there
                   ((!defined $tosz1) ||			   #  not before or
 		   ($tosz1 != $tosz2 or $tomt1 != $tomt2)) &&  #   was changed
                 $tosz2 == $fromsz;                         # it's all there
 
-    ($tosz1,$tomt1) = (stat($to))[[7,9]];  # just in case rename did something
+    ($tosz1,$tomt1) = < @(stat($to))[[@:7,9]];  # just in case rename did something
 
     {
         local $@;
         try {
             copy($from,$to) or die;
-            my($atime, $mtime) = (stat($from))[[8,9]];
+            my($atime, $mtime) = < @(stat($from))[[8..9]];
             utime($atime, $mtime, $to);
             unlink($from)   or die;
         };
@@ -263,7 +263,7 @@ sub move {
     }
     ($sts,$ossts) = ($! + 0, $^E + 0);
 
-    ($tosz2,$tomt2) = ((stat($to))[[7,9]],0,0) if defined $tomt1;
+    ($tosz2,$tomt2) = (< @(stat($to))[[@:7,9]],0,0) if defined $tomt1;
     unlink($to) if !defined($tomt1) or $tomt1 != $tomt2 or $tosz1 != $tosz2;
     ($!,$^E) = ($sts,$ossts);
     return 0;
