@@ -6,7 +6,7 @@ our (@ISA, $VERSION);
 $VERSION = '3.2701';
 $VERSION = eval $VERSION;
 
-my %module = (MacOS   => 'Mac',
+my %module = %(MacOS   => 'Mac',
 	      MSWin32 => 'Win32',
 	      os2     => 'OS2',
 	      VMS     => 'VMS',
@@ -20,7 +20,7 @@ my %module = (MacOS   => 'Mac',
 my $module = %module{$^O} || 'Unix';
 
 require "File/Spec/$module.pm";
-@ISA = ("File::Spec::$module");
+@ISA = @("File::Spec::$module");
 
 1;
 
