@@ -33,31 +33,31 @@ package Getopt::Long;
 
 use strict;
 
-use vars qw($VERSION);
+use vars < qw($VERSION);
 $VERSION        =  2.37;
 # For testing versions only.
-use vars qw($VERSION_STRING);
+use vars < qw($VERSION_STRING);
 $VERSION_STRING = "2.37";
 
 use Exporter;
-use vars qw(@ISA @EXPORT @EXPORT_OK);
-@ISA = @( qw(Exporter) );
+use vars < qw(@ISA @EXPORT @EXPORT_OK);
+@ISA = qw(Exporter);
 
 BEGIN {
     # Init immediately so their contents can be used in the 'use vars' below.
-    @EXPORT    = @( qw(&GetOptions $REQUIRE_ORDER $PERMUTE $RETURN_IN_ORDER) );
-    @EXPORT_OK = @( qw(&HelpMessage &VersionMessage &Configure
-		    &GetOptionsFromArray &GetOptionsFromString) );
+    @EXPORT    = qw(&GetOptions $REQUIRE_ORDER $PERMUTE $RETURN_IN_ORDER);
+    @EXPORT_OK = qw(&HelpMessage &VersionMessage &Configure
+		    &GetOptionsFromArray &GetOptionsFromString);
 }
 
 # User visible variables.
-use vars < @EXPORT, < @EXPORT_OK;
-use vars qw($error $debug $major_version $minor_version);
+our ($REQUIRE_ORDER, $PERMUTE, $RETURN_IN_ORDER);
+use vars < qw($error $debug $major_version $minor_version);
 # Deprecated visible variables.
-use vars qw($autoabbrev $getopt_compat $ignorecase $bundling $order
+use vars < qw($autoabbrev $getopt_compat $ignorecase $bundling $order
 	    $passthrough);
 # Official invisible variables.
-use vars qw($genprefix $caller $gnu_compat $auto_help $auto_version $longprefix);
+use vars < qw($genprefix $caller $gnu_compat $auto_help $auto_version $longprefix);
 
 ################ Local Variables ################
 
@@ -99,7 +99,7 @@ sub import {
     my @syms = @( () );		# symbols to import
     my @config = @( () );		# configuration
     my $dest = \@syms;		# symbols first
-    for ( < @_ ) {
+    for (  @_ ) {
 	if ( $_ eq ':config' ) {
 	    $dest = \@config;	# config next
 	    next;
@@ -108,7 +108,7 @@ sub import {
     }
     # Hide one level and call super.
     local $Exporter::ExportLevel = 1;
-    push(@syms, qw(&GetOptions)) if (nelems @syms); # always export GetOptions
+    push(@syms, < qw(&GetOptions)) if (nelems @syms); # always export GetOptions
     $pkg->SUPER::import(< @syms);
     # And configure.
     Configure(< @config) if (nelems @config);
@@ -117,7 +117,7 @@ sub import {
 ################ Initialization ################
 
 # Values for $order. See GNU getopt.c for details.
-($REQUIRE_ORDER, $PERMUTE, $RETURN_IN_ORDER) = (0..2);
+($REQUIRE_ORDER, $PERMUTE, $RETURN_IN_ORDER) = ( <0..2);
 # Version major/minor numbers.
 ($major_version, $minor_version) = $VERSION =~ m/^(\d+)\.(\d+)/;
 
@@ -129,9 +129,7 @@ package Getopt::Long::Parser;
 
 # Store a copy of the default configuration. Since ConfigDefaults has
 # just been called, what we get from Configure is the default.
-my $default_config = do {
-    Getopt::Long::Configure ()
-};
+my $default_config = &Getopt::Long::Configure ();
 
 sub new {
     my $that = shift;
@@ -139,7 +137,7 @@ sub new {
     my %atts = %( < @_ );
 
     # Register the callers package.
-    my $self = \%( caller_pkg => (caller)[[0]] );
+    my $self = \%( caller_pkg => @(caller)[0] );
 
     bless ($self, $class);
 
@@ -252,12 +250,12 @@ sub GetOptions(@) {
 sub GetOptionsFromString($@) {
     my ($string) = shift;
     require Text::ParseWords;
-    my $args = \@( < Text::ParseWords::shellwords($string) );
-    $caller ||= (caller)[[0]];	# current context
+    my $args = \ Text::ParseWords::shellwords($string);
+    $caller ||= @(caller)[0];	# current context
     my $ret = GetOptionsFromArray($args, < @_);
     if ( (nelems @$args) ) {
         $ret = 0;
-        warn("GetOptionsFromString: Excess data \"{join ' ', <@$args}\" in string \"$string\"\n");
+        warn("GetOptionsFromString: Excess data \"{join ' ',@$args}\" in string \"$string\"\n");
     }
     return $ret;
 }
@@ -285,7 +283,7 @@ sub GetOptionsFromArray($@) {
 	   '$Revision: 2.74 $', ") ",
 	   "called from package \"$pkg\".",
 	   "\n  ",
-	   "argv: ({join ' ', <@$argv})",
+	   "argv: ({join ' ',@$argv})",
 	   "\n  ",
 	   "autoabbrev=$autoabbrev,".
 	   "bundling=$bundling,",
@@ -336,7 +334,7 @@ sub GetOptionsFromArray($@) {
 	}
 
 	# Strip leading prefix so people can specify "--foo=i" if they like.
-	$opt = $+ if $opt =~ m/^$prefix+(.*)$/s;
+	$opt = $1 if $opt =~ m/^$prefix+(.*)$/s;
 
 	if ( $opt eq '<>' ) {
 	    if ( (defined $userlinkage)
@@ -388,7 +386,7 @@ sub GetOptionsFromArray($@) {
 
 	# Copy the linkage. If omitted, link to global variable.
 	if ( (nelems @optionlist) +> 0 && ref(@optionlist[0]) ) {
-	    print STDERR ("=> link \"$orig\" to @optionlist[0]\n")
+	    print STDERR ("=> link \"$orig\" to {dump::view(@optionlist[0])}\n")
 		if $debug;
 	    my $rl = ref(%linkage{$orig} = shift (@optionlist));
 
@@ -467,7 +465,8 @@ sub GetOptionsFromArray($@) {
 	my ($arrow, $k, $v);
 	$arrow = "=> ";
 	while ( ($k,$v) = each(%opctl) ) {
-	    print STDERR ($arrow, "\%opctl\{$k\} = {dump::view($v)} ", < dump::view( <OptCtl($v)), "\n");
+	    print STDERR ($arrow, "\%opctl\{$k\} = {dump::view($v)} ",
+                          dump::view(OptCtl($v)), "\n");
 	    $arrow = "   ";
 	}
     }
@@ -722,7 +721,7 @@ sub GetOptionsFromArray($@) {
     # Finish.
     if ( (nelems @ret) && $order == $PERMUTE ) {
 	#  Push back accumulated arguments
-	print STDERR ("=> restoring \"", join('" "', < @ret), "\"\n")
+	print STDERR ("=> restoring \"", join('" "', @ret), "\"\n")
 	    if $debug;
 	unshift (@$argv, < @ret);
     }
@@ -733,15 +732,15 @@ sub GetOptionsFromArray($@) {
 # A readable representation of what's in an optbl.
 sub OptCtl ($) {
     my ($v) = < @_;
-    my @v = @( map { defined($_) ? ($_) : ("<undef>") } < @$v );
+    my @v = map { defined($_) ? ($_) : ("<undef>") } @$v;
     "[".
-      join(",",
+      join(",", @(
 	   "\"@v[CTL_TYPE]\"",
 	   "\"@v[CTL_CNAME]\"",
 	   "\"@v[CTL_DEFAULT]\"",
-	   ("\$","\@","\%","\&")[[@v[CTL_DEST] || 0]],
+	   < @("\$","\@","\%","\&")[[@v[CTL_DEST] || @(0)]],
 	   @v[CTL_AMIN] || '',
-	   @v[CTL_AMAX] || '',
+	   @v[CTL_AMAX] || '',)
 #	   $v[CTL_RANGE] || '',
 #	   $v[CTL_REPEAT] || '',
 	  ). "]";
@@ -786,7 +785,7 @@ sub ParseOptionSpec ($$) {
 
     my @names;
     if ( defined $names ) {
-	@names = @(  split (m/\|/, $names) );
+	@names =  split (m/\|/, $names);
 	$orig = @names[0];
     }
     else {
@@ -841,7 +840,7 @@ sub ParseOptionSpec ($$) {
 
     # Process all names. First is canonical, the rest are aliases.
     my $dups = '';
-    foreach ( < @names ) {
+    foreach (  @names ) {
 
 	$_ = lc ($_)
 	  if $ignorecase +> (($bundling && length($_) == 1) ? 1 : 0);
@@ -853,7 +852,7 @@ sub ParseOptionSpec ($$) {
 	if ( $spec eq '!' ) {
 	    $opctl->{"no$_"} = $entry;
 	    $opctl->{"no-$_"} = $entry;
-	    $opctl->{$_} = \@(< @$entry);
+	    $opctl->{$_} = \$: @$entry;
 	    $opctl->{$_}->[CTL_TYPE] = '';
 	}
 	else {
@@ -883,7 +882,7 @@ sub FindOption ($$$$$) {
     return  @(0) unless $opt =~ m/^$prefix(.*)$/s;
     return  @(0) if $opt eq "-" && !defined $opctl->{''};
 
-    $opt = $+;
+    $opt = $2;
     my $starter = $1;
 
     print STDERR ("=> split \"$starter\"+\"$opt\"\n") if $debug;
@@ -932,22 +931,22 @@ sub FindOption ($$$$$) {
     # Try auto-abbreviation.
     elsif ( $autoabbrev ) {
 	# Sort the possible long option names.
-	my @names = @( sort(keys (%$opctl)) );
+	my @names = sort(keys (%$opctl));
 	# Downcase if allowed.
 	$opt = lc ($opt) if $ignorecase;
 	$tryopt = $opt;
 	# Turn option name into pattern.
 	my $pat = quotemeta ($opt);
 	# Look up in option names.
-	my @hits = @( grep (m/^$pat/, < @names) );
-	print STDERR ("=> ", scalar(nelems @hits), " hits ({join ' ', <@hits}) with \"$pat\" ",
+	my @hits = grep (m/^$pat/, @names);
+	print STDERR ("=> ", scalar(nelems @hits), " hits ({join ' ',@hits}) with \"$pat\" ",
 		      "out of ", scalar(nelems @names), "\n") if $debug;
 
 	# Check for ambiguous results.
-	unless ( ((nelems @hits) +<= 1) || (grep ($_ eq $opt, < @hits) == 1) ) {
+	unless ( ((nelems @hits) +<= 1) || (nelems grep ($_ eq $opt, @hits) == 1) ) {
 	    # See if all matches are for the same option.
 	    my %hit;
-	    foreach ( < @hits ) {
+	    foreach (  @hits ) {
 		my $hit = $_;
 		$hit = $opctl->{$hit}->[CTL_CNAME]
 		  if defined $opctl->{$hit}->[CTL_CNAME];
@@ -966,11 +965,11 @@ sub FindOption ($$$$$) {
 	    unless ( keys(%hit) == 1 ) {
 		return  @(0) if $passthrough;
 		warn ("Option ", $opt, " is ambiguous (",
-		      join(", ", < @hits), ")\n");
+		      join(", ", @hits), ")\n");
 		$error++;
 		return  @(1, undef);
 	    }
-	    @hits = @( keys(%hit) );
+	    @hits = keys(%hit);
 	}
 
 	# Complete the option name, if appropriate.
@@ -1002,7 +1001,7 @@ sub FindOption ($$$$$) {
     }
     # Apparently valid.
     $opt = $tryopt;
-    print STDERR ("=> found ", < OptCtl($ctl),
+    print STDERR ("=> found ", OptCtl($ctl),
 		  " for \"", $opt, "\"\n") if $debug;
 
     #### Determine argument status ####
@@ -1053,7 +1052,7 @@ sub FindOption ($$$$$) {
 	}
 	if ( $type eq 'I' ) {
 	    # Fake incremental type.
-	    my @c = @( < @$ctl );
+	    my @c = @$ctl;
 	    @c[CTL_TYPE] = '+';
 	    return  @(1, $opt, \@c, 1);
 	}
@@ -1116,7 +1115,7 @@ sub FindOption ($$$$$) {
 
 	if ( $bundling && defined $rest
 	     && $rest =~ m/^($key_valid)($o_valid)(.*)$/si ) {
-	    ($key, $arg, $rest) = ($1, $2, $+);
+	    ($key, $arg, $rest) = ($1, $2, $3);
 	    chop($key) if $key;
 	    $arg = ($type eq 'o' && $arg =~ m/^0/) ? oct($arg) : 0+$arg;
 	    unshift (@$argv, $starter.$rest) if defined $rest && $rest ne '';
@@ -1146,7 +1145,7 @@ sub FindOption ($$$$$) {
 		unshift (@$argv, defined $rest ? $starter.$rest : $arg);
 		if ( $type eq 'I' ) {
 		    # Fake incremental type.
-		    my @c = @( < @$ctl );
+		    my @c = @$ctl;
 		    @c[CTL_TYPE] = '+';
 		    return  @(1, $opt, \@c, 1);
 		}
@@ -1164,7 +1163,7 @@ sub FindOption ($$$$$) {
 	if ( $bundling && defined $rest &&
 	     $rest =~ m/^($key_valid)($o_valid)(.*)$/s ) {
 	    $arg =~ s/_//g;
-	    ($key, $arg, $rest) = ($1, $2, $+);
+	    ($key, $arg, $rest) = ($1, $2, $3);
 	    chop($key) if $key;
 	    unshift (@$argv, $starter.$rest) if defined $rest && $rest ne '';
 	}
@@ -1240,7 +1239,7 @@ sub ValidValue ($$$$$) {
 
 # Getopt::Long Configuration.
 sub Configure (@) {
-    my (@options) = @( < @_ );
+    my (@options) = @_;
 
     my $prevconfig =
       \@( $error, $debug, $major_version, $minor_version,
@@ -1256,12 +1255,12 @@ sub Configure (@) {
     }
 
     my $opt;
-    foreach $opt ( < @options ) {
+    foreach $opt (  @options ) {
 	my $try = lc ($opt);
 	my $action = 1;
 	if ( $try =~ m/^no_?(.*)$/s ) {
 	    $action = 0;
-	    $try = $+;
+	    $try = $1;
 	}
 	if ( ($try eq 'default' or $try eq 'defaults') && $action ) {
 	    ConfigDefaults ();
@@ -1459,12 +1458,6 @@ sub name {
     ''.$self->{name};
 }
 
-use overload
-  # Treat this object as an oridinary string for legacy API.
-  '""'	   => \&name,
-  '0+'	   => sub { 0 },
-  fallback => 1;
-
 1;
 
 ################ Documentation ################
