@@ -1,4 +1,4 @@
 $|++;
 print "# Child has TTY? " . (-t *STDIN ? "YES" : "NO" ) . $/;
-print $_ = <>;
+print $_ = ~< *ARGV;
 
