@@ -126,7 +126,7 @@ sub reload_loc { %Loc = %( () ) }
 sub load_loc {
     my ($class, < %args) = < @_;
 
-    my $pkg = join('::', grep { defined and length } %args{Class}, %args{Subclass});
+    my $pkg = join('::', grep { defined and length } @( %args{Class}, %args{Subclass}));
     return %Loc{$pkg} if exists %Loc{$pkg};
 
     try { require Locale::Maketext::Lexicon; 1 }   or return;
@@ -283,7 +283,7 @@ sub auto_path {
 
     # If that failed, try relative path with normal @INC searching.
     $path = "auto/$calldir/";
-    foreach my $inc (< @INC) {
+    foreach my $inc ( @INC) {
 	return "$inc/$path" if -d "$inc/$path";
     }
 
