@@ -5,8 +5,8 @@ our $VERSION = '1.01';
 our(@EXPORT, @EXPORT_OK, %EXPORT_TAGS);
 BEGIN {
     use Exporter   ();
-    @EXPORT      = @( qw(getservbyname getservbyport getservent getserv) );
-    @EXPORT_OK   = @( qw( $s_name @s_aliases $s_port $s_proto ) );
+    @EXPORT      = qw(getservbyname getservbyport getservent getserv);
+    @EXPORT_OK   = qw( $s_name @s_aliases $s_port $s_proto );
     %EXPORT_TAGS = %( FIELDS => \@( < @EXPORT_OK, < @EXPORT ) );
 }
 use vars      < @EXPORT_OK;
@@ -14,7 +14,7 @@ use vars      < @EXPORT_OK;
 # Class::Struct forbids use of @ISA
 sub import { goto &Exporter::import }
 
-use Class::Struct qw(struct);
+use Class::Struct < qw(struct);
 struct 'Net::servent' => \@(
    name		=> '$',
    aliases	=> '@',
@@ -26,7 +26,7 @@ sub populate (@) {
     return unless (nelems @_);
     my $sob = new();
     $s_name 	 =    $sob->[0]     	     = @_[0];
-    @s_aliases	 = @( @{ $sob->[1] } = @( split ' ', @_[1] ) );
+    @s_aliases	 = @( @{ $sob->[1] } = split ' ', @_[1] );
     $s_port	 =    $sob->[2] 	     = @_[2];
     $s_proto	 =    $sob->[3] 	     = @_[3];
     return $sob;
