@@ -28,14 +28,13 @@ package Pod::Man;
 
 use strict;
 use utf8;
-use subs qw(makespace);
-use vars qw(@ISA %ESCAPES $PREAMBLE $VERSION);
+use vars < qw(@ISA %ESCAPES $PREAMBLE $VERSION);
 
-use Carp qw(croak);
+use Carp < qw(croak);
 use Pod::Simple ();
-use POSIX qw(strftime);
+use POSIX < qw(strftime);
 
-@ISA = @( qw(Pod::Simple) );
+@ISA = qw(Pod::Simple);
 
 # Don't use the CVS revision as the version, since this module is also in Perl
 # core and too many things could munge CVS magic revision strings.  This
@@ -84,7 +83,7 @@ sub new {
     }
 
     # The =for and =begin targets that we accept.
-    $self->accept_targets (qw/man MAN roff ROFF/);
+    $self->accept_targets ( <qw/man MAN roff ROFF/);
 
     # Ensure that contiguous blocks of code are merged together.  Otherwise,
     # some of the guesswork heuristics don't work right.
@@ -241,7 +240,7 @@ sub method_for_element {
 # text and nested elements.  Otherwise, if start_element is defined, call it.
 sub _handle_element_start {
     my ($self, $element, $attrs) = < @_;
-    DEBUG +> 3 and print "++ $element (<", join ('> <', < %$attrs), ">)\n";
+    DEBUG +> 3 and print "++ $element (<", join ('> <', %$attrs), ">)\n";
     my $method = $self->method_for_element ($element);
 
     # If we have a command handler, we need to accumulate the contents of the
@@ -615,7 +614,7 @@ sub switchquotes {
     # Also separate troff from nroff if there are any fixed-width fonts in use
     # to work around problems with Solaris nroff.
     my $c_is_quote = (%$self{LQUOTE} =~ m/\"/) || (%$self{RQUOTE} =~ m/\"/);
-    my $fixedpat = join '|', %{ %$self{FONTS} }{['100', '101', '110', '111']};
+    my $fixedpat = join '|', %{ %$self{FONTS} }{[@('100', '101', '110', '111')]};
     $fixedpat =~ s/\\/\\\\/g;
     $fixedpat =~ s/\(/\\\(/g;
     if ($text =~ m/\"/ || $text =~ m/$fixedpat/) {
@@ -682,7 +681,7 @@ sub makespace {
 # strip special escapes from index entries.
 sub outindex {
     my ($self, $section, $index) = < @_;
-    my @entries = @( map { split m%\s*/\s*% } < @{ %$self{INDEX} } );
+    my @entries = map { < split m%\s*/\s*% } @{ %$self{INDEX} };
     return unless ($section || nelems @entries);
 
     # We're about to output all pending entries, so clear our pending queue.
@@ -692,7 +691,7 @@ sub outindex {
     # pass in their own section.  Undo some *roff formatting on headings.
     my @output;
     if ((nelems @entries)) {
-        push @output, \@( 'Xref', join (' ', < @entries) );
+        push @output, \@( 'Xref', join (' ', @entries) );
     }
     if ($section) {
         $index =~ s/\\-/-/g;
@@ -701,7 +700,7 @@ sub outindex {
     }
 
     # Print out the .IX commands.
-    for (< @output) {
+    for ( @output) {
         my ($type, $entry) = < @$_;
         $entry =~ s/\"/\"\"/g;
         $self->output (".IX $type " . '"' . $entry . '"' . "\n");
@@ -792,7 +791,7 @@ sub devise_title {
     } else {
         require File::Spec;
         my ($volume, $dirs, $file) = < File::Spec->splitpath ($name);
-        my @dirs = @( < File::Spec->splitdir ($dirs) );
+        my @dirs = File::Spec->splitdir ($dirs);
         my $cut = 0;
         my $i;
         for ($i = 0; $i +< nelems @dirs; $i++) {
@@ -813,7 +812,7 @@ sub devise_title {
 
         # Remove empty directories when building the module name; they
         # occur too easily on Unix by doubling slashes.
-        $name = join ('::', (grep { $_ ? $_ : () } < @dirs), $file);
+        $name = join ('::', @( (< grep { $_ ? $_ : () } @dirs), $file));
     }
     return  @($name, $section);
 }
@@ -828,11 +827,11 @@ sub devise_date {
     my $input = $self->source_filename;
     my $time;
     if ($input) {
-        $time = (stat $input)[[9]] || time;
+        $time = @(stat $input)[9] || time;
     } else {
         $time = time;
     }
-    return strftime ('%Y-%m-%d', localtime $time);
+    return strftime('%Y-%m-%d', localtime $time);
 }
 
 # Print out the preamble and the title.  The meaning of the arguments to .TH
@@ -853,7 +852,7 @@ sub preamble {
 
     # If name or section contain spaces, quote them (section really never
     # should, but we may as well be cautious).
-    for ($name, $section) {
+    for (@($name, $section)) {
         if (m/\s/) {
             s/\"/\"\"/g;
             $_ = '"' . $_ . '"';
@@ -946,9 +945,9 @@ sub cmd_verbatim {
     # we'll pass to .Vb as its parameter.  This tells *roff to keep that many
     # lines together.  We don't want to tell *roff to keep huge blocks
     # together.
-    my @lines = @( split (m/\n/, $text) );
+    my @lines = split (m/\n/, $text);
     my $unbroken = 0;
-    for (< @lines) {
+    for ( @lines) {
         last if m/^\s*$/;
         $unbroken++;
     }
@@ -1255,7 +1254,7 @@ sub parse_from_filehandle {
     my $self = shift;
     $self->parse_from_file (< @_);
 }
-
+ <
 ##############################################################################
 # Translation tables
 ##############################################################################
