@@ -15,7 +15,7 @@ sub output_extension   { 'txt' }  # override in subclass!
 
 sub _perldoc_elem {
   my($self, $name) = splice @_,0,2;
-  if(@_) {
+  if((nelems @_)) {
     $self->{$name} = @_[0];
   } else {
     $self->{$name};
