@@ -2,7 +2,7 @@
 package Pod::Perldoc::ToChecker;
 use strict;
 use warnings;
-use vars qw(@ISA);
+use vars < qw(@ISA);
 
 # Pick our superclass...
 #
