@@ -3,7 +3,7 @@ package Pod::Perldoc::ToText;
 use strict;
 use warnings;
 
-use base qw(Pod::Perldoc::BaseTo);
+use base < qw(Pod::Perldoc::BaseTo);
 
 sub is_pageable        { 1 }
 sub write_with_binmode { 0 }
@@ -23,10 +23,9 @@ sub new { return bless \%(), ref(@_[0]) || @_[0] }
 sub parse_from_file {
   my $self = shift;
   
-  my @options = @(
-    map {; $_, $self->{$_} }
-      grep !m/^_/s,
-        keys %$self )
+  my @options = map {; $_, $self->{$_} }
+ grep !m/^_/s,
+        keys %$self
   ;
   
   defined(&Pod::Perldoc::DEBUG)
@@ -34,7 +33,7 @@ sub parse_from_file {
    and print "About to call new Pod::Text ",
     $Pod::Text::VERSION ? "(v$Pod::Text::VERSION) " : '',
     "with options: ",
-    (nelems @options) ? "[{join ' ', <@options}]" : "(nil)", "\n";
+    (nelems @options) ? "[{join ' ',@options}]" : "(nil)", "\n";
   ;
 
   Pod::Text->new(< @options)->parse_from_file(< @_);
