@@ -2,9 +2,9 @@
 package Pod::Perldoc::ToXml;
 use strict;
 use warnings;
-use vars qw($VERSION);
+use vars < qw($VERSION);
 
-use base qw( Pod::Simple::XMLOutStream );
+use base < qw( Pod::Simple::XMLOutStream );
 
 $VERSION   # so that ->VERSION is happy
 # stop CPAN from seeing this
