@@ -1,10 +1,10 @@
 package Pod::Plainer;
 use strict;
 use Pod::Parser;
-our @ISA = @( qw(Pod::Parser) );
+our @ISA = qw(Pod::Parser);
 our $VERSION = '0.01';
 
-our %E = %( qw( < lt > gt ) );
+our %E = %( < qw( < lt > gt ) );
  
 sub escape_ltgt {
     (undef, my $text) = < @_;
