@@ -8,7 +8,7 @@ use Pod::Simple::LinkSection ();
 use Pod::Simple::BlackBox ();
 use utf8;
 
-use vars qw(
+use vars < qw(
   $VERSION @ISA
   @Known_formatting_codes  @Known_directives
   %Known_formatting_codes  %Known_directives
@@ -18,10 +18,10 @@ use vars qw(
 @ISA = @('Pod::Simple::BlackBox');
 $VERSION = '3.05';
 
-@Known_formatting_codes = @( qw(I B C L E F S X Z) ); 
-%Known_formatting_codes = %( map(($_=>1), < @Known_formatting_codes) );
-@Known_directives       = @( qw(head1 head2 head3 head4 item over back) ); 
-%Known_directives       = %( map(($_=>'Plain'), < @Known_directives) );
+@Known_formatting_codes = qw(I B C L E F S X Z); 
+%Known_formatting_codes = %( < map(($_=>1), @Known_formatting_codes) );
+@Known_directives       = qw(head1 head2 head3 head4 item over back); 
+%Known_directives       = %( < map(($_=>'Plain'), @Known_directives) );
 $NL = $/ unless defined $NL;
 
 #-----------------------------------------------------------------------------
@@ -106,10 +106,8 @@ sub any_errata_seen {  # good for using as an exit() value...
 
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 # Pull in some functions that, for some reason, I expect to see here too:
-BEGIN {
-  *pretty        = \&Pod::Simple::BlackBox::pretty;
-  *stringify_lol = \&Pod::Simple::BlackBox::stringify_lol;
-}
+sub pretty { Pod::Simple::BlackBox::pretty(< @_) }
+sub stringify_lol { Pod::Simple::BlackBox::stringify_lol(< @_); }
 
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
 
@@ -161,7 +159,7 @@ sub new {
   #Carp::croak(__PACKAGE__ . " is a virtual base class -- see perldoc "
   #  . __PACKAGE__ );
   return bless \%(
-    'accept_codes'      => \%( map( ($_=>$_), < @Known_formatting_codes ) ),
+    'accept_codes'      => \%( < map( ($_=>$_), @Known_formatting_codes ) ),
     'accept_directives' => \%( < %Known_directives ),
     'accept_targets'    => \%(),
   ), $class;
@@ -198,7 +196,7 @@ sub accept_directive_as_processed { shift->_accept_directives('Plain',    < @_)
 
 sub _accept_directives {
   my($this, $type) = splice @_,0,2;
-  foreach my $d (< @_) {
+  foreach my $d ( @_) {
     next unless defined $d and length $d;
     die "\"$d\" isn't a valid directive name"
      unless $d =~ m/^[a-zA-Z][a-zA-Z0-9]*$/s;
@@ -210,7 +208,7 @@ sub _accept_directives {
   DEBUG +> 6 and print "$this\'s accept_directives : ", <
    pretty($this->{'accept_directives'}), "\n";
   
-  return @( sort keys %{ $this->{'accept_directives'} });
+  return sort keys %{ $this->{'accept_directives'} };
 }
 
 #--------------------------------------------------------------------------
@@ -220,7 +218,7 @@ sub unaccept_directive { shift->unaccept_directives(< @_) };
 
 sub unaccept_directives {
   my $this = shift;
-  foreach my $d (< @_) {
+  foreach my $d ( @_) {
     next unless defined $d and length $d;
     die "\"$d\" isn't a valid directive name"
      unless $d =~ m/^[a-zA-Z][a-zA-Z0-9]*$/s;
@@ -229,7 +227,7 @@ sub unaccept_directives {
     delete $this->{'accept_directives'}->{$d};
     DEBUG +> 2 and print "OK, won't accept \"=$d\" as directive.\n";
   }
-  return @( sort keys %{ $this->{'accept_directives'} });
+  return sort keys %{ $this->{'accept_directives'} };
 }
 
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@ -247,13 +245,13 @@ sub accept_targets_as_text { shift->_accept_targets('force_resolve', < @_) }
 
 sub _accept_targets {
   my($this, $type) = splice @_,0,2;
-  foreach my $t (< @_) {
+  foreach my $t ( @_) {
     next unless defined $t and length $t;
     # TODO: enforce some limitations on what a target name can be?
     $this->{'accept_targets'}->{$t} = $type;
     DEBUG +> 2 and print "Learning to accept \"$t\" as target of type $type\n";
   }    
-  return @( sort keys %{ $this->{'accept_targets'} });
+  return sort keys %{ $this->{'accept_targets'} };
 }
 
 #--------------------------------------------------------------------------
@@ -261,13 +259,13 @@ sub unaccept_target         { shift->unaccept_targets(< @_) }
 
 sub unaccept_targets {
   my $this = shift;
-  foreach my $t (< @_) {
+  foreach my $t ( @_) {
     next unless defined $t and length $t;
     # TODO: enforce some limitations on what a target name can be?
     delete $this->{'accept_targets'}->{$t};
     DEBUG +> 2 and print "OK, won't accept \"$t\" as target.\n";
   }    
-  return @( sort keys %{ $this->{'accept_targets'} });
+  return sort keys %{ $this->{'accept_targets'} };
 }
 
 #@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
@@ -279,7 +277,7 @@ sub accept_code { shift->accept_codes(< @_) } # alias
 sub accept_codes {  # Add some codes
   my $this = shift;
   
-  foreach my $new_code (< @_) {
+  foreach my $new_code ( @_) {
     next unless defined $new_code and length $new_code;
     if(ASCII) {
       # A good-enough check that it's good as an XML Name symbol:
@@ -314,7 +312,7 @@ sub unaccept_code { shift->unaccept_codes(< @_) }
 sub unaccept_codes { # remove some codes
   my $this = shift;
   
-  foreach my $new_code (< @_) {
+  foreach my $new_code ( @_) {
     next unless defined $new_code and length $new_code;
     if(ASCII) {
       # A good-enough check that it's good as an XML Name symbol:
@@ -329,7 +327,7 @@ sub unaccept_codes { # remove some codes
     }
     
     die "But you must accept \"$new_code\" codes -- it's a builtin!"
-     if grep $new_code eq $_, < @Known_formatting_codes;
+     if grep $new_code eq $_, @Known_formatting_codes;
 
     delete $this->{'accept_codes'}->{$new_code};
 
@@ -346,7 +344,7 @@ sub unaccept_codes { # remove some codes
 sub parse_string_document {
   my $self = shift;
   my @lines;
-  foreach my $line_group (< @_) {
+  foreach my $line_group ( @_) {
     next unless defined $line_group and length $line_group;
     pos($line_group) = 0;
     while($line_group =~
@@ -617,7 +615,7 @@ sub _wrap_up {
       ) {
         DEBUG +> 3 and print "   Merging ", $i-1,
          ":[$treelet->[$i-1]] and $i\:[$treelet->[$i]]\n";
-        $treelet->[$i-1] .= ( splice(@$treelet, $i, 1) )[[0]];
+        $treelet->[$i-1] .= @(splice(@$treelet, $i, 1))[0];
         DEBUG +> 4 and print "    Now: ", $i-1, ":[$treelet->[$i-1]]\n";
         --$i;
         next; 
@@ -630,7 +628,7 @@ sub _wrap_up {
 
         if($treelet->[$i]->[0] eq 'L') {
           my $thing;
-          foreach my $attrname ('section', 'to') {        
+          foreach my $attrname (@('section', 'to')) {        
             if(defined($thing = $treelet->[$i]->[1]->{$attrname}) and ref $thing) {
               unshift @stack, $thing;
               DEBUG +> 4 and print "  +Enqueuing ", <
@@ -667,7 +665,7 @@ sub _remap_sequences {
   ;
   DEBUG +> 3 and print " Map: ",
     join('; ', map "$_=" . (
-        ref($map->{$_}) ? join(",", < @{$map->{$_}}) : $map->{$_}
+        ref($map->{$_}) ? join(",", @{$map->{$_}}) : $map->{$_}
       ),
       sort keys %$map ),
     ("B~C~E~F~I~L~S~X~Z" eq join '~', sort keys %$map)
@@ -693,7 +691,7 @@ sub _remap_sequences {
         } else  {
           print "   Code $was<> maps to ",
            ref($is)
-            ? ( "tags ", map("$_<", < @$is), '...', map('>', < @$is), "\n" )
+            ? ( "tags ", < map("$_<", @$is), '...', < map('>', @$is), "\n" )
             : "tag $is<...>.\n";
         }
       }
@@ -705,7 +703,7 @@ sub _remap_sequences {
         # children of this node, but something about that seems icky.
       }
       if(ref $is) {
-        my @dynasty = @( < @$is );
+        my @dynasty = @$is;
         DEBUG +> 4 and print "    Renaming $was node to @dynasty[-1]\n"; 
         $treelet->[$i]->[0] = pop @dynasty;
         my $nugget;
@@ -752,7 +750,7 @@ sub _ponder_extend {
   #  -- /Oblique Strategies/,  Brian Eno and Peter Schmidt
   
   my($self, $para) = < @_;
-  my $content = join ' ', splice @$para, 2;
+  my $content = join ' ', @( splice @$para, 2);
   $content =~ s/^\s+//s;
   $content =~ s/\s+$//s;
 
@@ -784,7 +782,7 @@ sub _ponder_extend {
       return;
     }
     
-    if(grep $new_letter eq $_, < @Known_formatting_codes) {
+    if(grep $new_letter eq $_, @Known_formatting_codes) {
       DEBUG +> 2 and print " $new_letter isn't a good thing to extend, because known.\n";
       $self->whine(
         $para->[1]->{'start_line'},
@@ -817,10 +815,10 @@ sub _ponder_extend {
       return;
     }
 
-    my @fallbacks  = @( split ',', $fallbacks_one,  -1 );
-    my @elements   = @( split ',', $elements_one, -1 );
+    my @fallbacks  = split ',', $fallbacks_one,  -1;
+    my @elements   = split ',', $elements_one, -1;
 
-    foreach my $f (< @fallbacks) {
+    foreach my $f ( @fallbacks) {
       next if exists %Known_formatting_codes{$f} or $f eq '0' or $f eq '1';
       DEBUG +> 2 and print "  Can't fall back on unknown code $f\n";
       $self->whine(
@@ -834,7 +832,7 @@ sub _ponder_extend {
      < @fallbacks, < @elements;
 
     my $canonical_form;
-    foreach my $e (< @elements) {
+    foreach my $e ( @elements) {
       if(exists $self->{'accept_codes'}->{$e}) {
         DEBUG +> 1 and print " Mapping '$new_letter' to known extension '$e'\n";
         $canonical_form = $e;
@@ -855,7 +853,7 @@ sub _ponder_extend {
       $self->{'accept_codes'}->{$new_letter}
         = ((nelems @fallbacks) == 1) ? @fallbacks[0] : \@fallbacks;
       DEBUG +> 2 and print
-       "Extensor maps $new_letter => fallbacks {join ' ', <@fallbacks}.\n";
+       "Extensor maps $new_letter => fallbacks {join ' ',@fallbacks}.\n";
     }
 
   } else {
@@ -887,7 +885,7 @@ sub _treat_Zs {  # Nix Z<...>'s
         next;
       }
         
-      DEBUG +> 1 and print "Nixing Z node {join ' ', <@{$treelet->[$i]}}\n";
+      DEBUG +> 1 and print "Nixing Z node {join ' ',@{$treelet->[$i]}}\n";
         
       # bitch UNLESS it's empty
       unless(  (nelems @{$treelet->[$i]}) == 2
@@ -1083,7 +1081,7 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
       
       my $link_text; # set to an arrayref if found
       my $ell = $treelet->[$i];
-      my @ell_content = @( < @$ell );
+      my @ell_content = @$ell;
       splice @ell_content,0,2; # Knock off the 'L' and {} bits
 
       DEBUG +> 3 and print " Ell content to start: ", <
@@ -1108,8 +1106,8 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
 
           unshift @link_text, splice @ell_content, 0, $j;
             # leaving only things at J and after
-          @ell_content = @(  grep ref($_)||length($_), < @ell_content ) ;
-          $link_text   = \@(grep ref($_)||length($_), < @link_text  );
+          @ell_content = grep ref($_)||length($_), @ell_content ;
+          $link_text   = \ grep ref($_)||length($_), @link_text;
           DEBUG +> 3 and printf
            "  So link text is \%s\n  and remaining ell content is \%s\n", <
             pretty($link_text), < pretty(< @ell_content);
@@ -1139,8 +1137,8 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
           push @section_name, splice @ell_content, 1+$j;
             # leaving only things before and including J
           
-          @ell_content  = @( grep ref($_)||length($_), < @ell_content )  ;
-          @section_name = @( grep ref($_)||length($_), < @section_name ) ;
+          @ell_content  = grep ref($_)||length($_), @ell_content  ;
+          @section_name = grep ref($_)||length($_), @section_name ;
 
           # Turn L<.../"foo"> into L<.../foo>
           if((nelems @section_name)
@@ -1181,7 +1179,7 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
 
       # Turn L<Foo Bar> into L</Foo Bar>.
       if(!$section_name and !$link_text and nelems @ell_content
-         and grep !ref($_) && m/ /s, < @ell_content
+         and grep !ref($_) && m/ /s, @ell_content
       ) {
         $section_name = \@(splice @ell_content);
         # That's support for the now-deprecated syntax.
@@ -1233,7 +1231,7 @@ sub _treat_Ls {  # Process our dear dear friends, the L<...> sequences
       }
       
       # And update children to be the link-text:
-      @$ell = @(@$ell[[0,1]], defined($link_text) ? splice(@$link_text) : '');
+      @$ell = @( <@$ell[[@(0,1)]], defined($link_text) ? splice(@$link_text) : '');
       
       DEBUG +> 2 and print "End of L-parsing for this node $treelet->[$i]\n";
 
@@ -1266,7 +1264,7 @@ sub _treat_Es {
         # SPECIAL STUFF for semi-processed L<>'s
         
         my $thing;
-        foreach my $attrname ('section', 'to') {        
+        foreach my $attrname (@('section', 'to')) {        
           if(defined($thing = $treelet->[$i]->[1]->{$attrname}) and ref $thing) {
             unshift @stack, $thing;
             DEBUG +> 2 and print "  Enqueuing ", <
@@ -1382,7 +1380,7 @@ sub _change_S_to_nbsp { #  a recursive function
 
 sub _accessorize {  # A simple-minded method-maker
   no strict 'refs';
-  foreach my $attrname (< @_) {
+  foreach my $attrname ( @_) {
     next if $attrname =~ m/::/; # a hack
     *{Symbol::fetch_glob(caller() . '::' . $attrname)} = sub {
       use strict;
@@ -1436,7 +1434,7 @@ sub _out {
 
   my $out = '';
   $parser->output_string( \$out );
-  DEBUG and print " _out to ", \$out, "\n";
+  DEBUG and print " _out to ", dump::view(\$out), "\n";
   
   $mutor->($parser) if $mutor;
 
@@ -1455,7 +1453,7 @@ sub _duo {
   
   my $mutor = shift(@_) if (nelems @_) and ref(@_[0] || '') eq 'CODE';
 
-  die "But $class->_duo takes two parameters, not: {join ' ', <@_}"
+  die "But $class->_duo takes two parameters, not: {join ' ',@_}"
    unless (nelems @_) == 2;
 
   my(@out);
