@@ -2,7 +2,7 @@
 package Pod::Simple::HTML;
 use strict;
 use Pod::Simple::PullParser ();
-use vars qw(
+use vars < qw(
   @ISA %Tagmap $Computerese $LamePad $Linearization_Limit $VERSION
   $Perldoc_URL_Prefix $Perldoc_URL_Postfix
   $Title_Prefix $Title_Postfix $HTML_EXTENSION %ToIndex
@@ -38,7 +38,7 @@ $Perldoc_URL_Postfix = ''
 
 $Title_Prefix  = '' unless defined $Title_Prefix;
 $Title_Postfix = '' unless defined $Title_Postfix;
-%ToIndex = %( map {; $_ => 1 } qw(head1 head2 head3 head4 ) ); # item-text
+%ToIndex = %( < map {; $_ => 1 } qw(head1 head2 head3 head4 ) ); # item-text
   # 'item-text' stuff in the index doesn't quite work, and may
   # not be a good idea anyhow.
 
@@ -106,7 +106,7 @@ my @_to_accept;
   'X'  => "<!--\n\tINDEX: ",
   '/X' => "\n-->", <
 
-  changes(qw(
+  changes( <qw(
     Para=p
     B=b I=i
     over-bullet=ul
@@ -118,7 +118,7 @@ my @_to_accept;
     item-text=dt
   )), <
   changes2(
-    map {; m/^([-a-z]+)/s && push @_to_accept, $1; $_ }
+    < map {; m/^([-a-z]+)/s && push @_to_accept, $1; $_ }
     qw[
       sample=samp
       definition=dfn
@@ -152,14 +152,14 @@ my @_to_accept;
 );
 
 sub changes {
-  return @( map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
+  return map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
      ? ( $1, => "\n<$2>", "/$1", => "</$2>\n" ) : die "Funky $_"
-  } < @_ );
+  } @_;
 }
 sub changes2 {
-  return @( map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
+  return map {; m/^([-_:0-9a-zA-Z]+)=([-_:0-9a-zA-Z]+)$/s
      ? ( $1, => "<$2>", "/$1", => "</$2>" ) : die "Funky $_"
-  } < @_ );
+  } @_;
 }
 
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
@@ -175,7 +175,7 @@ sub new {
   $new->accept_targets( 'html', 'HTML' );
   $new->accept_codes('VerbatimFormatted');
   $new->accept_codes(< @_to_accept);
-  DEBUG +> 2 and print "To accept: ", join(' ',< @_to_accept), "\n";
+  DEBUG +> 2 and print "To accept: ", join(' ', @_to_accept), "\n";
 
   $new->perldoc_url_prefix(  $Perldoc_URL_Prefix  );
   $new->perldoc_url_postfix( $Perldoc_URL_Postfix );
@@ -185,12 +185,12 @@ sub new {
   $new->html_header_before_title(
    qq[$Doctype_decl<html><head><title>]
   );
-  $new->html_header_after_title( join "\n" =>
+  $new->html_header_after_title( join "\n", @( 
     "</title>",
     $Content_decl,
     "</head>\n<body class='pod'>",
     $new->version_tag_comment,
-    "<!-- start doc -->\n",
+    "<!-- start doc -->\n",)
   );
   $new->html_footer( qq[\n<!-- end doc -->\n\n</body></html>\n] );
 
@@ -289,16 +289,16 @@ sub version_tag_comment {
   my $self = shift;
   return sprintf
    "<!--\n  generated by \%s v\%s,\n  using \%s v\%s,\n  under Perl v\%s at \%s GMT.\n\n \%s\n\n-->\n",
-   (map { esc($_) }
-    ref($self), $self->VERSION(), @ISA[0], @ISA[0]->VERSION(),
-    $^V, scalar(gmtime),
+   (< map { esc($_) }
+ @(    ref($self), $self->VERSION(), @ISA[0], @ISA[0]->VERSION(),
+    $^V, scalar(gmtime),)
    ), $self->_modnote(),
   ;
 }
 
 sub _modnote {
   my $class = ref(@_[0]) || @_[0];
-  return join "\n   " => grep m/\S/, split "\n",
+  return join "\n   ", grep m/\S/, split "\n",
 
 qq{
 If you want to change this HTML document, you probably shouldn't do that
@@ -381,7 +381,7 @@ sub index_as_html {
   my $level = 0;
 
   my( $target_level, $previous_tagname, $tagname, $text, $anchorname, $indent);
-  foreach my $p (< @$points, \@('head0', '(end)')) {
+  foreach my $p ( @( < @$points, \@('head0', '(end)') ) ) {
     ($tagname, $text) = < @$p;
     $anchorname = $self->section_escape($text);
     if( $tagname =~ m{^head(\d+)$} ) {
@@ -411,7 +411,7 @@ sub index_as_html {
     ;
   }
   push @out, "</div>\n";
-  return join "\n", < @out;
+  return join "\n", @out;
 }
 
 ###########################################################################
@@ -649,7 +649,7 @@ sub pagepath_url_escape { shift->general_url_escape(< @_) }
 sub general_url_escape {
   my($self, $string) = < @_;
  
-  $string =~ s/([^\x[00]-\x[FF]])/{join '', map sprintf('%%%02X',$_), unpack 'C*', $1}/g;
+  $string =~ s/([^\x[00]-\x[FF]])/{join '', map sprintf('%%%02X',$_), @( unpack 'C*', $1)}/g;
      # express Unicode things as urlencode(utf(orig)).
   
   # A pretty conservative escaping, behoovey even for query components
@@ -694,13 +694,13 @@ sub resolve_pod_page_link_singleton_mode {
 sub resolve_pod_page_link_batch_mode {
   my($self, $to) = < @_;
   DEBUG +> 1 and print " During batch mode, resolving $to ...\n";
-  my @path = @( grep length($_), split m/::/s, $to, -1 );
+  my @path = grep length($_), split m/::/s, $to, -1;
   unless( nelems @path ) { # sanity
     DEBUG and print "Very odd!  Splitting $to gives (nil)!\n";
     return undef;
   }
   $self->batch_mode_rectify_path(\@path);
-  my $out = join('/', map < $self->pagepath_url_escape($_), < @path)
+  my $out = join('/', map < $self->pagepath_url_escape($_), @path)
     . $HTML_EXTENSION;
   DEBUG +> 1 and print " => $out\n";
   return $out;
