@@ -1,7 +1,7 @@
 
 package Pod::Simple::HTMLBatch;
 use strict;
-use vars qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
+use vars < qw( $VERSION $HTML_RENDER_CLASS $HTML_EXTENSION
  $CSS $JAVASCRIPT $SLEEPY $SEARCH_CLASS @ISA
 );
 $VERSION = '3.02';
@@ -82,22 +82,22 @@ sub new {
     'index' . ($HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION)
   );
   
-  $new->contents_page_start( join "\n", grep $_,
+  $new->contents_page_start( join "\n", grep $_, @(
     $Pod::Simple::HTML::Doctype_decl,
     "<html><head>",
     "<title>Perl Documentation</title>",
     $Pod::Simple::HTML::Content_decl,
     "</head>",
-    "\n<body class='contentspage'>\n<h1>Perl Documentation</h1>\n"
+    "\n<body class='contentspage'>\n<h1>Perl Documentation</h1>\n")
   ); # override if you need a different title
   
   
   $new->contents_page_end( sprintf(
     "\n\n<p class='contentsfooty'>Generated by \%s v\%s under Perl v\%s\n<br >At \%s GMT, which is \%s local time.</p>\n\n</body></html>\n",
-    (map { esc($_) }
-      ref($new),
+    (< map { esc($_) }
+ @(      ref($new),
       try {$new->VERSION} || $VERSION,
-      $^V, scalar(gmtime), scalar(localtime), 
+      $^V, scalar(gmtime), scalar(localtime),) 
   )));
 
   return $new;
@@ -130,7 +130,7 @@ sub batch_convert {
     #  or, under MSWin, like "c:/thing;d:/also;c:/whatever/perl" (";"-delim!)
     require Config;
     my $ps = quotemeta( %Config::Config{'path_sep'} || ":" );
-    $dirs = \@( grep length($_), split qr/$ps/, $dirs );
+    $dirs = \ grep length($_), split qr/$ps/, $dirs;
   }
 
   $outdir = $self->filespecsys->curdir
@@ -163,7 +163,7 @@ sub _batch_convert_main {
   }
   
   if($dirs) {
-    $self->muse(scalar(nelems @$dirs), " dirs to scan: {join ' ', <@$dirs}");
+    $self->muse(scalar(nelems @$dirs), " dirs to scan: {join ' ',@$dirs}");
   } else {
     $self->muse("Scanning \@INC.  This could take a minute or two.");
   }
@@ -223,13 +223,13 @@ sub _do_one_batch_conversion {
   my $retval;
   my $total    = nkeys %$mod2path;
   my $infile   = $mod2path->{$module};
-  my @namelets = @( grep m/\S/, split "::", $module );
+  my @namelets = grep m/\S/, split "::", $module;
         # this can stick around in the contents LoL
   my $depth    = scalar nelems @namelets;
   die "Contentless thingie?! $module $infile" unless (nelems @namelets); #sanity
     
   $outfile  ||= do {
-    my @n = @( < @namelets );
+    my @n = @namelets;
     @n[-1] .= $HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION;
     $self->filespecsys->catfile( $outdir, < @n );
   };
@@ -291,10 +291,10 @@ sub note_for_contents_file {
   if( $self->contents_file ) {
     my $c = $self->_contents();
     push @$c,
-     \@( join("::", < @$namelets), $infile, $outfile, $namelets )
+     \@( join("::", @$namelets), $infile, $outfile, $namelets )
      #            0               1         2         3
     ;
-    DEBUG +> 3 and print "Noting @$c[[-1]]\n";
+    DEBUG +> 3 and print "Noting  <@$c[[@(-1)]]\n";
   }
   return;
 }
@@ -357,17 +357,17 @@ sub _write_contents_middle {
   my($self, $Contents, $outfile, $toplevel2submodules, $toplevel_form_freq) = < @_;
 
   foreach my $t (sort keys %$toplevel2submodules) {
-    my @downlines = @( sort {$a->[-1] cmp $b->[-1]}
-                          < @{ $toplevel2submodules->{$t} } );
+    my @downlines = sort {$a->[-1] cmp $b->[-1]}
+ @{ $toplevel2submodules->{$t} };
     
     printf $Contents qq[<dt><a name="\%s">\%s</a></dt>\n<dd>\n],
       esc( $t ), esc( $toplevel_form_freq->{$t} )
     ;
     
     my($path, $name);
-    foreach my $e (< @downlines) {
+    foreach my $e ( @downlines) {
       $name = $e->[0];
-      $path = join( "/", '.', map { esc($_) } < @{$e->[3]} )
+      $path = join( "/", @( '.', < map { esc($_) } @{$e->[3]}) )
         . ($HTML_EXTENSION || $Pod::Simple::HTML::HTML_EXTENSION);
       print $Contents qq{  <a href="$path">}, esc($name), "</a>&nbsp;&nbsp;\n";
     }
@@ -399,7 +399,7 @@ sub _prep_contents_breakdown {
   my %toplevel_form_freq; # ends up being  'foo' => 'Foo'
                                # (mapping anycase forms to most freq form)
   
-  foreach my $entry (< @$contents) {
+  foreach my $entry ( @$contents) {
     my $toplevel = 
       $entry->[0] =~ m/^perl\w*$/ ? 'perl_core_docs'
           # group all the perlwhatever docs together
@@ -418,7 +418,7 @@ sub _prep_contents_breakdown {
         keys %$fgroup
       # This hash is extremely unlikely to have more than 4 members, so this
       # sort isn't so very wasteful
-    )[[0]];
+    )[0];
   }
 
   return @(\%toplevel, \%toplevel_form_freq);
@@ -439,7 +439,7 @@ sub makepath {
   my($self, $outdir, $namelets) = < @_;
   return unless (nelems @$namelets) +> 1;
   for my $i (0 .. ((nelems @$namelets) - 2)) {
-    my $dir = $self->filespecsys->catdir( $outdir, @$namelets[[0 .. $i]] );
+    my $dir = $self->filespecsys->catdir( $outdir, < @$namelets[[0 .. $i]] );
     if(-e $dir) {
       die "$dir exists but not as a directory!?" unless -d $dir;
       next;
@@ -479,12 +479,12 @@ sub add_header_backlink {
   my $self = shift;
   return if $self->no_contents_links;
   my($page, $module, $infile, $outfile, $depth) = < @_;
-  $page->html_header_after_title( join '',
+  $page->html_header_after_title( join '', @(
     $page->html_header_after_title || '',
 
     qq[<p class="backlinktop"><b><a name="___top" href="],
     $self->url_up_to_contents($depth),
-    qq[" accesskey="1" title="All Documents">&lt;&lt;</a></b></p>\n],
+    qq[" accesskey="1" title="All Documents">&lt;&lt;</a></b></p>\n],)
   )
    if $self->contents_file
   ;
@@ -495,12 +495,12 @@ sub add_footer_backlink {
   my $self = shift;
   return if $self->no_contents_links;
   my($page, $module, $infile, $outfile, $depth) = < @_;
-  $page->html_footer( join '',
+  $page->html_footer( join '', @(
     qq[<p class="backlinkbottom"><b><a name="___bottom" href="],
     $self->url_up_to_contents($depth),
     qq[" title="All Documents">&lt;&lt;</a></b></p>\n],
     
-    $page->html_footer || '',
+    $page->html_footer || '',)
   )
    if $self->contents_file
   ;
@@ -510,7 +510,7 @@ sub add_footer_backlink {
 sub url_up_to_contents {
   my($self, $depth) = < @_;
   --$depth;
-  return join '/', ('..') x $depth, esc($self->contents_file);
+  return join '/', @( ('..') x $depth, esc($self->contents_file));
 }
 
 #_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-_-
@@ -601,7 +601,7 @@ sub _spray_css {
   $self->_gen_css_wad();
 
   my $lol = $self->_css_wad;
-  foreach my $chunk (< @$lol) {
+  foreach my $chunk ( @$lol) {
     my $url = $chunk->[0];
     my $outfile;
     if( ref($chunk->[-1]) and $url =~ m{^(_[-a-z0-9_]+\.css$)} ) {
@@ -629,7 +629,7 @@ sub _spray_css {
 sub _css_wad_to_markup {
   my($self, $depth) = < @_;
   
-  my @css  = @( < @{ $self->_css_wad || return '' } );
+  my @css  = @{ $self->_css_wad || return '' };
   return '' unless (nelems @css);
   
   my $rel = 'stylesheet';
@@ -638,12 +638,12 @@ sub _css_wad_to_markup {
   --$depth;
   my $uplink = $depth ? ('../' x $depth) : '';
 
-  foreach my $chunk (< @css) {
+  foreach my $chunk ( @css) {
     next unless $chunk and nelems @$chunk;
 
     my( $url1, $url2, $title, $type, $media) = (
       $self->_maybe_uplink( $chunk->[0], $uplink ),
-      map { esc($_) } (grep !ref($_), < @$chunk)
+      < map { esc($_) } @( (< grep !ref($_), @$chunk))
     );
 
     $out .= qq{<link rel="$rel" title="$title" type="$type" href="$url1$url2" media="$media" >\n};
@@ -697,7 +697,7 @@ sub _gen_css_wad {
     my $outname = $variation;
     my($flipmode, < @swap) = ( ($4 || ''), $1,$2,$3)
       if $outname =~ s/^([012])([012])([[012])([a-z]*)=?//s;
-    @swap = @( () ) if '010' eq join '', < @swap; # 010 is a swop-no-op!
+    @swap = @( () ) if '010' eq join '', @swap; # 010 is a swop-no-op!
   
     my $this_css =
       "/* This file is autogenerated.  Do not edit.  $variation */\n\n"
@@ -709,7 +709,7 @@ sub _gen_css_wad {
       $this_css =~ s/\bthin\b/medium/g;
     }
     $this_css =~ s<#([0-9a-fA-F])([0-9a-fA-F])([0-9a-fA-F])\b>
-                  |{ join '', '#', ($1,$2,$3)[[< @swap]] }|g   if (nelems @swap);
+                  |{ join '', @( '#', < @($1,$2,$3)[[@swap]]) }|g   if (nelems @swap);
 
     if(   $flipmode =~ m/a/)
        { $this_css =~ s/#fff\b/#999/gi } # black -> dark grey
@@ -727,11 +727,11 @@ sub _gen_css_wad {
     white_with_green_on_grey  grey_with_green_on_white
   ]) {
     my $outname = "indexless_$variation";
-    my $this_css = join "\n",
+    my $this_css = join "\n", @(
       "/* This file is autogenerated.  Do not edit.  $outname */\n",
       "\@import url(\"./_$variation.css\");",
       ".indexgroup \{ display: none; \}",
-      "\n",
+      "\n",)
     ;
     my $name = $outname;    
     $name =~ s/-|_/ /g;
@@ -744,7 +744,7 @@ sub _gen_css_wad {
 sub _color_negate {
   my $x = lc @_[0];
   $x =~ s/([0123456789abcdef])/{ 
-     %( qw| 0 f 1 e 2 d 3 c 4 b 5 a 6 9 7 8 8 7 9 6 a 5 b 4 c 3 d 2 e 1 f 0 | ){$1} }/g;
+     %( < qw| 0 f 1 e 2 d 3 c 4 b 5 a 6 9 7 8 8 7 9 6 a 5 b 4 c 3 d 2 e 1 f 0 | ){$1} }/g;
   return $x;
 }
 
@@ -765,7 +765,7 @@ sub _spray_javascript {
   $self->_gen_javascript_wad();
 
   my $lol = $self->_javascript_wad;
-  foreach my $script (< @$lol) {
+  foreach my $script ( @$lol) {
     my $url = $script->[0];
     my $outfile;
     
@@ -799,7 +799,7 @@ sub _gen_javascript_wad {
 sub _javascript_wad_to_markup {
   my($self, $depth) = < @_;
   
-  my @scripts  = @( < @{ $self->_javascript_wad || return '' } );
+  my @scripts  = @{ $self->_javascript_wad || return '' };
   return '' unless (nelems @scripts);
   
   my $out = '';
@@ -807,12 +807,12 @@ sub _javascript_wad_to_markup {
   --$depth;
   my $uplink = $depth ? ('../' x $depth) : '';
 
-  foreach my $s (< @scripts) {
+  foreach my $s ( @scripts) {
     next unless $s and nelems @$s;
 
     my( $url1, $url2, $type, $media) = (
       $self->_maybe_uplink( $s->[0], $uplink ),
-      map { esc($_) } (grep !ref($_), < @$s)
+      < map { esc($_) } @( (< grep !ref($_), @$s))
     );
 
     $out .= qq{<script type="$type" src="$url1$url2"></script>\n};
