@@ -5,14 +5,6 @@ package Pod::Simple::LinkSection;
 use strict;
 use Pod::Simple::BlackBox;
 
-use overload( # So it'll stringify nice
-  '""'   => \&Pod::Simple::BlackBox::stringify_lol,
-  'bool' => \&Pod::Simple::BlackBox::stringify_lol,
-  # '.='   => \&tack_on,  # grudgingly support
-  
-  'fallback' => 1,         # turn on cleverness
-);
-
 sub tack_on {
   @_[0] = \@('', \%(), "@_[0]" );
   return @_[0]->[2] .= @_[1];
@@ -33,7 +25,7 @@ sub new {
     if (!ref(@_[0] || '')) { # most common case: one bare string
       return bless \@('', \%(), @_[0] ), $class;
     } elsif( ref(@_[0] || '') eq 'ARRAY') {
-      $new = \@( < @{ @_[0] } );
+      $new = \$: @{ @_[0] };
     } else {
       Carp::croak( "$class new() doesn't know to clone $new" );
     }
@@ -42,7 +34,7 @@ sub new {
   }
 
   # By now it's a treelet:  [ 'foo', {}, ... ]
-  foreach my $x (< @$new) {
+  foreach my $x ( @$new) {
     if(ref($x || '') eq 'ARRAY') {
       $x = $class->new($x); # recurse
     } elsif(ref($x || '') eq 'HASH') {
