@@ -17,18 +17,18 @@
 package Term::ANSIColor;
 
 use strict;
-use vars qw($AUTORESET $EACHLINE @ISA @EXPORT @EXPORT_OK
+use vars < qw($AUTORESET $EACHLINE @ISA @EXPORT @EXPORT_OK
             %EXPORT_TAGS $VERSION %attributes %attributes_r);
 
 use Exporter ();
-@ISA         = @( qw(Exporter) );
-@EXPORT      = @( qw(color colored) );
-@EXPORT_OK   = @( qw(uncolor) );
-%EXPORT_TAGS = %(constants => \@(qw(CLEAR RESET BOLD DARK UNDERLINE UNDERSCORE
+@ISA         = qw(Exporter);
+@EXPORT      = qw(color colored);
+@EXPORT_OK   = qw(uncolor);
+%EXPORT_TAGS = %(constants => \qw(CLEAR RESET BOLD DARK UNDERLINE UNDERSCORE
                                  BLINK REVERSE CONCEALED BLACK RED GREEN
                                  YELLOW BLUE MAGENTA CYAN WHITE ON_BLACK
                                  ON_RED ON_GREEN ON_YELLOW ON_BLUE ON_MAGENTA
-                                 ON_CYAN ON_WHITE)));
+                                 ON_CYAN ON_WHITE));
 Exporter::export_ok_tags ('constants');
 
 $VERSION = '1.12';
@@ -107,9 +107,9 @@ for my $attr (keys %attributes) {
 # Return the escape code for a given set of color attributes.
 sub color {
     return '' if defined %ENV{ANSI_COLORS_DISABLED};
-    my @codes = @( map { split } < @_ );
+    my @codes = map { < split } @_;
     my $attribute = '';
-    foreach (< @codes) {
+    foreach ( @codes) {
         $_ = lc $_;
         unless (defined %attributes{$_}) {
             require Carp;
@@ -126,7 +126,7 @@ sub color {
 # empty escape sequence '' or "\e[m" gives an empty list of attrs.
 sub uncolor {
     my (@nums, @result);
-    for (< @_) {
+    for ( @_) {
         my $escape = $_;
         $escape =~ s/^\e\[//;
         $escape =~ s/m$//;
@@ -134,9 +134,9 @@ sub uncolor {
             require Carp;
             Carp::croak ("Bad escape sequence $_");
         }
-        push (@nums, split (m/;/, $1));
+        push (@nums, < split (m/;/, $1));
     }
-    for (< @nums) {
+    for ( @nums) {
 	$_ += 0; # Strip leading zeroes
 	my $name = %attributes_r{$_};
 	if (!defined $name) {
@@ -159,18 +159,17 @@ sub uncolor {
 sub colored {
     my ($string, @codes);
     if (ref @_[0]) {
-        @codes = @( < @{+shift} );
-        $string = join ('', < @_);
+        @codes = @{+shift};
+        $string = join ('', @_);
     } else {
         $string = shift;
-        @codes = @( < @_ );
+        @codes = @_;
     }
     return $string if defined %ENV{ANSI_COLORS_DISABLED};
     if (defined $EACHLINE) {
         my $attr = color (< @codes);
-        join '',
-            map { $_ ne $EACHLINE ? $attr . $_ . "\e[0m" : $_ }
-                grep { length ($_) +> 0 }
+        join '', map { $_ ne $EACHLINE ? $attr . $_ . "\e[0m" : $_ }
+ grep { length ($_) +> 0 }
                     split (m/(\Q$EACHLINE\E)/, $string);
     } else {
         color (< @codes) . $string . "\e[0m";
