@@ -7,8 +7,8 @@ sub new {
 
 
 package Overloaded::Compare;
-use vars qw(@ISA);
-@ISA = @( qw(Overloaded) );
+use vars < qw(@ISA);
+@ISA = qw(Overloaded);
 
 # Sometimes objects have only comparison ops overloaded and nothing else.
 # For example, DateTime objects.
@@ -19,8 +19,8 @@ use overload
 
 
 package Overloaded::Ify;
-use vars qw(@ISA);
-@ISA = @( qw(Overloaded) );
+use vars < qw(@ISA);
+@ISA = qw(Overloaded);
 
 use overload
         q{""}    => sub { @_[0]->{string} },
