@@ -219,7 +219,7 @@ sub CLEAR {
 	push @keys, $key;
 	$key = $self->NEXTKEY(< @_, $key);
     }
-    foreach $key (< @keys) {
+    foreach $key ( @keys) {
 	$self->DELETE(< @_, $key);
     }
 }
@@ -234,7 +234,7 @@ package Tie::StdHash;
 sub TIEHASH  { bless \%(), @_[0] }
 sub STORE    { @_[0]->{@_[1]} = @_[2] }
 sub FETCH    { @_[0]->{@_[1]} }
-sub FIRSTKEY { my $a = nelems(@( keys %{@_[0]})); each %{@_[0]} }
+sub FIRSTKEY { my $a = nelems( keys %{@_[0]}); each %{@_[0]} }
 sub NEXTKEY  { each %{@_[0]} }
 sub EXISTS   { exists @_[0]->{@_[1]} }
 sub DELETE   { delete @_[0]->{@_[1]} }
