@@ -17,7 +17,7 @@ no warnings 'utf8';
 our $VERSION = '0.52';
 our $PACKAGE = __PACKAGE__;
 
-my @Path = @( qw(Unicode Collate) );
+my @Path = qw(Unicode Collate);
 my $KeyFile = "allkeys.txt";
 
 # Perl's boolean
@@ -96,7 +96,7 @@ use constant CJK_ExtBFin   => 0x2A6D6;
 use constant BMP_Max       => 0xFFFF;
 
 # Logical_Order_Exception in PropList.txt
-my $DefaultRearrange = \@( 0x0E40..0x0E44, 0x0EC0..0x0EC4 );
+my $DefaultRearrange = \@( < 0x0E40..0x0E44, < 0x0EC0..0x0EC4 );
 
 sub UCA_Version { "14" }
 
@@ -115,24 +115,24 @@ sub unpack_U {
 ######
 
 my (%VariableOK);
-%VariableOK{[qw/
+ <%VariableOK{[qw/
     blanked  non-ignorable  shifted  shift-trimmed
   / ]} = (); # keys lowercased
 
-our @ChangeOK = @( qw/
+our @ChangeOK = qw/
     alternate backwards level normalization rearrange
     katakana_before_hiragana upper_before_lower
     overrideHangul overrideCJK preprocess UCA_Version
     hangul_terminator variable
-  / );
+  /;
 
-our @ChangeNG = @( qw/
+our @ChangeNG = qw/
     entry mapping table maxlength
     ignoreChar ignoreName undefChar undefName variableTable
     versionTable alternateTable backwardsTable forwardsTable rearrangeTable
     derivCode normCode rearrangeHash
     backwardsFlag
-  / );
+  /;
 # The hash key 'ignored' is deleted at v 0.21.
 # The hash key 'isShift' is deleted at v 0.23.
 # The hash key 'combining' is deleted at v 0.24.
@@ -145,8 +145,8 @@ sub version {
 }
 
 my (%ChangeOK, %ChangeNG);
-%ChangeOK{[< @ChangeOK ]} = ();
-%ChangeNG{[< @ChangeNG ]} = ();
+ <%ChangeOK{[ @ChangeOK ]} = ();
+ <%ChangeNG{[ @ChangeNG ]} = ();
 
 sub change {
     my $self = shift;
@@ -213,7 +213,7 @@ sub checkCollator {
     else {
 	my %level;
 	$self->{backwardsFlag} = 0;
-	for my $b (< @{ $self->{backwards} }) {
+	for my $b ( @{ $self->{backwards} }) {
 	    _checkLevel($b, "backwards");
 	    %level{$b} = 1;
 	}
@@ -229,8 +229,8 @@ sub checkCollator {
     # keys of $self->{rearrangeHash} are $self->{rearrange}.
     $self->{rearrangeHash} = undef;
 
-    if ((nelems @{ $self->{rearrange} })) {
-	%{ $self->{rearrangeHash} }{[< @{ $self->{rearrange} } ]} = ();
+    if ((nelems @{ $self->{rearrange} })) { <
+	%{ $self->{rearrangeHash} }{[ @{ $self->{rearrange} } ]} = ();
     }
 
     $self->{normCode} = undef;
@@ -295,14 +295,14 @@ sub read_table {
     my $self = shift;
 
     my($f, $fh);
-    foreach my $d (< @INC) {
+    foreach my $d ( @INC) {
 	$f = File::Spec->catfile($d, < @Path, $self->{table});
 	last if open($fh, "<", $f);
 	$f = undef;
     }
     if (!defined $f) {
 	$f = File::Spec->catfile(< @Path, $self->{table});
-	croak("$PACKAGE: Can't locate $f in \@INC (\@INC contains: {join ' ', <@INC})");
+	croak("$PACKAGE: Can't locate $f in \@INC (\@INC contains: {join ' ',@INC})");
     }
 
     while (my $line = ~< $fh) {
@@ -353,14 +353,14 @@ sub parseEntry
     return if defined $self->{undefName} && $name =~ m/$self->{undefName}/;
 
     # gets element
-    my($e, $k) = split m/;/, $line;
+    my($e, $k) = < split m/;/, $line;
     croak "Wrong Entry: <charList> must be separated by ';' from <collElement>"
 	if ! $k;
 
-    @uv = @( < _getHexArray($e) );
+    @uv = _getHexArray($e);
     return if !nelems @uv;
 
-    $entry = join(CODE_SEP, < @uv); # in JCPS
+    $entry = join(CODE_SEP, @uv); # in JCPS
 
     if (defined $self->{undefChar} || defined $self->{ignoreChar}) {
 	my $ele = pack_U(< @uv);
@@ -380,9 +380,9 @@ sub parseEntry
 
     my $is_L3_ignorable = TRUE;
 
-    foreach my $arr ($k =~ m/\[([^\[\]]+)\]/g) { # SPACEs allowed
+    foreach my $arr (@($k =~ m/\[([^\[\]]+)\]/g)) { # SPACEs allowed
 	my $var = $arr =~ m/\*/; # exactly /^\*/ but be lenient.
-	my @wt = @( < _getHexArray($arr) );
+	my @wt = _getHexArray($arr);
 	push @key, pack(VCE_TEMPLATE, $var, < @wt);
 	$is_L3_ignorable = FALSE
 	    if @wt[0] || @wt[1] || @wt[2];
@@ -421,7 +421,7 @@ sub _varCE
 	return $vce;
     }
     else {
-	return pack(VCE_TEMPLATE, $var, @wt[[0..2]],
+	return pack(VCE_TEMPLATE, $var, < @wt[[0..2]],
 	    $vbl eq 'shifted' && @wt[0]+@wt[1]+@wt[2] ? Shift4Wt : 0);
     }
 }
@@ -435,7 +435,7 @@ sub viewSortKey
 sub visualizeSortKey
 {
     my $self = shift;
-    my $view = join " ", map sprintf("\%04X", $_), unpack(KEY_TEMPLATE, shift);
+    my $view = join " ", map sprintf("\%04X", $_), @( unpack(KEY_TEMPLATE, shift));
 
     if ($self->{UCA_Version} +<= 8) {
 	$view =~ s/ ?0000 ?/|/g;
@@ -478,7 +478,7 @@ sub splitEnt
     }
 
     # get array of Unicode code point of string.
-    my @src = @( < unpack_U($str) );
+    my @src = unpack_U($str);
 
     # rearrangement:
     # Character positions are not kept if rearranged,
@@ -582,7 +582,7 @@ sub getWt
     my $der  = $self->{derivCode};
 
     return if !defined $u;
-    return @(map(_varCE($vbl, $_), < @{ $map->{$u} }))
+    return map(_varCE($vbl, $_), @{ $map->{$u} })
 	if $map->{$u};
 
     # JCPS must not be a contraction, then it's a code point.
@@ -590,53 +590,53 @@ sub getWt
 	my $hang = $self->{overrideHangul};
 	my @hangulCE;
 	if ($hang) {
-	    @hangulCE = @( map(pack(VCE_TEMPLATE, < NON_VAR, < @$_), < &$hang($u)) );
+	    @hangulCE = map(pack(VCE_TEMPLATE, < NON_VAR, < @$_), &$hang($u));
 	}
 	elsif (!defined $hang) {
-	    @hangulCE = @( < $der->($u) );
+	    @hangulCE = $der->($u);
 	}
 	else {
 	    my $max  = $self->{maxlength};
-	    my @decH = @( < _decompHangul($u) );
+	    my @decH = _decompHangul($u);
 
 	    if ((nelems @decH) == 2) {
-		my $contract = join(CODE_SEP, < @decH);
+		my $contract = join(CODE_SEP, @decH);
 		@decH = @($contract) if $map->{$contract};
 	    } else { # must be <@decH == 3>
 		if ($max->{@decH[0]}) {
-		    my $contract = join(CODE_SEP, < @decH);
+		    my $contract = join(CODE_SEP, @decH);
 		    if ($map->{$contract}) {
 			@decH = @($contract);
 		    } else {
-			$contract = join(CODE_SEP, @decH[[0,1]]);
+			$contract = join(CODE_SEP, @decH[[@(0,1)]]);
 			$map->{$contract} and @decH = @($contract, @decH[2]);
 		    }
 		    # even if V's ignorable, LT contraction is not supported.
 		    # If such a situatution were required, NFD should be used.
 		}
 		if ((nelems @decH) == 3 && $max->{@decH[1]}) {
-		    my $contract = join(CODE_SEP, @decH[[1,2]]);
+		    my $contract = join(CODE_SEP, @decH[[@(1,2)]]);
 		    $map->{$contract} and @decH = @(@decH[0], $contract);
 		}
 	    }
 
-	    @hangulCE = @( map({
+	    @hangulCE = map({
 		    $map->{$_} ? < @{ $map->{$_} } : < $der->($_);
-		} < @decH) );
+		} @decH);
 	}
-	return @(map _varCE($vbl, $_), < @hangulCE);
+	return map _varCE($vbl, $_), @hangulCE;
     }
     elsif (_isUIdeo($u, $self->{UCA_Version})) {
 	my $cjk  = $self->{overrideCJK};
-	return @(map { _varCE($vbl, $_) }
-	    $cjk
-		? map(pack(VCE_TEMPLATE, NON_VAR, < @$_), < &$cjk($u))
+	return map { _varCE($vbl, $_) }
+ @(	    $cjk
+		? < map(pack(VCE_TEMPLATE, NON_VAR, < @$_), &$cjk($u))
 		: defined $cjk && $self->{UCA_Version} +<= 8 && $u +< 0x10000
 		    ? _uideoCE_8($u)
-		    : < $der->($u) );
+		    : < $der->($u));
     }
     else {
-	return @( map { _varCE($vbl, $_) } < $der->($u) );
+	return map { _varCE($vbl, $_) } $der->($u);
     }
 }
 
@@ -655,7 +655,7 @@ sub getSortKey
     my @buf; # weight arrays
     if ($self->{hangul_terminator}) {
 	my $preHST = '';
-	foreach my $jcps (< @$rEnt) {
+	foreach my $jcps ( @$rEnt) {
 	    # weird things like VL, TL-contraction are not considered!
 	    my $curHST = '';
 	    foreach my $u (split m/;/, $jcps) {
@@ -676,7 +676,7 @@ sub getSortKey
 	    and push @buf, $self->getWtHangulTerm();
     }
     else {
-	foreach my $jcps (< @$rEnt) {
+	foreach my $jcps ( @$rEnt) {
 	    push @buf, < $self->getWt($jcps);
 	}
     }
@@ -685,7 +685,7 @@ sub getSortKey
     my @ret = @(\@(),\@(),\@(),\@());
     my $last_is_variable;
 
-    foreach my $vwt (< @buf) {
+    foreach my $vwt ( @buf) {
 	my($var, < @wt) = unpack(VCE_TEMPLATE, $vwt);
 
 	# "Ignorable (L1, L2) after Variable" since track. v. 9
@@ -707,7 +707,7 @@ sub getSortKey
 
     # modification of tertiary weights
     if ($self->{upper_before_lower}) {
-	foreach my $w (< @{ @ret[2] }) {
+	foreach my $w ( @{ @ret[2] }) {
 	    if    (0x8 +<= $w && $w +<= 0xC) { $w -= 6 } # lower
 	    elsif (0x2 +<= $w && $w +<= 0x6) { $w += 6 } # upper
 	    elsif ($w == 0x1C)             { $w += 1 } # square upper
@@ -715,7 +715,7 @@ sub getSortKey
 	}
     }
     if ($self->{katakana_before_hiragana}) {
-	foreach my $w (< @{ @ret[2] }) {
+	foreach my $w ( @{ @ret[2] }) {
 	    if    (0x0F +<= $w && $w +<= 0x13) { $w -= 2 } # katakana
 	    elsif (0x0D +<= $w && $w +<= 0x0E) { $w += 5 } # hiragana
 	}
@@ -724,12 +724,12 @@ sub getSortKey
     if ($self->{backwardsFlag}) {
 	for (my $v = MinLevel; $v +<= MaxLevel; $v++) {
 	    if ($self->{backwardsFlag} ^&^ (1 << $v)) {
-		@{ @ret[$v-1] } = @( reverse < @{ @ret[$v-1] } );
+		@{ @ret[$v-1] } = reverse @{ @ret[$v-1] };
 	    }
 	}
     }
 
-    return join LEVEL_SEP, map pack(KEY_TEMPLATE, < @$_), < @ret;
+    return join LEVEL_SEP, map pack(KEY_TEMPLATE, < @$_), @ret;
 }
 
 
@@ -745,10 +745,9 @@ sub ne  { @_[0]->getSortKey(@_[1]) ne  @_[0]->getSortKey(@_[2]) }
 ##
 sub sort {
     my $obj = shift;
-    return
-	@( map { $_[1] }
+    return map { $_[1] }
            sort { $a[0] cmp $b[0] }
-           map { @( $obj->getSortKey($_), $_) } < @_ );
+ map { @( $obj->getSortKey($_), $_) } @_;
 }
 
 
@@ -823,7 +822,7 @@ sub getWtHangulTerm {
 ##
 ## "hhhh hhhh hhhh" to (dddd, dddd, dddd)
 ##
-sub _getHexArray { @( map hex, @_[0] =~ m/([0-9a-fA-F]+)/g ) }
+sub _getHexArray { map hex, @( @_[0] =~ m/([0-9a-fA-F]+)/g) }
 
 #
 # $code *must* be in Hangul syllable.
@@ -926,7 +925,7 @@ sub index
     if (! nelems @$subE) {
 	my $temp = $pos +<= 0 ? 0 : $len +<= $pos ? $len : $pos;
 	return $grob
-	    ? @( map(\@($_, 0), $temp..$len) )
+	    ? map(\@($_, 0), $temp..$len)
 	    : @($temp,0);
     }
     $len +< $pos
@@ -938,7 +937,7 @@ sub index
     my(@strWt, @iniPos, @finPos, @subWt, @g_ret);
 
     my $last_is_variable;
-    for my $vwt (map < $self->getWt($_), < @$subE) {
+    for my $vwt ( map < $self->getWt($_), @$subE) {
 	my($var, < @wt) = unpack(VCE_TEMPLATE, $vwt);
 	my $to_be_pushed = _nonIgnorAtLevel(\@wt,$lev);
 
@@ -971,7 +970,7 @@ sub index
 
 	# fetch a grapheme
 	while ($i +<= $end && $found_base == 0) {
-	    for my $vwt ( <$self->getWt($strE->[$i]->[0])) {
+	    for my $vwt ( $self->getWt($strE->[$i]->[0])) {
 		my($var, < @wt) = unpack(VCE_TEMPLATE, $vwt);
 		my $to_be_pushed = _nonIgnorAtLevel(\@wt,$lev);
 
@@ -1056,8 +1055,8 @@ sub gmatch
     my $self = shift;
     my $str  = shift;
     my $sub  = shift;
-    return @( map substr($str, $_->[0], $_->[1]), <
-		$self->index($str, $sub, 0, 'g') );
+    return map substr($str, $_->[0], $_->[1]),
+		$self->index($str, $sub, 0, 'g');
 }
 
 ##
@@ -1092,7 +1091,7 @@ sub gsubst
     my $cnt = 0;
 
     # Replacement is carried out from the end, then use reverse.
-    for my $pos_len (reverse < $self->index(@_[0], @_[1], 0, 'g')) {
+    for my $pos_len (reverse $self->index(@_[0], @_[1], 0, 'g')) {
 	if ($code) {
 	    my $mat = substr(@_[0], $pos_len->[0], $pos_len->[1]);
 	    substr(@_[0], $pos_len->[0], $pos_len->[1], $code->($mat));
