@@ -22,7 +22,7 @@ sub SWASHNEW_real {
     my ($class, $type, $list, $minbits, $none) = < @_;
     local $^D = 0 if $^D;
 
-    print STDERR "SWASHNEW {join ' ', <@_}\n" if DEBUG;
+    print STDERR "SWASHNEW {join ' ',@_}\n" if DEBUG;
 
     ##
     ## Get the list of codepoints for the type.
@@ -190,7 +190,7 @@ sub SWASHNEW_real {
 	    ## If we have, return the cached results. The cache key is the
 	    ## class and file to load.
 	    ##
-	    my $found = %Cache{$class, $file};
+	    my $found = %Cache{$class . "," . $file};
 	    if ($found and ref($found) eq $class) {
 		print STDERR "Returning cached '$file' for \\p\{$type\}\n" if DEBUG;
 		return $found;
@@ -207,15 +207,14 @@ sub SWASHNEW_real {
 
     my $ORIG = $list;
     if ($list) {
-	my @tmp = @( split(m/^/m, $list) );
+	my @tmp = split(m/^/m, $list);
 	my %seen;
 	no warnings;
-	$extras = join '', grep m/^[^0-9a-fA-F]/, < @tmp;
-	$list = join '',
-	    map  { $_->[1] }
+	$extras = join '', grep m/^[^0-9a-fA-F]/, @tmp;
+	$list = join '', map  { $_->[1] }
 	    sort { $a->[0] <+> $b->[0] }
-	    map  { m/^([0-9a-fA-F]+)/; \@( CORE::hex($1), $_ ) }
-	    grep { m/^([0-9a-fA-F]+)/ and not %seen{$1}++ } < @tmp; # XXX doesn't do ranges right
+ map  { m/^([0-9a-fA-F]+)/; \@( CORE::hex($1), $_ ) }
+ grep { m/^([0-9a-fA-F]+)/ and not %seen{$1}++ } @tmp; # XXX doesn't do ranges right
     }
 
     if ($none) {
@@ -239,14 +238,14 @@ sub SWASHNEW_real {
     }
 
     my @extras;
-    for my $x ($extras) {
+    for my $x (@($extras)) {
 	pos $x = 0;
 	while ($x =~ m/^([^0-9a-fA-F\n])(.*)/mg) {
 	    my $char = $1;
 	    my $name = $2;
 	    print STDERR "$1 => $2\n" if DEBUG;
 	    if ($char =~ m/[-+!&]/) {
-		my ($c,$t) = split(m/::/, $name, 2);	# bogus use of ::, really
+		my ($c,$t) = < split(m/::/, $name, 2);	# bogus use of ::, really
 		my $subobj;
 		if ($c eq 'utf8') {
 		    $subobj = SWASHNEW_real('utf8', $t, "", $minbits, 0);
@@ -276,7 +275,7 @@ sub SWASHNEW_real {
     ) => $class;
 
     if ($file) {
-        %Cache{$class, $file} = $SWASH;
+        %Cache{$class . "," . $file} = $SWASH;
     }
 
     return $SWASH;
