@@ -25,7 +25,7 @@ require warnings;
 
 sub mkMask
 {
-    my ($bit) = @_;
+    my ($bit) = < @_;
     my $mask = "";
 
     vec($mask, $bit, 1) = 1;
@@ -35,7 +35,7 @@ sub mkMask
 sub import
 {
     shift;
-    my $package = (caller(0))[[0]];
+    my $package = @(caller(0))[0];
     if (! defined %warnings::Bits{$package}) {
         %warnings::Bits{$package}     = mkMask($warnings::LAST_BIT);
         vec(%warnings::Bits{'all'}, $warnings::LAST_BIT, 1) = 1;
