@@ -175,6 +175,7 @@ package P5AST::op_rv2sv; 	@ISA = 'P5AST::unop';
 package P5AST::op_av2arylen; 	@ISA = 'P5AST::unop';
 package P5AST::op_rv2cv; 	@ISA = 'P5AST::unop';
 package P5AST::op_anoncode; 	@ISA = 'P5AST::padop_svop';
+package P5AST::op_anonscalar; 	@ISA = 'P5AST::padop_svop';
 package P5AST::op_prototype; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_refgen; 	@ISA = 'P5AST::unop';
 package P5AST::op_srefgen; 	@ISA = 'P5AST::unop';
@@ -292,6 +293,7 @@ package P5AST::op_values; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_keys; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_delete; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_exists; 	@ISA = 'P5AST::baseop_unop';
+package P5AST::op_expand; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_rv2hv; 	@ISA = 'P5AST::unop';
 package P5AST::op_helem; 	@ISA = 'P5AST::listop';
 package P5AST::op_hslice; 	@ISA = 'P5AST::listop';
@@ -311,6 +313,8 @@ package P5AST::op_shift; 	@ISA = 'P5AST::baseop_unop';
 package P5AST::op_unshift; 	@ISA = 'P5AST::listop';
 package P5AST::op_sort; 	@ISA = 'P5AST::listop';
 package P5AST::op_reverse; 	@ISA = 'P5AST::listop';
+package P5AST::op_nelems; 	@ISA = 'P5AST::listop';
+package P5AST::op_nkeys; 	@ISA = 'P5AST::listop';
 package P5AST::op_grepstart; 	@ISA = 'P5AST::listop';
 package P5AST::op_grepwhile; 	@ISA = 'P5AST::logop';
 package P5AST::op_mapstart; 	@ISA = 'P5AST::listop';
