@@ -152,7 +152,6 @@ S_is_container_magic(const MAGIC *mg)
     case PERL_MAGIC_bm:
     case PERL_MAGIC_fm:
     case PERL_MAGIC_regex_global:
-    case PERL_MAGIC_nkeys:
     case PERL_MAGIC_qr:
     case PERL_MAGIC_taint:
     case PERL_MAGIC_vec:
@@ -441,9 +440,7 @@ Perl_mg_copy(pTHX_ SV *sv, SV *nsv, const char *key, I32 klen)
 		sv_magic(nsv,
 		     (type == PERL_MAGIC_tied)
 			? SvTIED_obj(sv, mg)
-			: (type == PERL_MAGIC_regdata && mg->mg_obj)
-			    ? sv
-			    : mg->mg_obj,
+			: mg->mg_obj,
 		     toLOWER(type), key, klen);
 		count++;
 	    }
@@ -1237,7 +1234,7 @@ Perl_magic_getsig(pTHX_ SV *sv, MAGIC *mg)
 
     if (i > 0) {
     	if(PL_psig_ptr[i])
-    	    sv_setsv(sv,PL_psig_ptr[i]);
+    	    sv_setsv(sv,sv_2mortal(newRV_inc(PL_psig_ptr[i])));
     	else {
 	    Sighandler_t sigstate = rsignal_state(i);
 #ifdef FAKE_PERSISTENT_SIGNAL_HANDLERS
@@ -1253,8 +1250,6 @@ Perl_magic_getsig(pTHX_ SV *sv, MAGIC *mg)
     	    	sv_setpvs(sv,"IGNORE");
     	    else
     	    	sv_setsv(sv,&PL_sv_undef);
-	    PL_psig_ptr[i] = SvREFCNT_inc_simple_NN(sv);
-    	    SvTEMP_off(sv);
     	}
     }
     return 0;
@@ -1301,7 +1296,7 @@ Perl_magic_clearsig(pTHX_ SV *sv, MAGIC *mg)
             }
             if(PL_psig_ptr[i]) {
                 SV * const to_dec=PL_psig_ptr[i];
-                PL_psig_ptr[i]=0;
+                PL_psig_ptr[i]=NULL;
                 LEAVE;
                 SvREFCNT_dec(to_dec);
             }
@@ -1438,7 +1433,6 @@ Perl_magic_setsig(pTHX_ SV *sv, MAGIC *mg)
 {
     dVAR;
     I32 i;
-    SV** svp = NULL;
     /* Need to be careful with SvREFCNT_dec(), because that can have side
      * effects (due to closures). We must make sure that the new disposition
      * is in place before it is called.
@@ -1446,6 +1440,8 @@ Perl_magic_setsig(pTHX_ SV *sv, MAGIC *mg)
     SV* to_dec = NULL;
     STRLEN len;
     const char *s;
+    bool set_to_ignore = FALSE;
+    bool set_to_default = FALSE;
 #ifdef HAS_SIGPROCMASK
     sigset_t set, save;
     SV* save_sv;
@@ -1453,81 +1449,77 @@ Perl_magic_setsig(pTHX_ SV *sv, MAGIC *mg)
 
     PERL_ARGS_ASSERT_MAGIC_SETSIG;
 
-    if ( ! (SvTYPE(sv) == SVt_PVGV || SvROK(sv)) ) {
+    if ( SvROK(sv) ) {
+	if ( SvTYPE(SvRV(sv)) != SVt_PVCV )
+	    Perl_croak(aTHX_ "signal handler should be a code refernce, 'DEFAULT' or 'IGNORE'");
+    } else {
         const char *s = SvOK(sv) ? SvPV_force(sv,len) : "DEFAULT";
-        if ( ! (strEQ(s,"IGNORE") || strEQ(s,"DEFAULT") || !*s)) {
-            Perl_croak(aTHX_  "signal handler should be glob or reference or 'DEFAULT or 'IGNORE'");
-        }
+        if ( strEQ(s,"IGNORE") )
+	    set_to_ignore = TRUE;
+	else if (strEQ(s,"DEFAULT"))
+	    set_to_default = TRUE;
+	else
+            Perl_croak(aTHX_  "signal handler should be a code reference or 'DEFAULT or 'IGNORE'");
     }
 
     s = MgPV_const(mg,len);
-    {
-        i = whichsig(s);        /* ...no, a brick */
-        if (i <= 0) {
-            if (ckWARN(WARN_SIGNAL))
-                Perl_warner(aTHX_ packWARN(WARN_SIGNAL), "No such signal: SIG%s", s);
-            return 0;
-        }
+    i = whichsig(s);        /* ...no, a brick */
+    if (i <= 0) {
+	if (ckWARN(WARN_SIGNAL))
+	    Perl_warner(aTHX_ packWARN(WARN_SIGNAL), "No such signal: SIG%s", s);
+	return 0;
+    }
 #ifdef HAS_SIGPROCMASK
-        /* Avoid having the signal arrive at a bad time, if possible. */
-        sigemptyset(&set);
-        sigaddset(&set,i);
-        sigprocmask(SIG_BLOCK, &set, &save);
-        ENTER;
-        save_sv = newSVpvn((char *)(&save), sizeof(sigset_t));
-        SAVEFREESV(save_sv);
-        SAVEDESTRUCTOR_X(restore_sigmask, save_sv);
+    /* Avoid having the signal arrive at a bad time, if possible. */
+    sigemptyset(&set);
+    sigaddset(&set,i);
+    sigprocmask(SIG_BLOCK, &set, &save);
+    ENTER;
+    save_sv = newSVpvn((char *)(&save), sizeof(sigset_t));
+    SAVEFREESV(save_sv);
+    SAVEDESTRUCTOR_X(restore_sigmask, save_sv);
 #endif
-        PERL_ASYNC_CHECK();
+    PERL_ASYNC_CHECK();
 #if defined(FAKE_PERSISTENT_SIGNAL_HANDLERS) || defined(FAKE_DEFAULT_SIGNAL_HANDLERS)
-        if (!PL_sig_handlers_initted) Perl_csighandler_init();
+    if (!PL_sig_handlers_initted) Perl_csighandler_init();
 #endif
 #ifdef FAKE_PERSISTENT_SIGNAL_HANDLERS
-        PL_sig_ignoring[i] = 0;
+    PL_sig_ignoring[i] = 0;
 #endif
 #ifdef FAKE_DEFAULT_SIGNAL_HANDLERS
-        PL_sig_defaulting[i] = 0;
+    PL_sig_defaulting[i] = 0;
 #endif
-        SvREFCNT_dec(PL_psig_name[i]);
-        to_dec = PL_psig_ptr[i];
-        PL_psig_ptr[i] = SvREFCNT_inc_simple_NN(sv);
-        SvTEMP_off(sv); /* Make sure it doesn't go away on us */
-        PL_psig_name[i] = newSVpvn(s, len);
-        SvREADONLY_on(PL_psig_name[i]);
-    }
-    if (SvTYPE(sv) == SVt_PVGV || SvROK(sv)) {
-        if (i) {
-            (void)rsignal(i, PL_csighandlerp);
+    SvREFCNT_dec(PL_psig_name[i]);
+    to_dec = PL_psig_ptr[i];
+    PL_psig_ptr[i] = NULL;
+    PL_psig_name[i] = newSVpvn(s, len);
+    SvREADONLY_on(PL_psig_name[i]);
+
+    if (SvROK(sv)) {
+	PL_psig_ptr[i] = SvREFCNT_inc(SvRV(sv));
+	(void)rsignal(i, PL_csighandlerp);
 #ifdef HAS_SIGPROCMASK
-            LEAVE;
+	LEAVE;
 #endif
-        }
-        else
-            *svp = SvREFCNT_inc_simple_NN(sv);
         if(to_dec)
             SvREFCNT_dec(to_dec);
         return 0;
     }
-    s = SvOK(sv) ? SvPV_force(sv,len) : "DEFAULT";
-    if (strEQ(s,"IGNORE")) {
-        if (i) {
+    if (set_to_ignore) {
 #ifdef FAKE_PERSISTENT_SIGNAL_HANDLERS
-            PL_sig_ignoring[i] = 1;
-            (void)rsignal(i, PL_csighandlerp);
+	PL_sig_ignoring[i] = 1;
+	(void)rsignal(i, PL_csighandlerp);
 #else
-            (void)rsignal(i, (Sighandler_t) SIG_IGN);
+	(void)rsignal(i, (Sighandler_t) SIG_IGN);
 #endif
-        }
     }
     else {
-        if (i) {
 #ifdef FAKE_DEFAULT_SIGNAL_HANDLERS
-            PL_sig_defaulting[i] = 1;
-            (void)rsignal(i, PL_csighandlerp);
+	PL_sig_defaulting[i] = 1;
+	(void)rsignal(i, PL_csighandlerp);
 #else
-            (void)rsignal(i, (Sighandler_t) SIG_DFL);
+	(void)rsignal(i, (Sighandler_t) SIG_DFL);
 #endif
-	}
     }
 #ifdef HAS_SIGPROCMASK
     if(i)
@@ -1599,52 +1591,6 @@ Perl_magic_clearisa(pTHX_ SV *sv, MAGIC *mg)
     return 0;
 }
 
-int
-Perl_magic_setamagic(pTHX_ SV *sv, MAGIC *mg)
-{
-    dVAR;
-    PERL_ARGS_ASSERT_MAGIC_SETAMAGIC;
-    PERL_UNUSED_ARG(sv);
-    PERL_UNUSED_ARG(mg);
-    PL_amagic_generation++;
-
-    return 0;
-}
-
-int
-Perl_magic_getnkeys(pTHX_ SV *sv, MAGIC *mg)
-{
-    HV * const hv = (HV*)LvTARG(sv);
-    I32 i = 0;
-
-    PERL_ARGS_ASSERT_MAGIC_GETNKEYS;
-    PERL_UNUSED_ARG(mg);
-
-    if (hv) {
-         (void) hv_iterinit(hv);
-         if (! SvTIED_mg((SV*)hv, PERL_MAGIC_tied))
-             i = HvKEYS(hv);
-         else {
-             while (hv_iternext(hv))
-                 i++;
-         }
-    }
-
-    sv_setiv(sv, (IV)i);
-    return 0;
-}
-
-int
-Perl_magic_setnkeys(pTHX_ SV *sv, MAGIC *mg)
-{
-    PERL_ARGS_ASSERT_MAGIC_SETNKEYS;
-    PERL_UNUSED_ARG(mg);
-    if (LvTARG(sv)) {
-        hv_ksplit((HV*)LvTARG(sv), SvIV(sv));
-    }
-    return 0;
-}
-
 /* caller is responsible for stack switching/cleanup */
 STATIC int
 S_magic_methcall(pTHX_ SV *sv, const MAGIC *mg, const char *meth, I32 flags, int n, SV *val)
@@ -2712,10 +2658,11 @@ Perl_sighandler(int sig)
         flags |= 16;
 
     if (!PL_psig_ptr[sig]) {
-                PerlIO_printf(Perl_error_log, "Signal SIG%s received, but no signal handler set.\n",
-                                 PL_sig_name[sig]);
-                exit(sig);
-        }
+/* 	PerlIO_printf(Perl_error_log, "Signal SIG%s received, but no signal handler set.\n", */
+/* 	    PL_sig_name[sig]); */
+/* 	exit(sig); */
+	return;
+    }
 
     /* Max number of items pushed there is 3*n or 4. We cannot fix
        infinity, so we fix 4 (in fact 5): */
@@ -2727,10 +2674,10 @@ Perl_sighandler(int sig)
         PL_markstack_ptr++;             /* Protect mark. */
     if (flags & 16)
         PL_scopestack_ix += 1;
-    /* sv_2cv is too complicated, try a simpler variant first: */
-    if (!SvROK(PL_psig_ptr[sig]) || !(cv = (CV*)SvRV(PL_psig_ptr[sig]))
+
+    if (!(cv = (CV*)PL_psig_ptr[sig])
         || SvTYPE(cv) != SVt_PVCV) {
-        cv = sv_2cv(PL_psig_ptr[sig], &gv, GV_ADD);
+	Perl_croak(aTHX "SIG%s handler is not valid", PL_sig_name[sig]);
     }
 
     if (!cv || !CvROOT(cv)) {
