@@ -97,15 +97,6 @@ PP(pp_regcomp)
 	tmpstr = PAD_SV(ARGTARG);
 	sv_setpvn(tmpstr, "", 0);
 	while (++MARK <= SP) {
-	    if (PL_amagic_generation) {
-		SV *sv;
-		if ((SvAMAGIC(tmpstr) || SvAMAGIC(*MARK)) &&
-		    (sv = amagic_call(tmpstr, *MARK, concat_amg, AMGf_assign)))
-		{
-		   sv_setsv(tmpstr, sv);
-		   continue;
-		}
-	    }
 	    sv_catsv(tmpstr, *MARK);
 	}
     	SvSETMAGIC(tmpstr);
@@ -394,17 +385,37 @@ Perl_rxres_free(pTHX_ void **rsp)
 PP(pp_grepstart)
 {
     dVAR; dSP;
-    SV *src;
+    SV *srcitem;
 
     if (PL_stack_base + *PL_markstack_ptr == SP) {
 	(void)POPMARK;
-	if (GIMME_V == G_SCALAR)
-	    mXPUSHi(0);
+	mXPUSHs(newAV());
 	RETURNOP(PL_op->op_next->op_next);
     }
+
     PL_stack_sp = PL_stack_base + *PL_markstack_ptr + 1;
+
+    SV* src = sv_mortalcopy(POPs);
+    SV* dst = sv_2mortal(newAV());
+
+    if ( ! SvOK(src) ) {
+	(void)POPMARK;
+	XPUSHs(dst);
+	RETURNOP(PL_op->op_next->op_next);
+    }
+    if ( ! SvAVOK(src) )
+	Perl_croak(aTHX_ "%s expected an array but got %s", OP_DESC(PL_op), Ddesc(src));
+    
+    if ( av_len(SvAV(src)) == -1 ) {
+	(void)POPMARK;
+	XPUSHs(dst);
+	RETURNOP(PL_op->op_next->op_next);
+    }
+
     pp_pushmark();				/* push dst */
-    pp_pushmark();				/* push src */
+    XPUSHs(dst);                          /* push dst */
+    XPUSHs(src);                          /* push dst */
+
     ENTER;					/* enter outer scope */
 
     SAVETMPS;
@@ -415,12 +426,14 @@ PP(pp_grepstart)
     ENTER;					/* enter inner scope */
     SAVEVPTR(PL_curpm);
 
-    src = PL_stack_base[*PL_markstack_ptr];
-    SvTEMP_off(src);
-    if (PL_op->op_private & OPpGREP_LEX)
-	SVcpREPLACE(PAD_SVl(PL_op->op_targ), src);
+    srcitem = av_shift(SvAV(src));
+    if (PL_op->op_type == OP_GREPSTART)
+	XPUSHs(srcitem);
+    if (PL_op->op_private & OPpGREP_LEX) {
+	SVcpSTEAL(PAD_SVl(PL_op->op_targ), srcitem);
+    }
     else
-	SVcpREPLACE(DEFSV, src);
+	SVcpSTEAL(DEFSV, srcitem);
 
     PUTBACK;
     if (PL_op->op_type == OP_MAPSTART)
@@ -438,100 +451,43 @@ PP(pp_mapwhile)
     SV** src;
     SV** dst;
 
-    /* first, move source pointer to the next item in the source list */
-    ++PL_markstack_ptr[-1];
+    dst = PL_stack_base + PL_markstack_ptr[-1] + 0;
+    src = PL_stack_base + PL_markstack_ptr[-1] + 1;
 
     /* if there are new items, push them into the destination list */
     if (items && gimme != G_VOID) {
-	/* might need to make room back there first */
-	if (items > PL_markstack_ptr[-1] - PL_markstack_ptr[-2]) {
-	    /* XXX this implementation is very pessimal because the stack
-	     * is repeatedly extended for every set of items.  Is possible
-	     * to do this without any stack extension or copying at all
-	     * by maintaining a separate list over which the map iterates
-	     * (like foreach does). --gsar */
-
-	    /* everything in the stack after the destination list moves
-	     * towards the end the stack by the amount of room needed */
-	    shift = items - (PL_markstack_ptr[-1] - PL_markstack_ptr[-2]);
-
-	    /* items to shift up (accounting for the moved source pointer) */
-	    count = (SP - PL_stack_base) - (PL_markstack_ptr[-1] - 1);
-
-	    /* This optimization is by Ben Tilly and it does
-	     * things differently from what Sarathy (gsar)
-	     * is describing.  The downside of this optimization is
-	     * that leaves "holes" (uninitialized and hopefully unused areas)
-	     * to the Perl stack, but on the other hand this
-	     * shouldn't be a problem.  If Sarathy's idea gets
-	     * implemented, this optimization should become
-	     * irrelevant.  --jhi */
-            if (shift < count)
-                shift = count; /* Avoid shifting too often --Ben Tilly */
-
-	    EXTEND(SP,shift);
-	    src = SP;
-	    dst = (SP += shift);
-	    PL_markstack_ptr[-1] += shift;
-	    *PL_markstack_ptr += shift;
-	    while (count--)
-		*dst-- = *src--;
-	}
-	/* copy the new items down to the destination list */
-	dst = PL_stack_base + (PL_markstack_ptr[-2] += items) - 1;
-	if (gimme == G_ARRAY) {
-	    while (items-- > 0)
-		*dst-- = SvTEMP(TOPs) ? POPs : sv_mortalcopy(POPs);
-	}
-	else {
-	    /* scalar context: we don't care about which values map returns
-	     * (we use undef here). And so we certainly don't want to do mortal
-	     * copies of meaningless values. */
-	    while (items-- > 0) {
-		(void)POPs;
-		*dst-- = &PL_sv_undef;
-	    }
+	int i;
+	SP -= items;
+	for (i=1; i <= items; i++) {
+	    av_push((AV*)*dst, SvTEMP(SP[i]) ? SvREFCNT_inc(SP[i]) : newSVsv(SP[i]));
 	}
     }
     LEAVE;					/* exit inner scope */
 
     /* All done yet? */
-    if (PL_markstack_ptr[-1] > *PL_markstack_ptr) {
+    if ( av_len(*src) == -1 ) {
 
 	(void)POPMARK;				/* pop top */
 	LEAVE;					/* exit outer scope */
-	(void)POPMARK;				/* pop src */
-	items = --*PL_markstack_ptr - PL_markstack_ptr[-1];
 	(void)POPMARK;				/* pop dst */
 	SP = PL_stack_base + POPMARK;		/* pop original mark */
-	if (gimme == G_SCALAR) {
-	    if (PL_op->op_private & OPpGREP_LEX) {
-		SV* sv = sv_newmortal();
-		sv_setiv(sv, items);
-		PUSHs(sv);
-	    }
-	    else {
-		dTARGET;
-		XPUSHi(items);
-	    }
+	if (gimme != G_VOID) {
+	    PUSHs(*dst);
 	}
-	else if (gimme == G_ARRAY)
-	    SP += items;
 	RETURN;
     }
     else {
-	SV *src;
+	SV *srcitem;
 
 	ENTER;					/* enter inner scope */
 	SAVEVPTR(PL_curpm);
 
 	/* set $_ to the new source item */
-	src = PL_stack_base[PL_markstack_ptr[-1]];
-	SvTEMP_off(src);
+	srcitem = av_shift(*src);
 	if (PL_op->op_private & OPpGREP_LEX)
-	    SVcpREPLACE(PAD_SVl(PL_op->op_targ), src);
+	    SVcpSTEAL(PAD_SVl(PL_op->op_targ), srcitem)
 	else
-	    SVcpREPLACE(DEFSV, src);
+	    SVcpSTEAL(DEFSV, srcitem);
 
 	RETURNOP(cLOGOP->op_other);
     }
@@ -542,9 +498,7 @@ PP(pp_mapwhile)
 PP(pp_range)
 {
     dVAR;
-    if (GIMME == G_ARRAY)
-	return NORMAL;
-    DIE(aTHX_ "range operator .. can only be used in list context.");
+    return NORMAL;
 }
 
 PP(pp_flip)
@@ -552,7 +506,6 @@ PP(pp_flip)
     dVAR;
     dSP;
 
-    assert(GIMME == G_ARRAY);
     RETURNOP(((LOGOP*)cUNOP->op_first)->op_other);
 }
 
@@ -571,8 +524,8 @@ PP(pp_flop)
 {
     dVAR; dSP;
 
+    AV* res = sv_2mortal(newAV());
     dPOPPOPssrl;
-    assert(GIMME == G_ARRAY);
 
     SvGETMAGIC(left);
     SvGETMAGIC(right);
@@ -587,14 +540,11 @@ PP(pp_flop)
 	max = SvIV(right);
 	if (max >= i) {
 	    j = max - i + 1;
-	    EXTEND_MORTAL(j);
-	    EXTEND(SP, j);
 	}
 	else
 	    j = 0;
 	while (j--) {
-	    SV * const sv = sv_2mortal(newSViv(i++));
-	    PUSHs(sv);
+	    av_push(res, newSViv(i++));
 	}
     }
     else {
@@ -605,14 +555,14 @@ PP(pp_flop)
 	SV *sv = sv_mortalcopy(left);
 	SvPV_force_nolen(sv);
 	while (!SvNIOKp(sv) && SvCUR(sv) <= len) {
-	    XPUSHs(sv);
+	    av_push(res, newSVsv(sv));
 	    if (strEQ(SvPVX_const(sv),tmps))
 		break;
-	    sv = sv_2mortal(newSVsv(sv));
 	    sv_inc(sv);
 	}
     }
 
+    XPUSHs(res);
     RETURN;
 }
 
@@ -969,8 +919,23 @@ PP(pp_caller)
 	PUSHs(&PL_sv_undef);
     else
 	mPUSHs(newSVpv(stashname, 0));
-    mPUSHs(newSVpv(OutCopFILE(cx->blk_oldcop), 0));
-    mPUSHi((I32)CopLINE(cx->blk_oldcop));
+    {
+	SV**linenr = NULL;
+	SV* location = cx->blk_oldop->op_location;
+	SV* filename = loc_filename(cx->blk_oldop->op_location);
+	if (location)
+	    linenr = av_fetch((AV*)location, 1, FALSE);
+	if (filename)
+	    mPUSHs(newSVsv(filename));
+	else 
+	    mPUSHs(newSVpv("(unknown)", 0));
+	if (linenr && *linenr) {
+	    mPUSHi(SvIV(*linenr));
+	}
+	else {
+	    mPUSHi(0);
+	}
+    }
     if (!MAXARG)
 	RETURN;
     if (CxTYPE(cx) == CXt_SUB) {
@@ -1236,28 +1201,19 @@ PP(pp_enteriter)
 	    }
 	}
     }
-    else if (PL_op->op_flags & OPf_STACKED) {
+    else { /* iterating over (copy of) the array on the stack */
 	SV *maybe_ary = POPs;
-	if ( ! SvOK(maybe_ary) )
-	    RETURN;
-	if ( ! SvAVOK(maybe_ary) )
+	if ( ! ( PL_op->op_flags & OPf_STACKED) ) {
+	    maybe_ary = sv_mortalcopy(maybe_ary);
+	}
+	if ( SvOK(maybe_ary) && ! SvAVOK(maybe_ary) )
 	    DIE("for loop expected an array but got %s", Ddesc(maybe_ary));
 
-	cx->blk_loop.state_u.ary.ary = (AV*)maybe_ary;
-	SvREFCNT_inc(maybe_ary);
+	cx->blk_loop.state_u.ary.ary = (AV*)SvREFCNT_inc(maybe_ary);
 	cx->blk_loop.state_u.ary.ix =
-	    (PL_op->op_private & OPpITER_REVERSED) ?
-	    AvFILL(cx->blk_loop.state_u.ary.ary) + 1 :
-	    -1;
-    }
-    else { /* iterating over items on the stack */
-	cx->blk_loop.state_u.ary.ary = NULL; /* means to use the stack */
-	if (PL_op->op_private & OPpITER_REVERSED) {
-	    cx->blk_loop.state_u.ary.ix = cx->blk_oldsp + 1;
-	}
-	else {
-	    cx->blk_loop.state_u.ary.ix = MARK - PL_stack_base;
-	}
+	    (PL_op->op_private & OPpITER_REVERSED)
+	    ? (SvAVOK(maybe_ary) ? AvFILL(maybe_ary) + 1 : -1 )
+	    : -1;
     }
 
     RETURN;
@@ -2085,6 +2041,7 @@ Perl_sv_compile_2op(pTHX_ SV *sv, OP** startop, const char *code, PAD** padp)
     int runtime;
     CV* runcv = NULL;	/* initialise to avoid compiler warnings */
     STRLEN len;
+    OP *oldop;
 
     PERL_ARGS_ASSERT_SV_COMPILE_2OP;
 
@@ -2096,21 +2053,9 @@ Perl_sv_compile_2op(pTHX_ SV *sv, OP** startop, const char *code, PAD** padp)
     if (IN_PERL_COMPILETIME) {
 	CopSTASH_set(&PL_compiling, PL_curstash);
     }
-    if (PERLDB_NAMEEVAL && CopLINE(PL_curcop)) {
-	SV * const sv = sv_newmortal();
-	Perl_sv_setpvf(aTHX_ sv, "_<(%.10seval %lu)[%s:%"IVdf"]",
-		       code, (unsigned long)++PL_evalseq,
-		       CopFILE(PL_curcop), (IV)CopLINE(PL_curcop));
-	tmpbuf = SvPVX(sv);
-	len = SvCUR(sv);
-    }
-    else
-	len = my_snprintf(tmpbuf, sizeof(tbuf), "_<(%.10s_eval %lu)", code,
-			  (unsigned long)++PL_evalseq);
-    SAVECOPFILE_FREE(&PL_compiling);
-    CopFILE_set(&PL_compiling, tmpbuf+2);
-    SAVECOPLINE(&PL_compiling);
-    CopLINE_set(&PL_compiling, 1);
+    len = my_snprintf(tmpbuf, sizeof(tbuf), "_<(%.10s_eval %lu)", code,
+	(unsigned long)++PL_evalseq);
+    SVcpSTEAL(PL_parser->lex_filename, newSVpvn(tmpbuf+2, len-2));
     /* XXX For C<eval "...">s within BEGIN {} blocks, this ends up
        deleting the eval's FILEGV from the stash before gv_check() runs
        (i.e. before run-time proper). To work around the coredump that
@@ -2130,9 +2075,11 @@ Perl_sv_compile_2op(pTHX_ SV *sv, OP** startop, const char *code, PAD** padp)
     if (runtime)
 	runcv = find_runcv(NULL);
 
+    oldop = PL_op;
     PL_op = &dummy;
     PL_op->op_type = OP_ENTEREVAL;
     PL_op->op_flags = 0;			/* Avoid uninit warning. */
+    PL_op->op_location = oldop ? newSVsv(oldop->op_location) : newAV();
     PUSHBLOCK(cx, CXt_EVAL|(IN_PERL_COMPILETIME ? 0 : CXp_REAL), SP);
     PUSHEVAL(cx, 0);
 
@@ -2215,7 +2162,7 @@ S_doeval(pTHX_ int gimme, OP** startop, CV* outside, U32 seq)
     if (PL_parser->error_count) {
 	/* were are inside an eval which already has compile errors */
 	Perl_croak(aTHX_ "%"SVf"%s compilation aborted.\n",
-		   SVfARG(ERRSV), OutCopFILE(PL_curcop));
+	    SVfARG(ERRSV), SvPV_nolen_const(PL_parser->lex_filename));
     }
 
     PL_in_eval = ((saveop && saveop->op_type == OP_REQUIRE)
@@ -2304,6 +2251,7 @@ S_doeval(pTHX_ int gimme, OP** startop, CV* outside, U32 seq)
 
 	    PUSHMARK(SP);
 	    XPUSHs(ERRSV);
+	    XPUSHs(PL_op->op_location);
 	    PUTBACK;
 	    call_sv(PL_errorcreatehook, G_SCALAR);
 	    SPAGAIN;
@@ -2318,7 +2266,6 @@ S_doeval(pTHX_ int gimme, OP** startop, CV* outside, U32 seq)
 	PUTBACK;
 	return FALSE;
     }
-    CopLINE_set(&PL_compiling, 0);
     if (startop) {
 	*startop = PL_eval_root;
     } else
@@ -2347,7 +2294,7 @@ S_doeval(pTHX_ int gimme, OP** startop, CV* outside, U32 seq)
 	if (cv) {
 	    dSP;
 	    PUSHMARK(SP);
-	    XPUSHs((SV*)CopFILEGV(&PL_compiling));
+	    XPUSHs(loc_filename(PL_compiling.op_location));
 	    PUTBACK;
 	    call_sv((SV*)cv, G_DISCARD);
 	}
@@ -2438,6 +2385,7 @@ PP(pp_require)
     SV *filter_sub = NULL;
     SV *hook_sv = NULL;
     OP *op;
+    SV *filename;
 
     sv = POPs;
     name = SvPV_const(sv, len);
@@ -2470,11 +2418,13 @@ PP(pp_require)
 	SV * const * const svp = hv_fetch(GvHVn(PL_incgv),
 					  unixname, unixlen, 0);
 	if ( svp ) {
-	    if (*svp != &PL_sv_undef)
+	    if (SvTRUE(*svp))
 		RETPUSHYES;
-	    else
+	    else if (*svp == &PL_sv_undef)
 		DIE(aTHX_ "Attempt to reload %s aborted.\n"
 			    "Compilation failed in require", unixname);
+	    else
+		DIE(aTHX_ "Circular dependency: %s is still being compiled", unixname);
 	}
     }
 
@@ -2682,8 +2632,7 @@ PP(pp_require)
 	    }
 	}
     }
-    SAVECOPFILE_FREE(&PL_compiling);
-    CopFILE_set(&PL_compiling, tryrsfp ? tryname : name);
+    filename = newSVpv( tryrsfp ? tryname : name, 0); /* fixme possible leak. */
     SvREFCNT_dec(namesv);
     if (!tryrsfp) {
 	if (PL_op->op_type == OP_REQUIRE) {
@@ -2721,17 +2670,18 @@ PP(pp_require)
     /* Check whether a hook in @INC has already filled %INC */
     if (!hook_sv) {
 	(void)hv_store(GvHVn(PL_incgv),
-		       unixname, unixlen, newSVpv(CopFILE(&PL_compiling),0),0);
+	    unixname, unixlen, &PL_sv_no, 0);
     } else {
 	SV** const svp = hv_fetch(GvHVn(PL_incgv), unixname, unixlen, 0);
 	if (!svp)
 	    (void)hv_store(GvHVn(PL_incgv),
-			   unixname, unixlen, SvREFCNT_inc_simple(hook_sv), 0 );
+			   unixname, unixlen, &PL_sv_no, 0 );
     }
 
     ENTER;
     SAVETMPS;
     lex_start(NULL, tryrsfp, TRUE);
+    SVcpREPLACE(PL_parser->lex_filename, filename);
 
     SAVEHINTS();
     PL_hints = DEFAULT_HINTS;
@@ -2757,9 +2707,7 @@ PP(pp_require)
     PUSHBLOCK(cx, CXt_EVAL, SP);
     PUSHEVAL(cx, name);
     cx->blk_eval.retop = PL_op->op_next;
-
-    SAVECOPLINE(&PL_compiling);
-    CopLINE_set(&PL_compiling, 0);
+    cx->blk_oldop = PL_op;
 
     PUTBACK;
 
@@ -2768,6 +2716,18 @@ PP(pp_require)
     else
 	op = PL_op->op_next;
 
+    /* mark require as finished */
+    if (!hook_sv) {
+	(void)hv_store(GvHVn(PL_incgv),
+	    unixname, unixlen, newSVsv(filename), 0);
+    } else {
+	SV** const svp = hv_fetch(GvHVn(PL_incgv), unixname, unixlen, 0);
+	if ( ! ( svp && SvTRUE(*svp) ) )
+	    (void)hv_store(GvHVn(PL_incgv),
+		unixname, unixlen, SvREFCNT_inc(hook_sv), 0 );
+    }
+    SvREFCNT_dec(filename);
+
     return op;
 }
 
@@ -2812,24 +2772,13 @@ PP(pp_entereval)
 
     ENTER;
     lex_start(sv, NULL, FALSE);
+    PL_parser->lex_line_number++;
     SAVETMPS;
 
     /* switch to eval mode */
 
-    if (PERLDB_NAMEEVAL && CopLINE(PL_curcop)) {
-	SV * const temp_sv = sv_newmortal();
-	Perl_sv_setpvf(aTHX_ temp_sv, "_<(eval %lu)[%s:%"IVdf"]",
-		       (unsigned long)++PL_evalseq,
-		       CopFILE(PL_curcop), (IV)CopLINE(PL_curcop));
-	tmpbuf = SvPVX(temp_sv);
-	len = SvCUR(temp_sv);
-    }
-    else
-	len = my_snprintf(tmpbuf, sizeof(tbuf), "_<(eval %lu)", (unsigned long)++PL_evalseq);
-    SAVECOPFILE_FREE(&PL_compiling);
-    CopFILE_set(&PL_compiling, tmpbuf+2);
-    SAVECOPLINE(&PL_compiling);
-    CopLINE_set(&PL_compiling, 1);
+    len = my_snprintf(tmpbuf, sizeof(tbuf), "_<(eval %lu)", (unsigned long)++PL_evalseq);
+    SVcpSTEAL(PL_parser->lex_filename, newSVpvn(tmpbuf+2, len-2));
     /* XXX For C<eval "...">s within BEGIN {} blocks, this ends up
        deleting the eval's FILEGV from the stash before gv_check() runs
        (i.e. before run-time proper). To work around the coredump that
@@ -2871,8 +2820,6 @@ PP(pp_entereval)
 
     /* prepare to compile string */
 
-    if (PERLDB_LINE && PL_curstash != PL_debstash)
-	save_lines(CopFILEAV(&PL_compiling), PL_parser->linestr);
     PUTBACK;
     ok = doeval(gimme, NULL, runcv, seq);
     if (PERLDB_INTER && was != (I32)PL_sub_generation /* Some subs defined here. */
@@ -3050,7 +2997,7 @@ STATIC PMOP *
 S_make_matcher(pTHX_ REGEXP *re)
 {
     dVAR;
-    PMOP *matcher = (PMOP *) newPMOP(OP_MATCH, OPf_WANT_SCALAR | OPf_STACKED);
+    PMOP *matcher = (PMOP *) newPMOP(OP_MATCH, OPf_WANT_SCALAR | OPf_STACKED, NULL);
 
     PERL_ARGS_ASSERT_MAKE_MATCHER;
 
@@ -3146,8 +3093,6 @@ S_do_smartmatch(pTHX_ HV *seen_this, HV *seen_other)
 #   define SM_SEEN_OTHER(sv) hv_exists_ent(seen_other, \
 	sv_2mortal(newSViv(PTR2IV(sv))), 0)
 
-    tryAMAGICbinSET(smart, 0);
-    
     SP -= 2;	/* Pop the values */
 
     /* Take care only to invoke mg_get() once for each argument. 
@@ -3501,49 +3446,6 @@ S_run_user_filter(pTHX_ int idx, SV *buf_sv, int maxlen)
     assert(maxlen >= 0);
     umaxlen = maxlen;
 
-    /* I was having segfault trouble under Linux 2.2.5 after a
-       parse error occured.  (Had to hack around it with a test
-       for PL_parser->error_count == 0.)  Solaris doesn't segfault --
-       not sure where the trouble is yet.  XXX */
-
-    if (NULL) { /* IoFMT_GV(datasv)) { */
-	SV *const cache = NULL; /* (SV *)IoFMT_GV(datasv); */
-	if (SvOK(cache)) {
-	    STRLEN cache_len;
-	    const char *cache_p = SvPV(cache, cache_len);
-	    STRLEN take = 0;
-
-	    if (umaxlen) {
-		/* Running in block mode and we have some cached data already.
-		 */
-		if (cache_len >= umaxlen) {
-		    /* In fact, so much data we don't even need to call
-		       filter_read.  */
-		    take = umaxlen;
-		}
-	    } else {
-		const char *const first_nl =
-		    (const char *)memchr(cache_p, '\n', cache_len);
-		if (first_nl) {
-		    take = first_nl + 1 - cache_p;
-		}
-	    }
-	    if (take) {
-		sv_catpvn(buf_sv, cache_p, take);
-		sv_chop(cache, cache_p + take);
-		/* Definately not EOF  */
-		return 1;
-	    }
-
-	    sv_catsv(buf_sv, cache);
-	    if (umaxlen) {
-		umaxlen -= cache_len;
-	    }
-	    SvOK_off(cache);
-	    read_from_cache = TRUE;
-	}
-    }
-
     /* Filter API says that the filter appends to the contents of the buffer.
        Usually the buffer is "", so the details don't matter. But if it's not,
        then clearly what it contains is already filtered by this filter, so we
