@@ -145,7 +145,7 @@ PP(pp_unstack)
 
 PP(pp_concat)
 {
-  dVAR; dSP; dATARGET; tryAMAGICbin(concat,opASSIGN);
+  dVAR; dSP; dATARGET;
   {
     dPOPTOPssrl;
     STRLEN rlen;
@@ -208,7 +208,6 @@ PP(pp_readline)
 {
     dVAR;
     SV* sv;
-    tryAMAGICunTARGET(iter, 0);
     sv = *PL_stack_sp--;
     if (SvTYPE(sv) != SVt_PVGV) {
 	if (SvROK(sv) && SvTYPE(SvRV(sv)) == SVt_PVGV)
@@ -226,14 +225,7 @@ PP(pp_readline)
 
 PP(pp_eq)
 {
-    dVAR; dSP; tryAMAGICbinSET(eq,0);
-#ifndef NV_PRESERVES_UV
-    if (SvROK(TOPs) && !SvAMAGIC(TOPs) && SvROK(TOPm1s) && !SvAMAGIC(TOPm1s)) {
-        SP--;
-	SETs(boolSV(SvRV(TOPs) == SvRV(TOPp1s)));
-	RETURN;
-    }
-#endif
+    dVAR; dSP;
 #ifdef PERL_PRESERVE_IVUV
 
     {
@@ -304,8 +296,8 @@ PP(pp_eq)
 PP(pp_preinc)
 {
     dVAR; dSP;
-    if (SvTYPE(TOPs) >= SVt_PVGV && SvTYPE(TOPs) != SVt_PVLV)
-	DIE(aTHX_ PL_no_modify);
+    if ( SvOK(TOPs) && ! SvPVOK(TOPs) )
+	Perl_croak(aTHX_ "increment (++) does not work on a %s", Ddesc(TOPs));
     if (!SvREADONLY(TOPs) && SvIOK_notUV(TOPs) && !SvNOK(TOPs) && !SvPOK(TOPs)
         && SvIVX(TOPs) != IV_MAX)
     {
@@ -380,7 +372,6 @@ PP(pp_defined)
 PP(pp_add)
 {
     dVAR; dSP; dATARGET; bool useleft; SV *svl, *svr;
-    tryAMAGICbin(add,opASSIGN);
     svl = sv_2num(TOPm1s);
     svr = sv_2num(TOPs);
     useleft = USE_LEFT(svl);
@@ -568,7 +559,7 @@ PP(pp_join)
 {
     dVAR; dSP; dMARK; dTARGET;
     MARK++;
-    do_join(TARG, *MARK, MARK, SP);
+    do_join(TARG, *MARK, MARK[1]);
     SP = MARK;
     SETs(TARG);
     RETURN;
@@ -600,7 +591,6 @@ PP(pp_print)
     dVAR; dSP; dMARK; dORIGMARK;
     IO *io;
     register PerlIO *fp;
-    MAGIC *mg;
     GV * const gv = (PL_op->op_flags & OPf_STACKED) ? (GV*)*++MARK : PL_defoutgv;
 
     if (!(io = GvIO(gv))) {
@@ -760,20 +750,16 @@ PP(pp_aassign)
 	    case SVt_PVAV:
 		ary = (AV*)sv;
 		magic = SvMAGICAL(ary) != 0;
-		av_clear(ary);
-		av_extend(ary, lastrelem - relem);
+		av_fill(ary, lastrelem - relem);
 		i = 0;
 		while (relem <= lastrelem) {	/* gobble up all the rest */
-		    SV **didstore;
 		    assert(*relem);
-		    sv = newSVsv(*relem);
+		    sv = *av_fetch(ary,i++,1);
+		    sv_setsv(sv, *relem);
 		    *(relem++) = sv;
-		    didstore = av_store(ary,i++,sv);
 		    if (magic) {
 			if (SvSMAGICAL(sv))
 			    mg_set(sv);
-			if (!didstore)
-			    sv_2mortal(sv);
 		    }
 		    TAINT_NOT;
 		}
@@ -1255,11 +1241,7 @@ Perl_do_readline(pTHX_ GV* gv)
 		    (void)do_close(gv, FALSE); /* now it does*/
 		}
 	    }
-	    else if (type == OP_GLOB)
-		fp = Perl_start_glob(aTHX_ POPs, gv);
 	}
-	else if (type == OP_GLOB)
-	    SP--;
 	else if (ckWARN(WARN_IO) && IoTYPE(io) == IoTYPE_WRONLY) {
 	    report_evil_fh(gv, io, OP_phoney_OUTPUT_ONLY);
 	}
@@ -1661,9 +1643,8 @@ PP(pp_iter)
     /* iterate array */
     assert(CxTYPE(cx) == CXt_LOOP_FOR);
     av = cx->blk_loop.state_u.ary.ary;
-    if (!av) {
-	av_is_stack = TRUE;
-	av = PL_curstack;
+    if (! SvAVOK(av)) {
+	RETPUSHNO;
     }
     if (PL_op->op_private & OPpITER_REVERSED) {
 	if (cx->blk_loop.state_u.ary.ix <= (av_is_stack
@@ -2030,49 +2011,51 @@ ret_no:
 PP(pp_grepwhile)
 {
     dVAR; dSP;
+    SV** src;
+
+    /* first, move source pointer to the next item in the source list */
+    SV** dst = PL_stack_base + (PL_markstack_ptr[0]) + 0;
+    src = PL_stack_base + PL_markstack_ptr[0] + 1;
+
+    /* if there are new items, push them into the destination list */
+    if (SvTRUE(POPs)) {
+	/* copy the new items down to the destination list */
+	av_push((AV*)*dst, newSVsv(POPs));
+    }
+    else {
+	/* discard item */
+	(void)POPs;
+    }
 
-    if (SvTRUE(POPs))
-	PL_stack_base[PL_markstack_ptr[-1]++] = PL_stack_base[*PL_markstack_ptr];
-    ++*PL_markstack_ptr;
     LEAVE;					/* exit inner scope */
 
     /* All done yet? */
-    if (PL_stack_base + *PL_markstack_ptr > SP) {
-	I32 items;
+    if ( av_len(SvAV(*src)) == -1 ) {
 	const I32 gimme = GIMME_V;
 
 	LEAVE;					/* exit outer scope */
-	(void)POPMARK;				/* pop src */
-	items = --*PL_markstack_ptr - PL_markstack_ptr[-1];
 	(void)POPMARK;				/* pop dst */
 	SP = PL_stack_base + POPMARK;		/* pop original mark */
-	if (gimme == G_SCALAR) {
-	    if (PL_op->op_private & OPpGREP_LEX) {
-		SV* const sv = sv_newmortal();
-		sv_setiv(sv, items);
-		PUSHs(sv);
-	    }
-	    else {
-		dTARGET;
-		XPUSHi(items);
-	    }
+	if (gimme != G_VOID) {
+	    PUSHs(*dst);
 	}
-	else if (gimme == G_ARRAY)
-	    SP += items;
 	RETURN;
     }
     else {
-	SV *src;
+	SV *srcitem;
 
 	ENTER;					/* enter inner scope */
 	SAVEVPTR(PL_curpm);
 
-	src = PL_stack_base[*PL_markstack_ptr];
-	SvTEMP_off(src);
-	if (PL_op->op_private & OPpGREP_LEX)
-	    PAD_SVl(PL_op->op_targ) = src;
+	/* set $_ to the new source item */
+	srcitem = av_shift(SvAV(*src));
+	XPUSHs(srcitem);
+	SvTEMP_off(srcitem);
+	if (PL_op->op_private & OPpGREP_LEX) {
+	    SVcpSTEAL(PAD_SVl(PL_op->op_targ), srcitem);
+	}
 	else
-	    SVcpREPLACE(DEFSV, src);
+	    SVcpSTEAL(DEFSV, srcitem);
 
 	RETURNOP(cLOGOP->op_other);
     }
@@ -2202,10 +2185,6 @@ PP(pp_entersub)
 	    DIE(aTHX_ PL_no_symref, sym, "a subroutine");
 	}
   got_rv:
-	{
-	    SV * const * sp = &sv;		/* Used in tryAMAGICunDEREF macro. */
-	    tryAMAGICunDEREF(to_cv);
-	}	
 	cv = (CV*)SvRV(sv);
 	if (SvTYPE(cv) == SVt_PVCV)
 	    break;
