@@ -1,8 +1,8 @@
 package Moped::Msg;
 use strict;
-use vars qw(@ISA $VERSION);
+use vars < qw(@ISA $VERSION);
 require DynaLoader;
-@ISA = @( qw(DynaLoader) );
+@ISA = qw(DynaLoader);
 $VERSION = '0.01';
  Moped::Msg->bootstrap();
 1;
