@@ -1,8 +1,8 @@
 package MakeMaker::Test::Setup::Problem;
 
-our @ISA = @( qw(Exporter) );
+our @ISA = qw(Exporter);
 require Exporter;
-our @EXPORT = @( qw(setup_recurs teardown_recurs) );
+our @EXPORT = qw(setup_recurs teardown_recurs);
 
 use strict;
 use File::Path;
@@ -18,7 +18,7 @@ WriteMakefile(
 END
 
              'Problem-Module/subdir/Makefile.PL'    => <<'END',
-printf "\@INC \%s .\n", (grep { $_ eq '.' } < @INC) ? "has" : "doesn't have";
+printf "\@INC \%s .\n", (grep { $_ eq '.' } @INC) ? "has" : "doesn't have";
 
 warn "I think I'm going to be sick\n";
 die "YYYAaaaakkk\n";
@@ -30,7 +30,7 @@ END
 sub setup_recurs {
     while(my($file, $text) = each %Files) {
         # Convert to a relative, native file path.
-        $file = 'File::Spec'->catfile('File::Spec'->curdir, split m{\/}, $file);
+        $file = 'File::Spec'->catfile('File::Spec'->curdir, < split m{\/}, $file);
 
         my $dir = dirname($file);
         mkpath $dir;
