@@ -4,18 +4,18 @@ use File::Spec;
 use strict;
 use Config;
 
-use vars qw($VERSION @ISA @EXPORT);
+use vars < qw($VERSION @ISA @EXPORT);
 
 require Exporter;
-@ISA = @( qw(Exporter) );
+@ISA = qw(Exporter);
 
 $VERSION = 0.03;
 
-@EXPORT = @( qw(which_perl perl_lib makefile_name makefile_backup
+@EXPORT = qw(which_perl perl_lib makefile_name makefile_backup
              make make_run run make_macro calibrate_mtime
              setup_mm_test_root
 	     have_compiler
-            ) );
+            );
 
 my $Is_VMS   = $^O eq 'VMS';
 my $Is_MacOS = $^O eq 'MacOS';
@@ -84,7 +84,7 @@ sub which_perl {
         die "Can't find a perl to use (\$^X=$^X), (\$perlpath=$perlpath)" 
           if %ENV{PERL_CORE};
 
-        foreach my $path ( <'File::Spec'->path) {
+        foreach my $path ( 'File::Spec'->path) {
             $perlpath = 'File::Spec'->catfile($path, $perl);
             last if -x $perlpath;
         }
@@ -111,7 +111,7 @@ sub perl_lib {
     $lib = 'File::Spec'->rel2abs($lib);
     my @libs = @($lib);
     push @libs, %ENV{PERL5LIB} if exists %ENV{PERL5LIB};
-    %ENV{PERL5LIB} = join(%Config{path_sep}, < @libs);
+    %ENV{PERL5LIB} = join(%Config{path_sep}, @libs);
     unshift @INC, $lib;
 }
 
@@ -232,7 +232,7 @@ sub calibrate_mtime {
     open(FILE, ">", "calibrate_mtime.tmp") || die $!;
     print FILE "foo";
     close FILE;
-    my($mtime) = (stat('calibrate_mtime.tmp'))[[9]];
+    my($mtime) = @(stat('calibrate_mtime.tmp'))[9];
     unlink 'calibrate_mtime.tmp';
     return $mtime;
 }
