@@ -33,22 +33,22 @@ sub like_eval
     sub new
     {
         my $self = shift ;
-        foreach (< @_)
+        foreach ( @_)
         {
             # autogenerate the name unless if none supplied
             $_ = "tst" . $index ++ . ".tmp"
                 unless defined $_;
         }
         chmod 0777, < @_;
-        for (< @_) { 1 while unlink $_ } ;
-        bless \@( < @_ ), $self ;
+        for ( @_) { 1 while unlink $_ } ;
+        bless \ @_, $self ;
     }
 
     sub DESTROY
     {
         my $self = shift ;
         chmod 0777, < @{ $self } ;
-        for (< @$self) { 1 while unlink $_ } ;
+        for ( @$self) { 1 while unlink $_ } ;
     }
 
 }
@@ -60,14 +60,14 @@ sub like_eval
     sub new
     {
         my $self = shift ;
-        foreach (< @_) { rmtree $_ }
-        bless \@( < @_ ), $self ;
+        foreach ( @_) { rmtree $_ }
+        bless \ @_, $self ;
     }
 
     sub DESTROY
     {
         my $self = shift ;
-        foreach (< @$self) { rmtree $_ }
+        foreach ( @$self) { rmtree $_ }
     }
 }
 sub readFile
@@ -92,12 +92,12 @@ sub readFile
         close F ;
     }
 
-    return join "", < @strings ;
+    return join "", @strings ;
 }
 
 sub touch
 {
-    foreach (< @_) { writeFile($_, '') }
+    foreach ( @_) { writeFile($_, '') }
 }
 
 sub writeFile
@@ -107,7 +107,7 @@ sub writeFile
     open (F, ">", "$filename") 
         or croak "Cannot open $filename: $!\n" ;
     binmode F;
-    foreach (< @strings) {
+    foreach ( @strings) {
         no warnings ;
         print F $_ ;
     }
@@ -157,7 +157,7 @@ sub hexDump
         $offset += 16;
 
         my @array = @( unpack('C*', $data) );
-        foreach (< @array) {
+        foreach ( @array) {
             printf('%2.2x ', $_);
         }
         print "   " x (16 - nelems @array)
@@ -298,7 +298,7 @@ my %TopFuncMap = %(  'IO::Compress::Gzip'          => 'IO::Compress::Gzip::gzip'
                     'IO::Uncompress::DummyUncomp' => 'IO::Uncompress::DummyUncomp::dummyuncomp',
                  );
 
-   %TopFuncMap = %( map { ($_              => %TopFuncMap{$_}, 
+   %TopFuncMap = %( < map { ($_              => %TopFuncMap{$_}, 
                         %TopFuncMap{$_} => %TopFuncMap{$_}) } 
                  keys %TopFuncMap ) ;
 
@@ -324,7 +324,7 @@ my %inverse  = %( 'IO::Compress::Gzip'                    => 'IO::Uncompress::Gu
                  'IO::Compress::DummyComp'               => 'IO::Uncompress::DummyUncomp',
              );
 
-%inverse  = %( map { ($_ => %inverse{$_}, %inverse{$_} => $_) } keys %inverse );
+%inverse  = %( < map { ($_ => %inverse{$_}, %inverse{$_} => $_) } keys %inverse );
 
 sub getInverse
 {
@@ -402,7 +402,7 @@ sub anyUncompress
     my @opts = @( () );
     if (ref $buffer && ref $buffer eq 'ARRAY')
     {
-        @opts = @( < @$buffer );
+        @opts = @$buffer;
         $buffer = shift @opts;
     }
 
@@ -462,7 +462,7 @@ sub getHeaders
     my @opts = @( () );
     if (ref $buffer && ref $buffer eq 'ARRAY')
     {
-        @opts = @( < @$buffer );
+        @opts = @$buffer;
         $buffer = shift @opts;
     }
 
@@ -583,7 +583,7 @@ sub dumpObj
 
     if ((nelems @_))
     {
-        print "#\n# dumpOBJ from $file line $line {join ' ', <@_}\n" ;
+        print "#\n# dumpOBJ from $file line $line {join ' ',@_}\n" ;
     }
     else
     {
