@@ -69,8 +69,8 @@ END {
 # messages
 sub _diag {
     return unless (nelems @_);
-    my @mess = @( map { m/^#/ ? "$_\n" : "# $_\n" }
-               map { split m/\n/ } < @_ );
+    my @mess = map { m/^#/ ? "$_\n" : "# $_\n" }
+ map { < split m/\n/ } @_;
     my $func = $TODO ? \&_print : \&_print_stderr;
     $func->(< @mess);
 }
@@ -81,7 +81,7 @@ sub diag {
 
 sub skip_all {
     if ((nelems @_)) {
-	_print "1..0 # Skipped: {join ' ', <@_}\n";
+	_print "1..0 # Skipped: {join ' ',@_}\n";
     } else {
 	_print "1..0\n";
     }
@@ -323,7 +323,7 @@ sub todo_skip {
 
 sub eq_array {
     my ($ra, $rb) = < @_;
-    return 0 unless (nelems @$ra) == nelems @$rb;
+    return 0 unless (nelems @$ra) == nelems(@$rb);
     for my $i (0..(nelems @$ra)-1) {
 	next     if !defined $ra->[$i] && !defined $rb->[$i];
 	return 0 if !defined $ra->[$i];
@@ -398,7 +398,7 @@ my $is_cygwin   = $^O eq 'cygwin';
 sub _quote_args {
     my ($runperl, $args) = < @_;
 
-    foreach (< @$args) {
+    foreach ( @$args) {
 	# In VMS protect with doublequotes because otherwise
 	# DCL will lowercase -- unless already doublequoted.
        $_ = q(").$_.q(") if $is_vms && !m/^\"/ && length($_) +> 0;
@@ -437,7 +437,7 @@ sub _create_runperl { # Create the string to qx in runperl().
     if (defined %args{progs}) {
 	die "test.pl:runperl(): 'progs' must be an ARRAYREF " . _where()
 	    unless ref %args{progs} eq "ARRAY";
-        foreach my $prog (< @{%args{progs}}) {
+        foreach my $prog ( @{%args{progs}}) {
             if ($is_mswin || $is_netware || $is_vms) {
                 $runperl .= qq ( -e "$prog" );
             }
@@ -503,7 +503,7 @@ sub runperl {
 
     my $tainted = $^TAINT;
     my %args = %( < @_ );
-    exists %args{switches} && grep m/^-T$/, < @{%args{switches}} and $tainted = $tainted + 1;
+    exists %args{switches} && grep m/^-T$/, @{%args{switches}} and $tainted = $tainted + 1;
 
     if ($tainted) {
 	# We will assume that if you're running under -T, you really mean to
@@ -519,14 +519,14 @@ sub runperl {
 	    $sep = %Config{path_sep};
 	}
 
-	my @keys = @( grep {exists %ENV{$_}} qw(CDPATH IFS ENV BASH_ENV) );
-	local %ENV{[< @keys]} = ();
+	my @keys = grep {exists %ENV{$_}} qw(CDPATH IFS ENV BASH_ENV);
+	local %ENV{[ @keys]} = @();
 	# Untaint, plus take out . and empty string:
 	local %ENV{'DCL$PATH'} = $1 if $is_vms && (%ENV{'DCL$PATH'} =~ m/(.*)/s);
 	%ENV{PATH} =~ m/(.*)/s;
 	local %ENV{PATH} =
 	    join $sep, grep { $_ ne "" and $_ ne "." and -d $_ and
-		($is_mswin or $is_vms or !(stat && (stat '_')[[2]]^&^0022)) }
+		($is_mswin or $is_vms or !(stat && @(stat '_')[2]^&^0022)) }
 		    split quotemeta ($sep), $1;
 	%ENV{PATH} .= "$sep/bin" if $is_cygwin;  # Must have /bin under Cygwin
 
@@ -544,7 +544,7 @@ sub runperl {
 *run_perl = \&runperl; # Nice alias.
 
 sub DIE {
-    _print_stderr "# {join ' ', <@_}\n";
+    _print_stderr "# {join ' ',@_}\n";
     exit 1;
 }
 
@@ -599,7 +599,7 @@ sub which_perl {
 }
 
 sub unlink_all {
-    foreach my $file (< @_) {
+    foreach my $file ( @_) {
         1 while unlink $file;
         _print_stderr "# Couldn't unlink '$file': $!\n" if -f $file;
     }
@@ -717,7 +717,7 @@ sub can_ok ($@) {
     }
 
     my @nok = @( () );
-    foreach my $method (< @methods) {
+    foreach my $method ( @methods) {
         local($!, $@);  # don't interfere with caller's $@
                         # eval sometimes resets $!
         try { $proto->can($method) } || push @nok, $method;
