@@ -7,7 +7,7 @@ use utf8;
 use strict;
 
 sub unidump {
-    join " ", map { sprintf "\%04X", $_ } unpack "U*", @_[0];
+    join " ", map { sprintf "\%04X", $_ } @( unpack "U*", @_[0]);
 }
 
 sub casetest {
@@ -15,14 +15,14 @@ sub casetest {
     # For each provided function run it, and run a version with some extra
     # characters afterwards. Use a recycling symbol, as it doesn't change case.
     my $ballast = chr (0x2672) x 3;
-    @funcs = @( map {my $f = $_;
+    @funcs = map {my $f = $_;
 		  ($f,
 		   sub {my $r = $f->(@_[0] . $ballast); # Add it before
 			$r =~ s/$ballast\z//so # Remove it afterwards
 			    or die "'@_[0]' to '$r' mangled";
 			$r; # Result with $ballast removed.
 		    },
-		   )} < @funcs );
+		   )} @funcs;
 
     my $file = 'File::Spec'->catfile('File::Spec'->catdir('File::Spec'->updir,
 						      "lib", "unicore", "To"),
@@ -30,7 +30,7 @@ sub casetest {
     my $simple = do $file or die $@;
     my %simple;
     for my $i (split(m/\n/, $simple)) {
-	my ($k, $v) = split(' ', $i);
+	my ($k, $v) = < split(' ', $i);
 	%simple{$k} = $v;
     }
     my %seen;
@@ -50,7 +50,7 @@ sub casetest {
     exit(1) if $both;
 
     my %none;
-    for my $i (map { ord } split m//,
+    for my $i ( map { ord } split m//,
 	       "\e !\"#\$\%&'()+,-./0123456789:;<=>?\@[\\]^_\{|\}~\b") {
 	next if pack("U0U", $i) =~ m/\w/;
 	%none{$i}++ unless %seen{$i};
@@ -67,7 +67,7 @@ sub casetest {
     for my $i (sort keys %simple) {
 	my $w = %simple{$i};
 	my $c = pack "U0U", hex $i;
-	foreach my $func (< @funcs) {
+	foreach my $func ( @funcs) {
 	    my $d = $func->($c);
 	    my $e = unidump($d);
 	    print $d eq pack("U0U", hex %simple{$i}) ?
@@ -80,7 +80,7 @@ sub casetest {
 	my $w = unidump($spec->{$i});
         #my $c = substr $i, 0, 1;
 	my $h = unidump($i);
-	foreach my $func (< @funcs) {
+	foreach my $func ( @funcs) {
 	    my $d = $func->($i);
 	    my $e = unidump($d);
 	    if (bytes::ord "A" == 193) { # EBCDIC
@@ -140,7 +140,7 @@ sub casetest {
     for my $i (sort { $a <+> $b } keys %none) {
 	my $w = $i = sprintf "\%04X", $i;
 	my $c = pack "U0U", hex $i;
-	foreach my $func (< @funcs) {
+	foreach my $func ( @funcs) {
 	    my $d = $func->($c);
 	    my $e = unidump($d);
 	    print $d eq $c ?
