@@ -3,7 +3,7 @@
 use strict;
 
 use Config;
-use File::Path qw(mkpath);
+use File::Path < qw(mkpath);
 use Getopt::Std;
 
 # Make sure read permissions for all are set:
@@ -12,9 +12,9 @@ if (defined umask && (umask() ^&^ 0444)) {
 }
 
 getopts('Dd:rlhaQe');
-use vars qw($opt_D $opt_d $opt_r $opt_l $opt_h $opt_a $opt_Q $opt_e);
+use vars < qw($opt_D $opt_d $opt_r $opt_l $opt_h $opt_a $opt_Q $opt_e);
 die "-r and -a options are mutually exclusive\n" if ($opt_r and $opt_a);
-my @inc_dirs = @( < inc_dirs() ) if $opt_a;
+my @inc_dirs = inc_dirs() if $opt_a;
 
 my $Exit = 0;
 
@@ -22,17 +22,17 @@ my $Dest_dir = $opt_d || %Config{installsitearch};
 die "Destination directory $Dest_dir doesn't exist or isn't a directory\n"
     unless -d $Dest_dir;
 
-my @isatype = @( qw(
+my @isatype = qw(
 	char	uchar	u_char
 	short	ushort	u_short
 	int	uint	u_int
 	long	ulong	u_long
 	FILE	key_t	caddr_t
 	float	double	size_t
-) );
+);
 
 my %isatype;
-%isatype{[< @isatype]} = (1) x nelems @isatype;
+ <%isatype{[ @isatype]} = (1) x nelems @isatype;
 my $inif = 0;
 my %Is_converted;
 my %bad_file = %( () );
@@ -75,7 +75,7 @@ while (defined (my $file = next_file())) {
 	}
 
 	if ($opt_a) { # automagic mode:  locate header file in @inc_dirs
-	    foreach (< @inc_dirs) {
+	    foreach ( @inc_dirs) {
 		chdir $_;
 		last if -f $file;
 	    }
@@ -250,9 +250,9 @@ while (defined (my $file = next_file())) {
 	    s/\s+/ /g;
 	    next unless m/^\s?(typedef\s?)?enum\s?([a-zA-Z_]\w*)?\s?\{(.*)\}\s?([a-zA-Z_]\w*)?\s?;/;
 	    (my $enum_subs = $3) =~ s/\s//g;
-	    my @enum_subs = @( split(m/,/, $enum_subs) );
+	    my @enum_subs = split(m/,/, $enum_subs);
 	    my $enum_val = -1;
-	    foreach my $enum (< @enum_subs) {
+	    foreach my $enum ( @enum_subs) {
 		my ($enum_name, $enum_value) = $enum =~ m/^([a-zA-Z_]\w*)(=.+)?$/;
 		$enum_name or next;
 		$enum_value =~ s/^=//;
@@ -305,7 +305,7 @@ while (defined (my $file = next_file())) {
 	    }
 	    $args = (
 		(nelems @args)
-		? "my(" . (join ',', map "\$$_", < @args) . ") = \@_;\n$t    "
+		? "my(" . (join ',', map "\$$_", @args) . ") = \@_;\n$t    "
 		: ""
 	    );
 	    my $proto = (nelems @args) ? '' : '() ';
@@ -336,7 +336,7 @@ while (defined (my $file = next_file())) {
 		  ]
 		 [my \$$1;]gx;
 	     }
-	    $new =~ s/&$_\b/\$$_/g for < @local_variables;
+	    $new =~ s/&$_\b/\$$_/g for  @local_variables;
 	    $new =~ s/(["\\])/\\$1/g;       #"]);
 	    # now that's almost like a macro (we hope)
 	    goto EMIT;
@@ -625,7 +625,7 @@ sub expand_glob
     $directory =~ s:/$::;
 
     opendir DIR, $directory;
-        foreach (readdir DIR) {
+        foreach (@(readdir DIR)) {
             next if ($_ eq '.' or $_ eq '..');
 
             # expand_glob() is going to be called until $ARGV[0] isn't a
@@ -774,7 +774,7 @@ sub _extract_cc_defines
 {
     my %define;
     my $allsymbols  = join " ",
-	%Config{['ccsymbols', 'cppsymbols', 'cppccsymbols']};
+	%Config{[@('ccsymbols', 'cppsymbols', 'cppccsymbols')]};
 
     # Split compiler pre-definitions into `key=value' pairs:
     while ($allsymbols =~ m/([^\s]+)=((\\\s|[^\s])+)/g) {
