@@ -3,8 +3,8 @@ use File::DosGlob;
 $| = 1;
 while ((nelems @ARGV)) {
     my $arg = shift;
-    my @m = @( < File::DosGlob::doglob(1,$arg) );
-    print ((nelems @m) ? join("\0", sort < @m) : $arg);
+    my @m = File::DosGlob::doglob(1,$arg);
+    print ((nelems @m) ? join("\0", sort @m) : $arg);
     print "\0" if (nelems @ARGV);
 }
 __END__
